@@ -3,17 +3,19 @@ local GLOBAL_DATA_MODULE = 'global_data'
 local utils = require('Utils')
 local persistence = require('persistence')
 local HTTPResponse = require('HTTPResponse')
+local ShellCommandResponse = require('ShellCommandResponse')
 local Timer = require('Timer')
 local Security = require('Security')
 local SystemEvent = require('SystemEvent')
 local CustomEvent = require('CustomEvent')
 local HistoricalStorage = require('HistoricalStorage')
+local sep = string.sub(package.config, 1, 1)
 
 local function EventHelpers(domoticz, mainMethod)
-
+	local _gv = globalvariables
 	local globalsDefinition
 
-	local currentPath = globalvariables['script_path']
+	local currentPath = _gv['script_path']
 
 	if (_G.TESTMODE) then
 		-- make sure you run the tests from the tests folder !!!!
@@ -26,47 +28,60 @@ local function EventHelpers(domoticz, mainMethod)
 			package.path
 	end
 
-	--if (_G.TESTMODE) then
-	--	-- make sure you run the tests from the tests folder !!!!
-	--	_G.scriptsFolderPath = currentPath .. 'scripts'
-	--	package.path = package.path .. ';' .. currentPath .. 'scripts/?.lua'
-	--	package.path = package.path .. ';' .. currentPath .. 'data/?.lua'
-	--	package.path = package.path .. ';' .. currentPath .. '/../?.lua'
-	--end
+	local validEventTypes = 'devices,timer,security,customEvents,system,httpResponses,shellCommandResponses,scenes,groups,variables'
+	local inValidEventTypes = 'on,logging,active,data,execute'
 
-	local webRoot = globalvariables['domoticz_webroot']
-	local _url = 'http://127.0.0.1:' .. (tostring(globalvariables['domoticz_listening_port']) or "8080")
+	-- defaults
+	local hyperTextTransferProtocol = 'http'
+	local serverPort = '8080'
+	local serverAddress = '127.0.0.1'
 
-	local settings = {
-		['Log level'] = tonumber(globalvariables['dzVents_log_level']) or 1,
-		['Domoticz url'] = _url,
-		url = url,
-		webRoot = tostring(webRoot),
-		serverPort = globalvariables['domoticz_listening_port'] or '8080',
-		dzVentsVersion = globalvariables.dzVents_version,
-		domoticzVersion = globalvariables.domoticz_version,
-		location = {
-			name = utils.urlDecode(globalvariables['domoticz_title'] or "Domoticz"),
-			latitude = globalvariables.latitude or 0,
-			longitude = globalvariables.longitude or 0,
-		}
-	}
-
-	if (webRoot ~= '' and webRoot ~= nil) then
-		settings['Domoticz url'] = settings['Domoticz url'] .. '/' .. tostring(webRoot)
+	if _gv.domoticz_listening_port and tostring(_gv.domoticz_listening_port) ~= '' and tonumber(_gv.domoticz_listening_port) ~= 0 then
+		serverPort = _gv.domoticz_listening_port
+	elseif _gv.domoticz_is_secure and _gv.domoticz_secure_listening_port and
+		tostring(_gv.domoticz_secure_listening_port) ~= '' and tonumber(_gv.domoticz_secure_listening_port) ~= 0 then
+		hyperTextTransferProtocol = 'https'
+		serverPort = _gv.domoticz_secure_listening_port
 	end
 
+	if _gv.domoticz_wwwbind ~= nil and tostring(_gv.domoticz_wwwbind) ~= '' and tostring(_gv.domoticz_wwwbind) ~= '::' then
+		serverAddress = _gv.domoticz_wwwbind
+	end
+
+	local API_url = hyperTextTransferProtocol .. '://' .. serverAddress .. ':' .. serverPort
+
+	local settings = {
+		['Log level'] = _gv.dzVents_log_level or 1,
+		['Domoticz url'] = API_url,
+		url = API_url,
+		webRoot = _gv.domoticz_webroot,
+		wwwBind = _gv.domoticz_wwwbind,
+		serverPort = port,
+		secureServer = _gv.domoticz_is_secure,
+		dzVentsVersion = _gv.dzVents_version,
+		domoticzVersion = _gv.domoticz_version,
+		location = {
+			name = _gv.domoticz_title or 'Domoticz',
+			latitude = _gv.latitude or 0,
+			longitude = _gv.longitude or 0,
+		}
+	}
 	_G.logLevel = settings['Log level']
 
+	if settings.webRoot ~= nil and settings.webRoot ~= '' then
+		settings['Domoticz url'] = settings['Domoticz url'] .. '/' .. settings.webRoot
+		settings.url = settings['Domoticz url']
+	end
+
 	if (domoticz == nil) then
 		local Domoticz = require('Domoticz')
 		domoticz = Domoticz(settings)
 	end
 
 	local self = {
-		['utils'] = utils, -- convenient for testing and stubbing
-		['domoticz'] = domoticz,
-		['settings'] = settings,
+		utils = utils, -- convenient for testing and stubbing
+		domoticz = domoticz,
+		settings = settings,
 	}
 
 	if (_G.TESTMODE) then
@@ -81,19 +96,15 @@ local function EventHelpers(domoticz, mainMethod)
 
 		local storageContext = {}
 		local fileStorage, value, ok
-		--require('lodash').print(1, storageDef)
+		
 		if (storageDef ~= nil) then
 			-- load the datafile for this module
 			ok, fileStorage = pcall(require, module)
-			if type(fileStorage) == boolean then
-				utils.log('Problem with module: ' .. module, utils.LOG_ERROR)
-			end
 			package.loaded[module] = nil -- no caching
 			if (ok) then
 				-- only transfer data as defined in storageDef
 				for _var, _def in pairs(storageDef) do
 					local var, def
-
 					if (type(_var) == 'number' and type(_def) == 'string') then
 						var = _def
 						def = {}
@@ -102,7 +113,23 @@ local function EventHelpers(domoticz, mainMethod)
 						def = _def
 					end
 
-					if (def.history ~= nil and def.history == true) then
+					if type(fileStorage) == 'boolean' then
+
+						local function preserve(fullQualifiedName, fullQualifiedNameFaulty)
+							local inf = io.open(fullQualifiedName, 'rb')
+							local outf = io.open(fullQualifiedNameFaulty, 'w')
+							outf:write(inf:read('*a'))
+							inf:close()
+							outf:close()
+							os.remove(fullQualifiedName)
+						end
+
+						local fullQualifiedName = _G.dataFolderPath .. sep .. module .. '.lua'
+						local fullQualifiedNameFaulty = _G.dataFolderPath .. sep .. module .. '.faulty'
+
+						utils.log('There was an issue with the require of the datamodule "' .. fullQualifiedName .. '"', utils.LOG_ERROR)
+						preserve(fullQualifiedName,fullQualifiedNameFaulty)
+					elseif def.history ~= nil and def.history == true then
 						storageContext[var] = HistoricalStorage(fileStorage[var], def.maxItems, def.maxHours, def.maxMinutes, def.getValue)
 					else
 						if (fileStorage[var] == nil) then
@@ -127,7 +154,6 @@ local function EventHelpers(domoticz, mainMethod)
 						def = _def
 					end
 
-					--require('lodash').print('>', var, def, '<')
 					if (def.history ~= nil and def.history == true) then
 						-- no initial value, just an empty history
 						storageContext[var] = HistoricalStorage(fileStorage[var], def.maxItems, def.maxHours, def.maxMinutes, def.getValue)
@@ -257,6 +283,12 @@ local function EventHelpers(domoticz, mainMethod)
 				end
 				ok, res = pcall(eventHandler['execute'], self.domoticz, subject, info)
 
+			elseif (baseType == domoticz.BASETYPE_SHELLCOMMAND_RESPONSE) then
+				info = getEventInfo(eventHandler, self.domoticz.EVENT_TYPE_SHELLCOMMANDRESPONSE)
+				info.trigger = subject.callback
+				local response = ShellCommandResponse(self.domoticz, subject)
+				ok, res = pcall(eventHandler['execute'], self.domoticz, response, info)
+
 			elseif (baseType == domoticz.BASETYPE_HTTP_RESPONSE) then
 				info = getEventInfo(eventHandler, self.domoticz.EVENT_TYPE_HTTPRESPONSE)
 				info.trigger = subject.callback
@@ -319,7 +351,6 @@ local function EventHelpers(domoticz, mainMethod)
 	function self.scandir(directory, type)
 		local pos, len
 		local i, t, popen = 0, {}, io.popen
-		local sep = string.sub(package.config, 1, 1)
 		local cmd
 		local namesLookup = {}
 
@@ -387,6 +418,15 @@ local function EventHelpers(domoticz, mainMethod)
 		for eventIdx, eventHandler in pairs(events) do
 
 			if (eventHandler.logging) then
+				if type(eventHandler.logging) ~= 'table' then
+					if type(eventHandler.logging) == 'number' then
+						local level = eventHandler.logging
+						eventHandler.logging = {}
+						eventHandler.logging.level = level
+					end
+					utils.log(eventHandler.type .. ' script ' .. eventHandler.name .. '.lua has a malformed logging section. Check the documentation.', utils.LOG_FORCE)
+				end
+
 				if (eventHandler.logging.level ~= nil) then
 					_G.logLevel = eventHandler.logging.level
 				end
@@ -420,6 +460,8 @@ local function EventHelpers(domoticz, mainMethod)
 				moduleLabelInfo = (subject.baseType == 'scene' and ' Scene' or ' Group') .. ': "' .. subject.name .. '", Index: ' .. tostring(subject.id)
 			elseif (baseType == domoticz.BASETYPE_HTTP_RESPONSE) then
 				moduleLabelInfo = ' HTTPResponse: "' .. subject.callback .. '"'
+			elseif (baseType == domoticz.BASETYPE_SHELLCOMMAND_RESPONSE) then
+				moduleLabelInfo = ' ShellCommandResponse: "' .. subject.callback .. '"'
 			elseif (baseType == domoticz.BASETYPE_SYSTEM_EVENT) then
 				moduleLabelInfo = ' Domoticz event: "' .. subject.name .. '"'
 			elseif (baseType == domoticz.BASETYPE_CUSTOM_EVENT) then
@@ -445,6 +487,19 @@ local function EventHelpers(domoticz, mainMethod)
 				utils.log('------ Finished ' .. moduleLabel , utils.LOG_MODULE_EXEC_INFO)
 			end
 
+			if (tonumber(_gv['dzVents_log_level']) == utils.LOG_DEBUG or TESTMODE ) then
+				local moduleSummary = _gv.script_path  .. 'module.log'
+				utils.log('Debug: Writing module summary to ' .. moduleSummary ,utils.LOG_FORCE)
+
+				local f = io.open(moduleSummary, 'a' )
+				f:write(
+					os.date('%x %X - ',timeStampAtStart) .. os.date('%x %X ') .. '(' ..
+					string.format('%02d', realTimeSpend) .. ' - ' .. string.format('%.4f',clockTimeSpend) ..
+					') ' .. string.format('%35s',moduleLabel) .. ' <<' .. moduleLabelInfo ..
+					( eventHandler.trigger and ( ' timer: "' .. eventHandler.trigger .. '"' ) or '') ,'\n')
+				f:close()
+			end
+
 			restoreLogging()
 		end
 	end
@@ -467,10 +522,9 @@ local function EventHelpers(domoticz, mainMethod)
 				return self.processTimeRuleFunction(_rule), 'function'
 			end
 
-			local rule = string.lower(_rule)
-
+			local rule = string.lower(tostring(_rule))
 			if (now.matchesRule(rule)) then
-				return true, rule
+				return true, _rule
 			end
 		end
 
@@ -498,10 +552,9 @@ local function EventHelpers(domoticz, mainMethod)
 	local function loadEventScripts()
 		local scripts = {}
 		local errModules = {}
-		local internalScripts
-		local ok, diskScripts, externalNames, moduleName, i, event, j, err
 		local modules = {}
 		local scripts = {}
+		local requireTimeout, moduleName, event, err, ok, diskScripts, externalNames, internalScripts
 
 		ok, diskScripts, externalNames = pcall(self.scandir, _G.scriptsFolderPath, 'external')
 
@@ -544,6 +597,31 @@ local function EventHelpers(domoticz, mainMethod)
 			table.insert(modules, 1, globalModule)
 		end
 
+		function self.wait(time)
+			local isWindows = string.sub(package.config, 1, 1) ~= '/'
+			local delayCommand = ( isWindows and 'timeout /T 1' ) or 'sleep 1'
+			local duration = os.time() + ( time or 1 )
+			while os.time() < duration do os.execute(delayCommand) end
+		end
+
+		function self.tryRequire(moduleName, requireTimeout, location)
+			local ok = true
+			ok, module = pcall(require, moduleName)
+			if ( ok and module ) or requireTimeout < 1 or not(tostring(module):match('^module')) then
+				return ok, module, requireTimeout
+			elseif not(ok) then
+				while not(ok) and requireTimeout > 0 do
+					utils.log('Loading of ' .. location .. ' script "'.. moduleName .. '.lua" failed. Retrying in a second.', utils.LOG_FORCE)
+					if not(_G.TESTMODE) then self.wait(1) end
+					ok, module = pcall(require, moduleName)
+					if not(ok) then
+						requireTimeout = requireTimeout - 1
+					end
+				end
+			end
+			return ok, module, requireTimeout
+		end
+
 		for i, moduleInfo in ipairs(modules) do
 
 			local module, skip
@@ -552,18 +630,18 @@ local function EventHelpers(domoticz, mainMethod)
 			local logScript = (moduleInfo.type == 'external' and 'Script ' or 'Internal script ')
 
 			_G.domoticz = {
-				['LOG_INFO'] = utils.LOG_INFO,
-				['LOG_MODULE_EXEC_INFO'] = utils.LOG_MODULE_EXEC_INFO,
-				['LOG_DEBUG'] = utils.LOG_DEBUG,
-				['LOG_ERROR'] = utils.LOG_ERROR,
-				['SECURITY_DISARMED'] = self.domoticz.SECURITY_DISARMED,
-				['SECURITY_ARMEDAWAY'] = self.domoticz.SECURITY_ARMEDAWAY,
-				['SECURITY_ARMEDHOME'] = self.domoticz.SECURITY_ARMEDHOME,
+				LOG_INFO = utils.LOG_INFO,
+				LOG_MODULE_EXEC_INFO = utils.LOG_MODULE_EXEC_INFO,
+				LOG_DEBUG = utils.LOG_DEBUG,
+				LOG_ERROR = utils.LOG_ERROR,
+				LOG_FORCE = utils.LOG_FORCE,
+				SECURITY_DISARMED = self.domoticz.SECURITY_DISARMED,
+				SECURITY_ARMEDAWAY = self.domoticz.SECURITY_ARMEDAWAY,
+				SECURITY_ARMEDHOME = self.domoticz.SECURITY_ARMEDHOME,
 			}
 
-			ok = true
-
-			ok, module = pcall(require, moduleName)
+			local ok = true
+			ok, module, requireTimeout = self.tryRequire(moduleName, ( requireTimeout or 3 ), moduleInfo.type )
 
 			_G.domoticz = nil
 
@@ -641,12 +719,32 @@ local function EventHelpers(domoticz, mainMethod)
 			local logScript = (module.type == 'external' and 'Script ' or 'Internal script ')
 
 			for j, event in pairs(module.on) do
+				if type(j) ~= 'string' or type(event) ~= 'table' or validEventTypes:find(j) == nil then
+					if not self.scripts[i].invalidOnSection then
+						self.scripts[i].invalidOnSection = true
+						if type(j) == "string" and validEventTypes:find(j) == nil then
+							if inValidEventTypes:find(j) then
+								utils.log('You entered "' .. tostring(j) .. '" in the on = section. Probably you misplaced your curly brackets', utils.LOG_FORCE)
+							else
+								utils.log('Valid eventTypes are: ' .. validEventTypes, utils.LOG_DEBUG )
+								utils.log('You entered "' .. tostring(j) .. '" in the on = section. Maybe you meant "' .. utils.fuzzyLookup(j, utils.stringSplit(validEventTypes,',')) ..'"?', utils.LOG_FORCE)
+							end
+
+						else
+							utils.log('You entered "' .. utils.toStr(event) .. '" as trigger but the eventType is not (properly) set')
+						end
+						utils.log(logScript .. module.name .. '.lua has an invalid on = section;  please check the wiki. Skipping it until fixed.', utils.LOG_ERROR)
+					end
 
-				if (not (type(j) == 'string' or type(event) == 'table')) then
-					utils.log(logScript .. module.name .. '.lua has a malformed on-section. Check the documentation. Skipping', utils.LOG_DEBUG)
 				else
 					if (mode == 'timer' and j == 'timer') then
 						-- { ['timer'] = { 'every minute ', 'every hour' } }
+
+						if type(event) ~= 'table' then
+							utils.log(logScript .. module.name .. '.lua has a malformed timer = section. Check the documentation.', utils.LOG_FORCE)
+							event = { event }
+						end
+
 						local triggered, def = self.processTimeRules(event)
 						if (triggered) then
 							-- this one can be executed
@@ -675,13 +773,13 @@ local function EventHelpers(domoticz, mainMethod)
 
 						-- { ['scenes'] = { 'scA', ['scB'] = { ..timedefs }, .. }
 
-						for devIdx, scgrpName in pairs(event) do
+						for scgrpIdx, scgrpName in pairs(event) do
 
 							-- detect if scgrpName is of the form ['devB'] = { 'every hour' }
 							if (type(scgrpName) == 'table') then
 								local triggered, def = self.processTimeRules(scgrpName, testTime)
 								if (triggered) then
-									addBindingEvent(bindings, devIdx, module)
+									addBindingEvent(bindings, scgrpIdx, module)
 								end
 							else
 								-- a single scene or group name (or id)
@@ -704,6 +802,11 @@ local function EventHelpers(domoticz, mainMethod)
 						for i, callbackName in pairs(event) do
 							addBindingEvent(bindings, callbackName, module)
 						end
+					elseif (mode == 'shellcommandResponse' and j == 'shellCommandResponses') then
+						-- { ['shellCommandResponses'] = { 'callbackA', 'callbackB' }
+						for i, callbackName in pairs(event) do
+							addBindingEvent(bindings, callbackName, module)
+						end
 					elseif (mode == 'system' and j == 'system') then
 						-- { ['system'] = { 'start', 'end' }
 						for evtIdx, systemEvent in pairs(event) do
@@ -737,7 +840,6 @@ local function EventHelpers(domoticz, mainMethod)
 				end
 			end
 		end
-
 		return bindings, self.errModules
 	end
 
@@ -749,7 +851,7 @@ local function EventHelpers(domoticz, mainMethod)
 			fromIndex = 1
 		end
 
-		if (force == true and force ~= nil or globalvariables['testmode'] == true) then
+		if (force == true and force ~= nil or _gv['testmode'] == true) then
 			level = utils.LOG_INFO
 		end
 
@@ -760,7 +862,7 @@ local function EventHelpers(domoticz, mainMethod)
 				end
 				if (type(v) == 'table') then
 					for kk, vv in pairs(v) do
-						utils.log('- ' .. kk .. ' = ' .. _.str(vv), level)
+						utils.log('- ' .. kk .. ' = ' .. utils.toStr(vv), level)
 					end
 				else
 					utils.log(k .. ' = ' .. v, level)
@@ -805,7 +907,15 @@ local function EventHelpers(domoticz, mainMethod)
 
 		for scriptTrigger, scripts in pairs(allEventScripts) do
 
-			if (string.find(scriptTrigger, '*')) then -- a wild-card was used
+			local function strFind(str, key)
+				return string.find(str, key)
+			end
+
+			local ok, res = pcall(strFind, scriptTrigger, '*');
+			if not ok then
+				utils.log('Script name: ' .. scripts[1].name  .. '.lua, has a malformed on = section. The trigger = ' .. utils.toStr(scriptTrigger) , utils.LOG_ERROR)
+				allEventScripts[scriptTrigger] = ''
+			elseif res then -- a wild-card was used
 				scriptTrigger = ('^' .. scriptTrigger:gsub("[%^$]","."):gsub("*", ".*") .. '$')
 
 				local function sMatch(text, match) -- specialized sanitized match function to allow combination of Lua magic chars in wildcards
@@ -985,6 +1095,37 @@ local function EventHelpers(domoticz, mainMethod)
 		return self.domoticz.commandArray
 	end
 
+	function self.dispatchShellCommandResponseEventsToScripts(domoticz)
+		if (domoticz == nil) then -- you can pass a domoticz object for testing purposes
+			domoticz = self.domoticz
+		end
+
+		local shellcommandResponseScripts = self.getEventBindings('shellcommandResponse')
+
+		local responses =_G.shellcommandresponse
+
+		if (responses ~= nil) then
+			for i, response in pairs(responses) do
+				response.baseType = domoticz.BASETYPE_SHELLCOMMAND_RESPONSE
+				local callback = response.callback
+				local caSize = _.size(self.domoticz.commandArray)
+
+				local scriptsToExecute = self.findScriptForTarget(callback, shellcommandResponseScripts)
+
+				if (scriptsToExecute ~= nil) then
+					utils.log('Handling shellcommandResponse-events for: "' .. callback .. '"', utils.LOG_MODULE_EXEC_INFO)
+					self.handleEvents(scriptsToExecute, response)
+					self.dumpCommandArray(self.domoticz.commandArray, caSize + 1)
+				end
+
+			end
+
+		end
+
+		return self.domoticz.commandArray
+
+	end
+
 	function self.dispatchHTTPResponseEventsToScripts(domoticz)
 		if (domoticz == nil) then -- you can pass a domoticz object for testing purposes
 			domoticz = self.domoticz
@@ -1060,10 +1201,16 @@ local function EventHelpers(domoticz, mainMethod)
 			domoticz = self.domoticz
 		end
 
-		if (_G.notification == nil) then
+		if (_G.notification == nil or _G.notification.customevent == nil ) then
 			return
 		end
 
+		for _, row in ipairs(_G.notification.customevent) do
+			 if row.data.name:match('^___%a*__$') then
+				table.insert(self.domoticz.commandArray, { [ row.data.name:sub(4,-3) ] = row.data.data })
+			 end
+		end
+
 		local customEventScripts = self.getEventBindings('customEvents', nil)
 		local customEvents = _G.notification.customevent
 
@@ -1144,7 +1291,7 @@ local function EventHelpers(domoticz, mainMethod)
 
 		local customEvents = _G.notification and _G.notification.customEvents or nil
 
-		if (dcustomEvents ~= nil) then
+		if (customEvents ~= nil) then
 			for i, customEvent in pairs(customEvents) do
 				table.insert(items, '- Custom: ' .. customEvent.type) -- .. ' - ' .. customEvent.status)
 				length = length + 1
