@@ -8,6 +8,10 @@ local function Timer(domoticz, rule)
 
 	evenItemIdentifier.setType(self, 'isTimer', domoticz.BASETYPE_TIMER, rule)
 
+	function self.dump( filename )
+		domoticz.logObject(self, filename, 'timer')
+	end
+
 	return self
 
 end
