@@ -28,11 +28,13 @@ local function getDevice_(
 	additionalRootData,
 	additionalDataData,
 	hardwareType,
-	hardwaryTypeValue,
+	hardwareTypeValue,
 	baseType,
 	dummyLogger,
 	batteryLevel,
-	signalLevel)
+	signalLevel,
+	nValue,
+	customImage)
 
 	local Device = require('Device')
 
@@ -63,10 +65,11 @@ local function getDevice_(
 	{
 		["id"] = 1,
 		["name"] = name,
+		["customImage"] = 102,
 		["description"] = "Description 1",
 		["batteryLevel"] = batteryLevel and batteryLevel or 50,
 		["protected"] = true,
-		["signalLevel"] = signalLevel and signalLevel or 55,
+		["signalLevel"] = signalLevel and signalLevel or 11,
 		["deviceType"] = type and type or "someSubType",
 		["deviceID"] = "123abc",
 		["subType"] = subType and subType or "someDeviceType",
@@ -78,14 +81,14 @@ local function getDevice_(
 		["_state"] = state,
 		["hardwareName"] = "hw1",
 		["hardwareType"] = hardwareType,
-		["hardwareTypeValue"] = hardwaryTypeValue,
+		["hardwareTypeValue"] = hardwareTypeValue,
 		["hardwareID"] = 1,
 		['protected'] = true,
-		['_nValue'] = 123,
+		['_nValue'] = nValue or 123,
 		['unit'] = 1
 		},
 		["rawData"] = rawData,
-		["baseType"] = baseType ~= nil and baseType or "device",
+		["baseType"] = baseType or "device",
 		["changed"] = changed,
 		["changedAttribute"] = 'temperature' --tbd
 	}
@@ -117,7 +120,9 @@ local function getDevice(domoticz, options)
 		options.baseType,
 		options.dummyLogger,
 		options.batteryLevel,
-		options.signalLevel)
+		options.signalLevel,
+		options.nValue,
+		options.customImage)
 
 end
 
@@ -162,6 +167,8 @@ describe('device', function()
 			['currentTime'] = '2017-08-17 12:13:14.123'
 		}
 
+		_G.domoticzData = {}
+
 		TimedCommand = require('TimedCommand')
 
 		Device = require('Device')
@@ -176,6 +183,7 @@ describe('device', function()
 			['name'] = 'myDevice',
 			['type'] = 'Light/Switch',
 			['state'] = 'On',
+			['customImage'] = 102,
 			['changed'] = true,
 		})
 		utils = device._getUtilsInstance()
@@ -198,7 +206,8 @@ describe('device', function()
 				subType = 'sub',
 				hardwareType = 'hwtype',
 				hardwareTypeValue = 'hvalue',
-				state = 'bla'
+				state = 'bla',
+				id = 1,
 			})
 
 			assert.is_same(true, device.changed)
@@ -213,7 +222,7 @@ describe('device', function()
 			assert.is_same(true, device.timedOut)
 			assert.is_same(true, device.protected)
 			assert.is_same(50, device.batteryLevel)
-			assert.is_same(55, device.signalLevel)
+			assert.is_same(11, device.signalLevel)
 			assert.is_same('sub', device.deviceSubType)
 			assert.is_same(2016, device.lastUpdate.year)
 			assert.is_same({'1', '2', '3'}, device.rawData)
@@ -275,12 +284,12 @@ describe('device', function()
 				hardwareType = 'hwtype',
 				hardwareTypeValue = 'hvalue',
 				state = 'bla',
-				batteryLevel = 100,
-				signalLevel = 100
+				batteryLevel = 31,
+				signalLevel = 11
 			})
 
-			assert.is_same(100, device.batteryLevel)
-			assert.is_same(100, device.signalLevel)
+			assert.is_same(31, device.batteryLevel)
+			assert.is_same(11, device.signalLevel)
 
 			device = getDevice(domoticz, {
 				['name'] = 'myDevice',
@@ -290,12 +299,12 @@ describe('device', function()
 				hardwareType = 'hwtype',
 				hardwareTypeValue = 'hvalue',
 				state = 'bla',
-				batteryLevel = 0,
-				signalLevel = 0
+				batteryLevel = -1,
+				signalLevel = 100
 			})
 
-			assert.is_same(0, device.batteryLevel)
-			assert.is_same(0, device.signalLevel)
+			assert.is_nil(device.batteryLevel)
+			assert.is_nil(device.signalLevel)
 		end)
 
 		it('should detect a lux device', function()
@@ -599,6 +608,7 @@ describe('device', function()
 					"updateDistance",
 					"updateElectricity",
 					"updateGas",
+					"updateHistory",
 					"updateHumidity",
 					"updateLux",
 					"updateMode",
@@ -743,7 +753,7 @@ describe('device', function()
 			end
 			local test = 'sValue'
 			device.setValues(12,test,13,14,test)
-			assert.is_same('http://127.0.0.1:8080/json.htm?type=command&param=udevice&idx=1&nvalue=12&svalue=sValue;13;14;sValue', res)
+			assert.is_same('http://127.0.0.1:8080/json.htm?type=command&param=udevice&idx=1&nvalue=12&svalue=sValue;13;14;sValue&parsetrigger=false', res)
 		end)
 
 		it('should detect an evohome device', function()
@@ -871,6 +881,34 @@ describe('device', function()
 
 		end)
 
+		it('should detect a Thermostat type 3 device', function()
+
+			local device = getDevice(domoticz, {
+				['name'] = 'myDevice',
+				['type'] = 'Thermostat 3',
+				['subType'] = 'Mertik some type',
+				['nValue'] = 2;
+				['_nValue'] = 2;
+				}
+			)
+
+			domoticz.openURL = function(url)
+				return url;
+			end
+
+			assert.is_same( { 'Off', 'On', 'Up', 'Down', 'Run Up', 'Run Down', 'Stop' } , utils.stringSplit(device.modes,',') )
+			assert.is_same(2, device.mode)
+			assert.is_same('Up', device.modeString)
+
+			assert.is_same( 'http://127.0.0.1:8080/json.htm?type=command&param=switchlight&idx=1&switchcmd=Off', device.updateMode('Off'))
+			assert.is_same( 'http://127.0.0.1:8080/json.htm?type=command&param=switchlight&idx=1&switchcmd=On', device.updateMode('On'))
+			assert.is_same( 'http://127.0.0.1:8080/json.htm?type=command&param=switchlight&idx=1&switchcmd=Up', device.updateMode('Up'))
+			assert.is_same( 'http://127.0.0.1:8080/json.htm?type=command&param=switchlight&idx=1&switchcmd=Down', device.updateMode('Down'))
+			assert.is_same( 'http://127.0.0.1:8080/json.htm?type=command&param=switchlight&idx=1&switchcmd=Run%20Up', device.updateMode('Run Up'))
+			assert.is_same( 'http://127.0.0.1:8080/json.htm?type=command&param=switchlight&idx=1&switchcmd=Run%20Down', device.updateMode('Run Down'))
+			assert.is_same( 'http://127.0.0.1:8080/json.htm?type=command&param=switchlight&idx=1&switchcmd=Stop', device.updateMode('Stop'))
+		end)
+
 		it('should detect a wind device', function()
 			local device = getDevice(domoticz, {
 				['name'] = 'myDevice',
@@ -955,6 +993,16 @@ describe('device', function()
 			device.updateTempHum(10, 12, 'wet')
 			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="10;12;wet", _trigger=true} } }, commandArray)
 			assert.is_same(2, device.humidityStatusValue)
+
+			commandArray = {}
+			device.updateTempHum(10, 12)
+			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="10;12;2", _trigger=true} } }, commandArray)
+			assert.is_same(2, device.humidityStatusValue)
+
+			commandArray = {}
+			device.updateTempHum(24, 52)
+			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="24;52;1", _trigger=true} } }, commandArray)
+			assert.is_same(2, device.humidityStatusValue)
 		end)
 
 		it('should detect a temp+humidity+barometer device', function()
@@ -966,8 +1014,18 @@ describe('device', function()
 				}
 			})
 
-			device.updateTempHumBaro(10, 12, 'wet', 1000, 'rain')
-			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="10;12;wet;1000;4", _trigger=true} } }, commandArray)
+			device.updateTempHumBaro(10, 12, 2, 1000, 'rain')
+			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="10;12;2;1000;4", _trigger=true} } }, commandArray)
+			assert.is_same(1, device.humidityStatusValue)
+
+			commandArray = {}
+			device.updateTempHumBaro(10, 12, -1, 1000, 'rain')
+			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="10;12;2;1000;4", _trigger=true} } }, commandArray)
+			assert.is_same(1, device.humidityStatusValue)
+
+			commandArray = {}
+			device.updateTempHumBaro(24, 52, -1, 1000, 'rain')
+			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="24;52;1;1000;4", _trigger=true} } }, commandArray)
 			assert.is_same(1, device.humidityStatusValue)
 		end)
 
@@ -1017,6 +1075,37 @@ describe('device', function()
 			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="10", _trigger=true} } }, commandArray)
 		end)
 
+		it('should detect a managed counter device', function()
+			local device = getDevice(domoticz, {
+				['name'] = 'myDevice',
+				['type'] = 'Counter',
+				['subType'] = 'Managed Counter',
+				['additionalDataData'] = {
+					["counterToday"] = "123.44 Watt";
+					["counter"] = "6.7894 kWh";
+				}
+			})
+
+			domoticz.openURL = function(url)
+				return table.insert(commandArray, url)
+			end
+
+			assert.is_same(123.44, device.counterToday)
+			assert.is_same(6.7894, device.counter)
+
+			commandArray = {}
+			device.updateCounter(555.123)
+			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="555.123", _trigger=true} } }, commandArray)
+
+			 commandArray = {}
+			device.updateHistory('2021-13-32','12;234567')
+			assert.is_same( { 'http://127.0.0.1:8080/json.htm?type=command&param=udevice&idx=1&nvalue=0&svalue=12;234567;2021-13-32' }, commandArray)
+
+			commandArray = {}
+			device.updateHistory('2021-13-32 12:34:56','12;234567')
+			assert.is_same( { 'http://127.0.0.1:8080/json.htm?type=command&param=udevice&idx=1&nvalue=0&svalue=12;234567;2021-13-32+12%3A34%3A56' }, commandArray)
+		end)
+
 		it('should detect a pressure device', function()
 			local device = getDevice(domoticz, {
 				['name'] = 'myDevice',
@@ -1097,11 +1186,25 @@ describe('device', function()
 		it('should detect a custom sensor device', function()
 			local device = getDevice(domoticz, {
 				['name'] = 'myDevice',
-				['subType'] = 'Custom Sensor'
+				['subType'] = 'Custom Sensor',
+				['rawData'] = { [1]="12" }
 			})
 
 			device.updateCustomSensor(12)
 			assert.is_same({ { ["UpdateDevice"] = {idx=1, nValue=0, sValue="12", _trigger=true} } }, commandArray)
+
+			assert.is_same(12, device.sensorValue)
+			assert.is_same('number' , type(device.sensorValue) )
+
+			local device = getDevice(domoticz, {
+				['name'] = 'myDevice',
+				['subType'] = 'Custom Sensor',
+				['rawData'] = { [1]="12a" }
+			})
+
+			assert.is_same('12a', device.sensorValue)
+			assert.is_same('string', type(device.sensorValue))
+
 		end)
 
 		it('should detect a solar radiation device', function()
@@ -1529,6 +1632,42 @@ describe('device', function()
 			end)
 		end)
 
+		describe('hardware', function()
+
+			it('should detect hardware', function()
+				local hardware = getDevice(domoticz, {
+					['baseType'] = 'hardware',
+					['name'] = 'myHardware',
+					['hardwareType'] = 'myHardware type',
+					['hardwareTypeValue'] = '234',
+				})
+
+				assert.is_false(hardware.isHTTPResponse)
+				assert.is_false(hardware.isVariable)
+				assert.is_false(hardware.isTimer)
+				assert.is_false(hardware.isDevice)
+				assert.is_false(hardware.isGroup)
+				assert.is_false(hardware.isScene)
+				assert.is_false(hardware.isSecurity)
+				assert.is_true(hardware.isHardware)
+			end)
+
+			it('should return attributes correctly', function()
+				local hardware = getDevice(domoticz, {
+					['baseType'] = 'hardware',
+					['name'] = 'myHardware',
+					['hardwareType'] = 'myHardware type',
+					['hardwareTypeValue'] = 234,
+				})
+
+				assert.is_equal(hardware.name,'myHardware' )
+				assert.is_equal(hardware.hardwareType,'myHardware type' )
+				assert.is_equal(hardware.hardwareTypeValue,234)
+				assert.is_true(hardware.isHardware)
+
+			end)
+		end)
+
 		it('should detect a huelight', function()
 			local device = getDevice(domoticz, {
 				['name'] = 'myHue',
@@ -1550,6 +1689,25 @@ describe('device', function()
 			assert.is_same({ { ["myHue"] = "Off" } }, commandArray)
 		end)
 
+		it('should detect a Thermostat operating state device', function()
+			local device = getDevice(domoticz, {
+				['idx'] = 1,
+				['type'] = 'General',
+				['name'] = 'myThermostat operating state device',
+				['subType'] = 'Thermostat Operating State',
+				['nValue'] = 0,
+			})
+
+			assert.is_same('Idle', device.modeString)
+			assert.is_same('Idle, Cooling, Heating', device.modes)
+			assert.is_same(0, device.mode)
+
+			commandArray = {}
+			device.updateMode('Cooling')
+			assert.is_same({ { ['UpdateDevice'] = { ['_trigger'] = true, ['idx'] = 1, ['nValue'] = 1, ['sValue'] = 'cooling' } }  }, commandArray)
+
+		end)
+
 		it('should detect a youless device', function()
 			local device = getDevice(domoticz, {
 				['name'] = 'myYouless',
@@ -1604,6 +1762,42 @@ describe('device', function()
 			end)
 		end)
 
+		describe('Quiet device ( updateQuiet', function()
+
+			local commandArray = {}
+			domoticz.openURL = function(url)
+				return table.insert(commandArray, url)
+			end
+
+			local device = getDevice(domoticz, {
+				['name'] = 'quietDevice',
+				['state'] = 'On',
+					['type'] = 'Light/Switch',
+				['subType'] = 'RGBWW',
+				['type'] = 'Color Switch'
+			})
+
+			it('should handle the updateQuiet method correctly )', function()
+				commandArray = {}
+				device.updateQuiet() -- fail (no parms)
+				assert.is_same({  }, commandArray) -- empty
+
+				commandArray = {}
+				device.updateQuiet('string only') -- only svalue
+				assert.is_same({ 'http://127.0.0.1:8080/json.htm?type=command&param=udevice&idx=1&svalue=string+only'  }, commandArray)
+
+				commandArray = {}
+				device.updateQuiet(7) -- only nvalue
+				assert.is_same({ 'http://127.0.0.1:8080/json.htm?type=command&param=udevice&idx=1&nvalue=7'  }, commandArray)
+
+				commandArray = {}
+				device.updateQuiet(7, '(string plus)') -- nvalue, svalue
+				assert.is_same({ 'http://127.0.0.1:8080/json.htm?type=command&param=udevice&idx=1&svalue=%28string+plus%29&nvalue=7'   }, commandArray)
+
+			end)
+
+		end)
+
 		describe('RGBW device #RGB', function()
 
 			local commandArray = {}
@@ -1695,13 +1889,13 @@ describe('device', function()
 			it('should handle setColor method correctly',function()
 				commandArray = {}
 				assert.is_nil(device.setColor(15,31,44))
-				assert.is_same({'http://127.0.0.1:8080/json.htm?type=command&param=setcolbrightnessvalue&idx=1&brightness=100&color={"m":3,"t":0,"cw":0,"ww":0,"r":15,"g":31,"b":44}'},commandArray)
+				assert.is_same({'http://127.0.0.1:8080/json.htm?type=command&param=setcolbrightnessvalue&idx=1&brightness=1&color={"m":3,"t":0,"cw":0,"ww":0,"r":15,"g":31,"b":44}'},commandArray)
 			end)
 
 			it('should handle setColorBrightness method correctly',function()
 				commandArray = {}
 				assert.is_nil(device.setColorBrightness(15,31,44))
-				assert.is_same({'http://127.0.0.1:8080/json.htm?type=command&param=setcolbrightnessvalue&idx=1&brightness=100&color={"m":3,"t":0,"cw":0,"ww":0,"r":15,"g":31,"b":44}'},commandArray)
+				assert.is_same({'http://127.0.0.1:8080/json.htm?type=command&param=setcolbrightnessvalue&idx=1&brightness=1&color={"m":3,"t":0,"cw":0,"ww":0,"r":15,"g":31,"b":44}'},commandArray)
 			end)
 
 			it('should handle setDiscomode method correctly',function()
