@@ -28,14 +28,11 @@
 #include "ASyncSerial.h"
 #include "../main/Logger.h"
 #include "../main/Helper.h"
-#include "../main/Noncopyable.h"
 
 #include <string>
 #include <algorithm>
 #include <iostream>
 #include <boost/asio.hpp>
-#include <boost/bind.hpp>
-#include <boost/function.hpp>
 #include <boost/thread.hpp>
 #include <boost/smart_ptr/shared_array.hpp>  // for shared_array
 #include <boost/system/error_code.hpp>       // for error_code
@@ -51,25 +48,28 @@ class AsyncSerialImpl
 	: private domoticz::noncopyable
 {
 public:
-    AsyncSerialImpl(): io(), port(io), backgroundThread(), open(false),
-		error(false), writeBufferSize(0) {}
+  AsyncSerialImpl()
+	  : io()
+	  , port(io)
+  {
+  }
 
     boost::asio::io_service io; ///< Io service object
     boost::asio::serial_port port; ///< Serial port object
     boost::thread backgroundThread; ///< Thread that runs read/write operations
-    bool open; ///< True if port open
-    bool error; ///< Error flag
+    bool open{ false };		    ///< True if port open
+    bool error{ false };	    ///< Error flag
     mutable std::mutex errorMutex; ///< Mutex for access to error
 
     /// Data are queued here before they go in writeBuffer
     std::vector<char> writeQueue;
     boost::shared_array<char> writeBuffer; ///< Data being written
-    size_t writeBufferSize; ///< Size of writeBuffer
+    size_t writeBufferSize{ 0 };	   ///< Size of writeBuffer
     std::mutex writeQueueMutex; ///< Mutex for access to writeQueue
     char readBuffer[BUFFER_SIZE]; ///< data being read
 
     /// Read complete callback
-    boost::function<void (const char*, size_t)> callback;
+    std::function<void(const char *, size_t)> callback;
 };
 
 AsyncSerial::AsyncSerial(): pimpl(new AsyncSerialImpl)
@@ -98,10 +98,11 @@ void AsyncSerial::open(const std::string& devname, unsigned int baud_rate,
         boost::asio::serial_port_base::flow_control opt_flow,
         boost::asio::serial_port_base::stop_bits opt_stop)
 {
-    if(isOpen()) close();
+	if (isOpen())
+		close();
 
-    setErrorStatus(true);//If an exception is thrown, error_ remains true
-    pimpl->port.open(devname);
+	setErrorStatus(true); // If an exception is thrown, error_ remains true
+	pimpl->port.open(devname);
 	try {
 		pimpl->port.set_option(boost::asio::serial_port_base::baud_rate(baud_rate));
 		pimpl->port.set_option(opt_parity);
@@ -118,13 +119,13 @@ void AsyncSerial::open(const std::string& devname, unsigned int baud_rate,
 
 	pimpl->io.reset();
 
-    //This gives some work to the io_service before it is started
-    pimpl->io.post(boost::bind(&AsyncSerial::doRead, this));
+	// This gives some work to the io_service before it is started
+	pimpl->io.post([this] { return doRead(); });
 
-    boost::thread t(boost::bind(&boost::asio::io_service::run, &pimpl->io));
-    pimpl->backgroundThread.swap(t);
-    setErrorStatus(false);//If we get here, no error
-    pimpl->open=true; //Port is now open
+	boost::thread t([p = &pimpl->io] { p->run(); });
+	pimpl->backgroundThread.swap(t);
+	setErrorStatus(false); // If we get here, no error
+	pimpl->open = true;    // Port is now open
 }
 
 void AsyncSerial::openOnlyBaud(const std::string& devname, unsigned int baud_rate,
@@ -151,9 +152,9 @@ void AsyncSerial::openOnlyBaud(const std::string& devname, unsigned int baud_rat
 	pimpl->io.reset();
 
 	//This gives some work to the io_service before it is started
-	pimpl->io.post(boost::bind(&AsyncSerial::doRead, this));
+	pimpl->io.post([this] { return doRead(); });
 
-	boost::thread t(boost::bind(&boost::asio::io_service::run, &pimpl->io));
+	boost::thread t([p = &pimpl->io] { p->run(); });
 	pimpl->backgroundThread.swap(t);
 	setErrorStatus(false);//If we get here, no error
 	pimpl->open=true; //Port is now open
@@ -175,7 +176,7 @@ void AsyncSerial::close()
     if(!isOpen()) return;
 
     pimpl->open = false;
-    pimpl->io.post(boost::bind(&AsyncSerial::doClose, this));
+    pimpl->io.post([this] { doClose(); });
     pimpl->backgroundThread.join();
     pimpl->io.reset();
     if(errorStatus())
@@ -191,7 +192,7 @@ void AsyncSerial::write(const char *data, size_t size)
         std::lock_guard<std::mutex> l(pimpl->writeQueueMutex);
         pimpl->writeQueue.insert(pimpl->writeQueue.end(),data,data+size);
     }
-    pimpl->io.post(boost::bind(&AsyncSerial::doWrite, this));
+    pimpl->io.post([this] { doWrite(); });
 }
 
 void AsyncSerial::write(const std::string &data)
@@ -200,7 +201,7 @@ void AsyncSerial::write(const std::string &data)
 		std::lock_guard<std::mutex> l(pimpl->writeQueueMutex);
 		pimpl->writeQueue.insert(pimpl->writeQueue.end(), data.c_str(), data.c_str()+data.size());
 	}
-	pimpl->io.post(boost::bind(&AsyncSerial::doWrite, this));
+	pimpl->io.post([this] { doWrite(); });
 }
 
 void AsyncSerial::write(const std::vector<char>& data)
@@ -210,7 +211,7 @@ void AsyncSerial::write(const std::vector<char>& data)
         pimpl->writeQueue.insert(pimpl->writeQueue.end(),data.begin(),
                 data.end());
     }
-    pimpl->io.post(boost::bind(&AsyncSerial::doWrite, this));
+    pimpl->io.post([this] { doWrite(); });
 }
 
 void AsyncSerial::writeString(const std::string& s)
@@ -219,17 +220,13 @@ void AsyncSerial::writeString(const std::string& s)
         std::lock_guard<std::mutex> l(pimpl->writeQueueMutex);
         pimpl->writeQueue.insert(pimpl->writeQueue.end(),s.begin(),s.end());
     }
-    pimpl->io.post(boost::bind(&AsyncSerial::doWrite, this));
+    pimpl->io.post([this] { doWrite(); });
 }
 
 void AsyncSerial::doRead()
 {
 	if(isOpen()==false) return;
-    pimpl->port.async_read_some(boost::asio::buffer(pimpl->readBuffer,sizeof(pimpl->readBuffer)),
-            boost::bind(&AsyncSerial::readEnd,
-            this,
-            boost::asio::placeholders::error,
-            boost::asio::placeholders::bytes_transferred));
+	pimpl->port.async_read_some(boost::asio::buffer(pimpl->readBuffer, sizeof(pimpl->readBuffer)), [this](auto &&err, auto bytes) { readEnd(err, bytes); });
 }
 
 void AsyncSerial::readEnd(const boost::system::error_code& error,
@@ -254,18 +251,15 @@ void AsyncSerial::readEnd(const boost::system::error_code& error,
 void AsyncSerial::doWrite()
 {
     //If a write operation is already in progress, do nothing
-    if(pimpl->writeBuffer==0)
+    if (pimpl->writeBuffer == nullptr)
     {
-        std::lock_guard<std::mutex> l(pimpl->writeQueueMutex);
-        pimpl->writeBufferSize=pimpl->writeQueue.size();
-        pimpl->writeBuffer.reset(new char[pimpl->writeQueue.size()]);
+	    std::lock_guard<std::mutex> l(pimpl->writeQueueMutex);
+	    pimpl->writeBufferSize = pimpl->writeQueue.size();
+	    pimpl->writeBuffer.reset(new char[pimpl->writeQueue.size()]);
 
-        copy(pimpl->writeQueue.begin(),pimpl->writeQueue.end(),
-                pimpl->writeBuffer.get());
-        pimpl->writeQueue.clear();
-        async_write(pimpl->port,boost::asio::buffer(pimpl->writeBuffer.get(),
-                pimpl->writeBufferSize),
-                boost::bind(&AsyncSerial::writeEnd, this, boost::asio::placeholders::error));
+	    copy(pimpl->writeQueue.begin(), pimpl->writeQueue.end(), pimpl->writeBuffer.get());
+	    pimpl->writeQueue.clear();
+	    async_write(pimpl->port, boost::asio::buffer(pimpl->writeBuffer.get(), pimpl->writeBufferSize), [this](auto &&err, auto) { writeEnd(err); });
     }
 }
 
@@ -286,9 +280,7 @@ void AsyncSerial::writeEnd(const boost::system::error_code& error)
         copy(pimpl->writeQueue.begin(),pimpl->writeQueue.end(),
                 pimpl->writeBuffer.get());
         pimpl->writeQueue.clear();
-        async_write(pimpl->port,boost::asio::buffer(pimpl->writeBuffer.get(),
-                pimpl->writeBufferSize),
-                boost::bind(&AsyncSerial::writeEnd, this, boost::asio::placeholders::error));
+	async_write(pimpl->port, boost::asio::buffer(pimpl->writeBuffer.get(), pimpl->writeBufferSize), [this](auto &&err, auto) { writeEnd(err); });
     } else {
 		try
 		{
@@ -317,7 +309,7 @@ void AsyncSerial::setErrorStatus(bool e)
     pimpl->error=e;
 }
 
-void AsyncSerial::setReadCallback(const boost::function<void (const char*, size_t)>& callback)
+void AsyncSerial::setReadCallback(const std::function<void(const char *, size_t)> &callback)
 {
     pimpl->callback=callback;
 }
@@ -327,7 +319,7 @@ void AsyncSerial::setReadCallback(const boost::function<void (const char*, size_
  */
 void AsyncSerial::clearReadCallback()
 {
-    pimpl->callback.clear();
+	pimpl->callback = {};
 }
 
 /**
