@@ -4,20 +4,21 @@
 
 class CDarkSky : public CDomoticzHardwareBase
 {
-public:
-	CDarkSky(const int ID, const std::string &APIKey, const std::string &Location);
-	~CDarkSky(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
+      public:
+	CDarkSky(int ID, const std::string &APIKey, const std::string &Location);
+	~CDarkSky() override = default;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
 	std::string GetForecastURL();
-private:
+
+      private:
 	void Init();
 	bool StartHardware() override;
 	bool StopHardware() override;
 	void Do_Work();
 	void GetMeterDetails();
-private:
+
+      private:
 	std::string m_APIKey;
 	std::string m_Location;
 	std::shared_ptr<std::thread> m_thread;
 };
-
