@@ -243,7 +243,7 @@ bool CDenkoviDevices::WriteToHardware(const char *pdata, const unsigned char /*l
 		}
 
 		std::string sResult;
-		if (!HTTPClient::GET(szURL.str(), sResult)) {
+		if (!dHttpGet(szURL.str(), sResult)) {
 			Log(LOG_ERROR, "%s: Error sending command to: %s",szDenkoviHardwareNames[m_iModel], m_szIPAddress.c_str());
 			return false;
 		}
@@ -270,7 +270,7 @@ bool CDenkoviDevices::WriteToHardware(const char *pdata, const unsigned char /*l
 		std::string sResult;
 
 		szURL << "http://" << sPass << "@" << m_szIPAddress << ":" << m_usIPPort << "/ioreg.js";
-		if (!HTTPClient::GET(szURL.str(), sResult)) {
+		if (!dHttpGet(szURL.str(), sResult)) {
 			Log(LOG_ERROR, "%s: Error sending command to: %s", m_szIPAddress.c_str(),szDenkoviHardwareNames[m_iModel]);
 			return false;
 		}
@@ -301,7 +301,7 @@ bool CDenkoviDevices::WriteToHardware(const char *pdata, const unsigned char /*l
 		sprintf(port3Val, "%02X", port3);
 		sprintf(port5Val, "%02X", port5);
 		szURL << "http://" << sPass << "@" << m_szIPAddress << ":" << m_usIPPort << "/iochange.cgi?ref=re-io&01=" << port3Val << "&02=" << port5Val;
-		if (!HTTPClient::GET(szURL.str(), sResult)) {
+		if (!dHttpGet(szURL.str(), sResult)) {
 			Log(LOG_ERROR, "%s: Error sending command to: %s!",szDenkoviHardwareNames[m_iModel], m_szIPAddress.c_str());
 			return false;
 		}		
@@ -323,13 +323,15 @@ bool CDenkoviDevices::WriteToHardware(const char *pdata, const unsigned char /*l
 		std::stringstream szURL;
 		std::string sResult;
 
+		//szURL << "http://" << sPass << "@" << m_szIPAddress << ":" << m_usIPPort << "/iochange.cgi?ref=re-io&01=FF&02=FF";
 		szURL << "http://" << sPass << "@" << m_szIPAddress << ":" << m_usIPPort << "/ioreg.js";
-		if (!HTTPClient::GET(szURL.str(), sResult)) {
+		if (!dHttpGet(szURL.str(), sResult)) {
 			Log(LOG_ERROR, "%s: Error sending command to: %s",szDenkoviHardwareNames[m_iModel], m_szIPAddress.c_str());
 			return false;
 		}
 		uint8_t port3 = DAEnetIP2GetIoPort(sResult, DAENETIP2_PORT_3_VAL);
 		uint8_t port5 = DAEnetIP2GetIoPort(sResult, DAENETIP2_PORT_5_VAL);
+		//Log(LOG_NORM, "P3=%u, P5=%u",port3,port5);
 		if (io < 9) { //DIO1 to DIO8 are from Port 3
 			if (command== light2_sOff)
 				port3 = port3 & (~(0x01 << (io - 1)));
@@ -354,12 +356,13 @@ bool CDenkoviDevices::WriteToHardware(const char *pdata, const unsigned char /*l
 		char port3Val[3], port5Val[3];
 		sprintf(port3Val, "%02X", port3);
 		sprintf(port5Val, "%02X", port5);
-		szURL << "http://" << sPass << "@" << m_szIPAddress << ":" << m_usIPPort << "/iochange.cgi?ref=re-io&01=" << port3Val << "&02=" << port5Val;
-		if (!HTTPClient::GET(szURL.str(), sResult)) {
+		szURL << "http://" << sPass << "@" << m_szIPAddress << ":" << m_usIPPort << "/iochange.cgi?ref=re-io&01=" << port3Val << "&02=" << port5Val;	
+		if (!dHttpGet(szURL.str(), sResult)) {
 			Log(LOG_ERROR, "%s: Error sending command to: %s",szDenkoviHardwareNames[m_iModel], m_szIPAddress.c_str());
 			return false;
 		}		
 		return true;
+		//return dHttpGet(szURL.str(), sResult);
 	}
 	case DDEV_DAEnet_IP3: {
 		//int ioType = pSen->id;
@@ -391,7 +394,7 @@ bool CDenkoviDevices::WriteToHardware(const char *pdata, const unsigned char /*l
 			return false;
 		}
 		std::string sResult;
-		if (!HTTPClient::GET(szURL.str(), sResult)) {
+		if (!dHttpGet(szURL.str(), sResult)) {
 			Log(LOG_ERROR, "%s: Error sending command to: %s",szDenkoviHardwareNames[m_iModel], m_szIPAddress.c_str());
 			return false;
 		}
@@ -445,7 +448,7 @@ bool CDenkoviDevices::WriteToHardware(const char *pdata, const unsigned char /*l
 		else
 			szURL << "1";
 		std::string sResult;
-		if (!HTTPClient::GET(szURL.str(), sResult)) {
+		if (!dHttpGet(szURL.str(), sResult)) {
 			Log(LOG_ERROR, "%s Error sending command to: %s!",szDenkoviHardwareNames[m_iModel], m_szIPAddress.c_str());
 			return false;
 		}
@@ -486,7 +489,7 @@ bool CDenkoviDevices::WriteToHardware(const char *pdata, const unsigned char /*l
 		else
 			szURL << "1";
 		std::string sResult;
-		if (!HTTPClient::GET(szURL.str(), sResult)) {
+		if (!dHttpGet(szURL.str(), sResult)) {
 			Log(LOG_ERROR, "%s: Error sending command to: %s!",szDenkoviHardwareNames[m_iModel], m_szIPAddress.c_str());
 			return false;
 		}
@@ -528,7 +531,7 @@ bool CDenkoviDevices::WriteToHardware(const char *pdata, const unsigned char /*l
 			return false;
 		}
 		std::string sResult;
-		if (!HTTPClient::GET(szURL.str(), sResult))
+		if (!dHttpGet(szURL.str(), sResult))
 		{
 			Log(LOG_ERROR, "%s: Error sending relay command to: %s!",szDenkoviHardwareNames[m_iModel], m_szIPAddress.c_str());			 
 			return false;
@@ -697,7 +700,15 @@ void CDenkoviDevices::SendDenkoviTextSensor(const int NodeID, const int ChildID,
 		SendTextSensor(NodeID, ChildID, BatteryLevel, textMessage, defaultname);
 }
 
-
+bool CDenkoviDevices::dHttpGet(const std::string &url, std::string &sResult)
+{
+	for (int ii=0; ii<3; ii++)
+	{
+		//Log(LOG_NORM,"Retry: %u",ii);
+		if (HTTPClient::GET(url, sResult)) return true;
+	}
+	return false;
+}
 
 void CDenkoviDevices::GetMeterDetails()
 {
@@ -738,7 +749,7 @@ void CDenkoviDevices::GetMeterDetails()
 			szURL << "?pw=" << m_Password;
 	}
 
-	if (!HTTPClient::GET(szURL.str(), sResult) || (m_iModel == DDEV_DAEnet_IP3 && !HTTPClient::GET(szURL2.str(), sResult2)))
+	if (!dHttpGet(szURL.str(), sResult) || (m_iModel == DDEV_DAEnet_IP3 && !dHttpGet(szURL2.str(), sResult2)))
 	{
 		Log(LOG_ERROR, "%s: Error connecting to: %s!",szDenkoviHardwareNames[m_iModel], m_szIPAddress.c_str()); 
 		return;
