@@ -3,7 +3,6 @@
 #include "ASyncTCP.h"
 #include "DomoticzHardware.h"
 
-
 #define MAX_EC3K_METERS 64
 #define EC3K_UPDATE_INTERVAL 60
 
@@ -16,27 +15,29 @@ typedef struct {
 
 class Ec3kLimiter
 {
-public:
-  Ec3kLimiter();
-  ~Ec3kLimiter();
-  bool update(int id);
+      public:
+	Ec3kLimiter();
+	~Ec3kLimiter() = default;
+	bool update(int id);
 
-private:
-  int no_meters;
-  struct {
-	int id;
-	time_t last_update;
+      private:
+	int no_meters;
+	struct
+	{
+		int id;
+		time_t last_update;
 	} meters[MAX_EC3K_METERS];
 };
 
 class Ec3kMeterTCP : public CDomoticzHardwareBase, ASyncTCP
 {
-public:
-	Ec3kMeterTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort);
-	~Ec3kMeterTCP(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-	boost::signals2::signal<void()>	sDisconnected;
-private:
+      public:
+	Ec3kMeterTCP(int ID, const std::string &IPAddress, unsigned short usIPPort);
+	~Ec3kMeterTCP() override = default;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+	boost::signals2::signal<void()> sDisconnected;
+
+      private:
 	bool StartHardware() override;
 	bool StopHardware() override;
 	void Do_Work();
@@ -45,8 +46,9 @@ private:
 	void OnConnect() override;
 	void OnDisconnect() override;
 	void OnData(const unsigned char *pData, size_t length) override;
-	void OnError(const boost::system::error_code& error) override;
-private:
+	void OnError(const boost::system::error_code &error) override;
+
+      private:
 	int m_retrycntr;
 	Ec3kLimiter *m_limiter;
 	std::string m_szIPAddress;
@@ -54,4 +56,3 @@ private:
 
 	std::shared_ptr<std::thread> m_thread;
 };
-
