@@ -5,15 +5,16 @@
 
 class FritzboxTCP : public CDomoticzHardwareBase, ASyncTCP
 {
-public:
-	FritzboxTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort);
-	~FritzboxTCP(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-	boost::signals2::signal<void()>	sDisconnected;
-private:
+      public:
+	FritzboxTCP(int ID, const std::string &IPAddress, unsigned short usIPPort);
+	~FritzboxTCP() override = default;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+	boost::signals2::signal<void()> sDisconnected;
+
+      private:
 	bool StartHardware() override;
 	bool StopHardware() override;
-	void UpdateSwitch(const unsigned char Idx, const uint8_t SubUnit, const bool bOn, const double Level, const std::string &defaultname);
+	void UpdateSwitch(unsigned char Idx, uint8_t SubUnit, bool bOn, double Level, const std::string &defaultname);
 	void WriteInt(const std::string &sendStr);
 	void Do_Work();
 	void ParseData(const unsigned char *pData, int Len);
@@ -22,8 +23,9 @@ private:
 	void OnConnect() override;
 	void OnDisconnect() override;
 	void OnData(const unsigned char *pData, size_t length) override;
-	void OnError(const boost::system::error_code& error) override;
-private:
+	void OnError(const boost::system::error_code &error) override;
+
+      private:
 	int m_retrycntr;
 	std::string m_szIPAddress;
 	unsigned short m_usIPPort;
@@ -31,4 +33,3 @@ private:
 	std::shared_ptr<std::thread> m_thread;
 	unsigned char m_buffer[1024];
 };
-
