@@ -10,26 +10,15 @@
 #include <sstream>
 #include <algorithm>
 #include <iostream>
-#include <boost/bind.hpp>
-
 #include <ctime>
 
 #define round(a) ( int ) ( a + .5 )
 
-
-KMTronicBase::KMTronicBase(void)
+KMTronicBase::KMTronicBase()
 {
 	m_bufferpos = 0;
 	m_TotRelais = 0;
-	for (int ii = 0; ii < Max_KMTronic_Relais; ii++)
-	{
-		m_bRelaisStatus[ii] = false;
-	}
-}
-
-
-KMTronicBase::~KMTronicBase(void)
-{
+	m_bRelaisStatus = {};
 }
 
 void KMTronicBase::ParseData(const unsigned char *pData, int Len)
