@@ -10,7 +10,6 @@
 #include <string>
 #include <algorithm>
 #include <iostream>
-#include <boost/bind.hpp>
 #include <boost/exception/diagnostic_information.hpp>
 #include <ctime>
 
@@ -28,11 +27,6 @@ KMTronicSerial::KMTronicSerial(const int ID, const std::string& devname)
 	m_bHaveReceived = false;
 }
 
-KMTronicSerial::~KMTronicSerial()
-{
-
-}
-
 bool KMTronicSerial::StartHardware()
 {
 	RequestStart();
@@ -44,7 +38,7 @@ bool KMTronicSerial::StartHardware()
 
 	//Start worker thread
 	m_bIsStarted = true;
-	m_thread = std::make_shared<std::thread>(&KMTronicSerial::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	return (m_thread != nullptr);
 }
@@ -65,20 +59,20 @@ void KMTronicSerial::Do_Work()
 {
 	int sec_counter = 0;
 
-	_log.Log(LOG_STATUS, "KMTronic: Worker started...");
+	Log(LOG_STATUS, "Worker started...");
 
 	while (!IsStopRequested(1000))
 	{
 		sec_counter++;
 		if (sec_counter % 12 == 0) {
-			m_LastHeartbeat=mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if (!isOpen())
 		{
 			if (m_retrycntr == 0)
 			{
-				_log.Log(LOG_STATUS, "KMTronic: retrying in %d seconds...", RETRY_DELAY);
+				Log(LOG_STATUS, "retrying in %d seconds...", RETRY_DELAY);
 			}
 			m_retrycntr++;
 			if (m_retrycntr >= RETRY_DELAY)
@@ -93,7 +87,7 @@ void KMTronicSerial::Do_Work()
 	}
 	terminate();
 
-	_log.Log(LOG_STATUS, "KMTronic: Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 bool KMTronicSerial::OpenSerialDevice()
@@ -101,7 +95,7 @@ bool KMTronicSerial::OpenSerialDevice()
 	//Try to open the Serial Port
 	try
 	{
-		_log.Log(LOG_STATUS, "KMTronic: Using serial port: %s", m_szSerialPort.c_str());
+		Log(LOG_STATUS, "Using serial port: %s", m_szSerialPort.c_str());
 #ifndef WIN32
 		openOnlyBaud(
 			m_szSerialPort,
@@ -120,9 +114,9 @@ bool KMTronicSerial::OpenSerialDevice()
 	}
 	catch (boost::exception & e)
 	{
-		_log.Log(LOG_ERROR, "KMTronic: Error opening serial port!");
+		Log(LOG_ERROR, "Error opening serial port!");
 #ifdef _DEBUG
-		_log.Log(LOG_ERROR, "-----------------\n%s\n-----------------", boost::diagnostic_information(e).c_str());
+		Log(LOG_ERROR, "-----------------\n%s\n-----------------", boost::diagnostic_information(e).c_str());
 #else
 		(void)e;
 #endif
@@ -130,12 +124,12 @@ bool KMTronicSerial::OpenSerialDevice()
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "KMTronic: Error opening serial port!!!");
+		Log(LOG_ERROR, "Error opening serial port!!!");
 		return false;
 	}
 	m_bIsStarted = true;
 	m_bufferpos = 0;
-	setReadCallback(boost::bind(&KMTronicSerial::readCallback, this, _1, _2));
+	setReadCallback([this](auto d, auto l) { readCallback(d, l); });
 	sOnConnected(this);
 	return true;
 }
@@ -204,8 +198,8 @@ void KMTronicSerial::GetRelayStates()
 					std::stringstream sstr;
 					int iRelay = (iBoard * 8) + ii + 1;
 					sstr << "Board" << int(iBoard + 1) << " - " << int(ii + 1);
-					SendSwitch(iRelay, 1, 255, bIsOn, 0, sstr.str());
-					_log.Debug(DEBUG_HARDWARE, "KMTronic: %s = %s", sstr.str().c_str(), (bIsOn) ? "On" : "Off");
+					SendSwitch(iRelay, 1, 255, bIsOn, 0, sstr.str(), m_Name);
+					Debug(DEBUG_HARDWARE, "%s = %s", sstr.str().c_str(), (bIsOn) ? "On" : "Off");
 					if (iRelay > m_TotRelais)
 						m_TotRelais = iRelay;
 				}
@@ -240,8 +234,8 @@ void KMTronicSerial::GetRelayStates()
 			std::stringstream sstr;
 			int iRelay = (ii + 1);
 			sstr << "Relay " << iRelay;
-			SendSwitch(iRelay, 1, 255, bIsOn, 0, sstr.str());
-			_log.Debug(DEBUG_HARDWARE, "KMTronic: %s = %s", sstr.str().c_str(), (bIsOn) ? "On" : "Off");
+			SendSwitch(iRelay, 1, 255, bIsOn, 0, sstr.str(), m_Name);
+			Debug(DEBUG_HARDWARE, "%s = %s", sstr.str().c_str(), (bIsOn) ? "On" : "Off");
 			if (iRelay > m_TotRelais)
 				m_TotRelais = iRelay;
 		}
@@ -268,15 +262,15 @@ void KMTronicSerial::GetRelayStates()
 					std::stringstream sstr;
 					int iRelay = ii + 1;
 					sstr << "Relay " << iRelay;
-					SendSwitch(iRelay, 1, 255, bIsOn, 0, sstr.str());
-					_log.Log(LOG_STATUS, "KMTronic: %s = %s", sstr.str().c_str(), (bIsOn) ? "On" : "Off");
+					SendSwitch(iRelay, 1, 255, bIsOn, 0, sstr.str(), m_Name);
+					Log(LOG_STATUS, "%s = %s", sstr.str().c_str(), (bIsOn) ? "On" : "Off");
 					if (iRelay > m_TotRelais)
 						m_TotRelais = iRelay;
 				}
 			}
 			else
 			{
-				_log.Log(LOG_ERROR, "KMTronic: Invalid data received!");
+				Log(LOG_ERROR, "Invalid data received!");
 			}
 		}
 	}
