@@ -43,10 +43,6 @@ m_Password(CURLEncode::URLEncode(password))
 	m_bIsTempDevice = false;
 }
 
-KMTronicTCP::~KMTronicTCP(void)
-{
-}
-
 void KMTronicTCP::Init()
 {
 }
@@ -57,7 +53,7 @@ bool KMTronicTCP::StartHardware()
 
 	Init();
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&KMTronicTCP::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 	sOnConnected(this);
@@ -79,12 +75,12 @@ bool KMTronicTCP::StopHardware()
 void KMTronicTCP::Do_Work()
 {
 	int sec_counter = KMTRONIC_POLL_INTERVAL - 2;
-	_log.Log(LOG_STATUS, "KMTronic: TCP/IP Worker started...");
+	Log(LOG_STATUS, "TCP/IP Worker started...");
 	while (!IsStopRequested(1000))
 	{
 		sec_counter++;
 		if (sec_counter % 12 == 0) {
-			m_LastHeartbeat=mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		int iPollInterval = KMTRONIC_POLL_INTERVAL;
@@ -97,7 +93,7 @@ void KMTronicTCP::Do_Work()
 			GetMeterDetails();
 		}
 	}
-	_log.Log(LOG_STATUS, "KMTronic: TCP/IP Worker stopped...");
+	Log(LOG_STATUS, "TCP/IP Worker stopped...");
 }
 
 bool KMTronicTCP::WriteToHardware(const char *pdata, const unsigned char /*length*/)
@@ -141,7 +137,7 @@ bool KMTronicTCP::WriteToHardware(const char *pdata, const unsigned char /*lengt
 		std::string sResult;
 		if (!HTTPClient::GET(szURL.str(), sResult,true))
 		{
-			_log.Log(LOG_ERROR, "KMTronic: Error sending relay command to: %s", m_szIPAddress.c_str());
+			Log(LOG_ERROR, "Error sending relay command to: %s", m_szIPAddress.c_str());
 			return false;
 		}
 		return true;
@@ -195,7 +191,7 @@ void KMTronicTCP::GetMeterDetails()
 		}
 		if (sResult.empty())
 		{
-			_log.Log(LOG_ERROR, "KMTronic: Error connecting to: %s", m_szIPAddress.c_str());
+			Log(LOG_ERROR, "Error connecting to: %s", m_szIPAddress.c_str());
 			return;
 		}
 	}
@@ -215,7 +211,7 @@ void KMTronicTCP::ParseRelays(const std::string &sResult)
 	StringSplit(sResult, "\r\n", results);
 	if (results.size() < 8)
 	{
-		_log.Log(LOG_ERROR, "KMTronic: Invalid data received");
+		Log(LOG_ERROR, "Invalid data received");
 		return;
 	}
 	size_t ii, jj;
@@ -233,14 +229,14 @@ void KMTronicTCP::ParseRelays(const std::string &sResult)
 				std::stringstream sstr;
 				int iRelay = (jj + 1);
 				sstr << "Relay " << iRelay;
-				SendSwitch(iRelay, 1, 255, bIsOn, 0, sstr.str());
+				SendSwitch(iRelay, 1, 255, bIsOn, 0, sstr.str(), m_Name);
 				if (iRelay > m_TotRelais)
 					m_TotRelais = iRelay;
 			}
 			return;
 		}
 	}
-	_log.Log(LOG_ERROR, "KMTronic: Invalid data received");
+	Log(LOG_ERROR, "Invalid data received");
 }
 
 void KMTronicTCP::ParseTemps(const std::string &sResult)
@@ -249,7 +245,7 @@ void KMTronicTCP::ParseTemps(const std::string &sResult)
 	StringSplit(sResult, "\r\n", results);
 	if (results.size() < 8)
 	{
-		_log.Log(LOG_ERROR, "KMTronic: Invalid data received");
+		Log(LOG_ERROR, "Invalid data received");
 		return;
 	}
 	size_t ii;
