@@ -4,22 +4,24 @@
 
 class KMTronicTCP : public KMTronicBase
 {
-public:
-	KMTronicTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort, const std::string &username, const std::string &password);
-	~KMTronicTCP(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-	boost::signals2::signal<void()>	sDisconnected;
-private:
+      public:
+	KMTronicTCP(int ID, const std::string &IPAddress, unsigned short usIPPort, const std::string &username, const std::string &password);
+	~KMTronicTCP() override = default;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+	boost::signals2::signal<void()> sDisconnected;
+
+      private:
 	bool StartHardware() override;
 	bool StopHardware() override;
 	void ParseRelays(const std::string &sResult);
 	void ParseTemps(const std::string &sResult);
-	std::string GenerateURL(const bool bIsTempDevice);
-	bool WriteInt(const unsigned char *data, const size_t len, const bool bWaitForReturn) override;
+	std::string GenerateURL(bool bIsTempDevice);
+	bool WriteInt(const unsigned char *data, size_t len, bool bWaitForReturn) override;
 	void Init();
 	void GetMeterDetails();
 	void Do_Work();
-private:
+
+      private:
 	std::string m_szIPAddress;
 	unsigned short m_usIPPort;
 	std::string m_Username;
@@ -28,4 +30,3 @@ private:
 	bool m_bCheckedForTempDevice;
 	bool m_bIsTempDevice;
 };
-
