@@ -583,7 +583,7 @@ void CKodiNode::handleConnect()
 			boost::system::error_code ec;
 			boost::asio::ip::tcp::resolver resolver(*m_Ios);
 			boost::asio::ip::tcp::resolver::query query(m_IP, (m_Port[0] != '-' ? m_Port : m_Port.substr(1)));
-			boost::asio::ip::tcp::resolver::iterator iter = resolver.resolve(query);
+			auto iter = resolver.resolve(query);
 			boost::asio::ip::tcp::endpoint endpoint = *iter;
 			m_Socket = new boost::asio::ip::tcp::socket(*m_Ios);
 			m_Socket->connect(endpoint, ec);
