@@ -11,11 +11,11 @@
 #include "../notifications/NotificationHelper.h"
 #include "../httpclient/HTTPClient.h"
 
-CLogitechMediaServer::CLogitechMediaServer(const int ID, const std::string &IPAddress, const int Port, const std::string &User, const std::string &Pwd, const int PollIntervalsec) :
-	m_IP(IPAddress),
-	m_User(User),
-	m_Pwd(Pwd),
-	m_iThreadsRunning(0)
+CLogitechMediaServer::CLogitechMediaServer(const int ID, const std::string &IPAddress, const int Port, const std::string &User, const std::string &Pwd, const int PollIntervalsec)
+	: m_iThreadsRunning(0)
+	, m_IP(IPAddress)
+	, m_User(User)
+	, m_Pwd(Pwd)
 {
 	m_HwdID = ID;
 	m_Port = Port;
@@ -45,7 +45,7 @@ CLogitechMediaServer::CLogitechMediaServer(const int ID) :
 	SetSettings(10);
 }
 
-CLogitechMediaServer::~CLogitechMediaServer(void)
+CLogitechMediaServer::~CLogitechMediaServer()
 {
 	m_bIsStarted = false;
 }
@@ -58,7 +58,7 @@ Json::Value CLogitechMediaServer::Query(const std::string &sIP, const int iPort,
 	std::stringstream sURL;
 	std::stringstream sPostData;
 
-	if ((m_User != "") && (m_Pwd != ""))
+	if ((!m_User.empty()) && (!m_Pwd.empty()))
 		sURL << "http://" << m_User << ":" << m_Pwd << "@" << sIP << ":" << iPort << "/jsonrpc.js";
 	else
 		sURL << "http://" << sIP << ":" << iPort << "/jsonrpc.js";
@@ -77,14 +77,14 @@ Json::Value CLogitechMediaServer::Query(const std::string &sIP, const int iPort,
 	{
 		size_t aFind = sResult.find("401 Authorization Required");
 		if ((aFind > 0) && (aFind != std::string::npos))
-			_log.Log(LOG_ERROR, "Logitech Media Server: Username and/or password are incorrect. Check Logitech Media Server settings.");
+			Log(LOG_ERROR, "Username and/or password are incorrect. Check Logitech Media Server settings.");
 		else
-			_log.Log(LOG_ERROR, "Logitech Media Server: PARSE ERROR: %s", sResult.c_str());
+			Log(LOG_ERROR, "PARSE ERROR: %s", sResult.c_str());
 		return root;
 	}
 	if (root["method"].empty())
 	{
-		_log.Log(LOG_ERROR, "Logitech Media Server: '%s' request '%s'", sURL.str().c_str(), sPostData.str().c_str());
+		Log(LOG_ERROR, "'%s' request '%s'", sURL.str().c_str(), sPostData.str().c_str());
 		return root;
 	}
 	return root["result"];
@@ -117,7 +117,7 @@ bool CLogitechMediaServer::StartHardware()
 	StartHeartbeatThread();
 
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CLogitechMediaServer::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 
 	return (m_thread != nullptr);
@@ -142,52 +142,57 @@ void CLogitechMediaServer::UpdateNodeStatus(const LogitechMediaServerNode &Node,
 	//This has to be rebuild! No direct poking in the database, please use CMainWorker::UpdateDevice
 
 	//Find out node, and update it's status
-	std::vector<LogitechMediaServerNode>::iterator itt;
-	for (itt = m_nodes.begin(); itt != m_nodes.end(); ++itt)
+	for (auto &node : m_nodes)
 	{
-		if (itt->ID == Node.ID)
+		if (node.ID == Node.ID)
 		{
 			//Found it
 			//Retrieve devicename instead of playername in case it was renamed...
-			std::string sDevName = itt->Name;
+			std::string sDevName = node.Name;
 			std::vector<std::vector<std::string> > result;
-			result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE DeviceID=='%q'", itt->szDevID);
+			result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE DeviceID=='%q'", node.szDevID);
 			if (result.size() == 1) {
 				std::vector<std::string> sd = result[0];
 				sDevName = sd[0];
 			}
 			bool	bUseOnOff = false;
 			if (((nStatus == MSTAT_OFF) && bPingOK) || ((nStatus != MSTAT_OFF) && !bPingOK)) bUseOnOff = true;
-			time_t atime = mytime(NULL);
-			itt->LastOK = atime;
-			if ((itt->nStatus != nStatus) || (itt->sStatus != sStatus))
+			time_t atime = mytime(nullptr);
+			node.LastOK = atime;
+			if ((node.nStatus != nStatus) || (node.sStatus != sStatus))
 			{
 				// 1:	Update the DeviceStatus
 				if ((nStatus == MSTAT_PLAYING) || (nStatus == MSTAT_PAUSED) || (nStatus == MSTAT_STOPPED))
-					_log.Log(LOG_NORM, "Logitech Media Server: (%s) %s - '%s'", Node.Name.c_str(), Media_Player_States(nStatus), sStatus.c_str());
+					Log(LOG_NORM, "(%s) %s - '%s'", Node.Name.c_str(), Media_Player_States(nStatus), sStatus.c_str());
 				else
-					_log.Log(LOG_NORM, "Logitech Media Server: (%s) %s", Node.Name.c_str(), Media_Player_States(nStatus));
+					Log(LOG_NORM, "(%s) %s", Node.Name.c_str(), Media_Player_States(nStatus));
 				struct tm ltime;
 				localtime_r(&atime, &ltime);
 				char szLastUpdate[40];
 				sprintf(szLastUpdate, "%04d-%02d-%02d %02d:%02d:%02d", ltime.tm_year + 1900, ltime.tm_mon + 1, ltime.tm_mday, ltime.tm_hour, ltime.tm_min, ltime.tm_sec);
-				result = m_sql.safe_query("UPDATE DeviceStatus SET nValue=%d, sValue='%q', LastUpdate='%q' WHERE (HardwareID == %d) AND (DeviceID == '%q') AND (Unit == 1) AND (SwitchType == %d)",
-					int(nStatus), sStatus.c_str(), szLastUpdate, m_HwdID, itt->szDevID, STYPE_Media);
+				result = m_sql.safe_query("UPDATE DeviceStatus SET nValue=%d, sValue='%q', "
+							  "LastUpdate='%q' WHERE (HardwareID == %d) AND (DeviceID == "
+							  "'%q') AND (Unit == 1) AND (SwitchType == %d)",
+							  int(nStatus), sStatus.c_str(), szLastUpdate, m_HwdID, node.szDevID, STYPE_Media);
 
 				// 2:	Log the event if the actual status has changed
-				std::string sShortStatus = sStatus;
-				if ((itt->nStatus != nStatus) || (itt->sShortStatus != sShortStatus))
+				const std::string &sShortStatus = sStatus;
+				if ((node.nStatus != nStatus) || (node.sShortStatus != sShortStatus))
 				{
 					std::string sLongStatus = Media_Player_States(nStatus);
 					if ((nStatus == MSTAT_PLAYING) || (nStatus == MSTAT_PAUSED) || (nStatus == MSTAT_STOPPED))
 						if (sShortStatus.length()) sLongStatus += " - " + sShortStatus;
-					result = m_sql.safe_query("INSERT INTO LightingLog (DeviceRowID, nValue, sValue, User) VALUES (%d, %d, '%q','%q')", itt->ID, int(nStatus), sLongStatus.c_str(), "Logitech");
+					result = m_sql.safe_query("INSERT INTO LightingLog (DeviceRowID, nValue, sValue, "
+								  "User) VALUES (%d, %d, '%q','%q')",
+								  node.ID, int(nStatus), sLongStatus.c_str(), "Logitech");
 				}
 
 				// 3:	Trigger On/Off actions
 				if (bUseOnOff)
 				{
-					result = m_sql.safe_query("SELECT StrParam1,StrParam2 FROM DeviceStatus WHERE (HardwareID==%d) AND (ID = '%q') AND (Unit == 1)", m_HwdID, itt->szDevID);
+					result = m_sql.safe_query("SELECT StrParam1,StrParam2 FROM DeviceStatus WHERE "
+								  "(HardwareID==%d) AND (ID = '%q') AND (Unit == 1)",
+								  m_HwdID, node.szDevID);
 					if (!result.empty())
 					{
 						m_sql.HandleOnOffAction(bPingOK, result[0][0], result[0][1]);
@@ -195,15 +200,16 @@ void CLogitechMediaServer::UpdateNodeStatus(const LogitechMediaServerNode &Node,
 				}
 
 				// 4:   Trigger Notifications & events on status change
-				if (itt->nStatus != nStatus)
+				if (node.nStatus != nStatus)
 				{
-					m_notifications.CheckAndHandleNotification(itt->ID, sDevName, NotificationType(nStatus), sStatus.c_str());
-					m_mainworker.m_eventsystem.ProcessDevice(m_HwdID, itt->ID, 1, int(pTypeLighting2), int(sTypeAC), 12, 100, int(nStatus), sStatus.c_str(), sDevName);
+					m_notifications.CheckAndHandleNotification(node.ID, sDevName, NotificationType(nStatus), sStatus);
+					m_mainworker.m_eventsystem.ProcessDevice(m_HwdID, node.ID, 1, int(pTypeLighting2), int(sTypeAC), 12,
+										 100, int(nStatus), sStatus.c_str());
 				}
 
-				itt->nStatus = nStatus;
-				itt->sStatus = sStatus;
-				itt->sShortStatus = sShortStatus;
+				node.nStatus = nStatus;
+				node.sStatus = sStatus;
+				node.sShortStatus = sShortStatus;
 			}
 			break;
 		}
@@ -216,11 +222,11 @@ void CLogitechMediaServer::Do_Node_Work(const LogitechMediaServerNode &Node)
 	_eMediaStatus nStatus = MSTAT_UNKNOWN;
 	_eMediaStatus nOldStatus = Node.nStatus;
 	std::string	sPlayerId = Node.IP;
-	std::string	sStatus = "";
+	std::string sStatus;
 
 	try
 	{
-		std::string sPostdata = "{\"id\":1,\"method\":\"slim.request\",\"params\":[\"" + sPlayerId + "\",[\"status\",\"-\",1,\"tags:Aadly\"]]}";
+		std::string sPostdata = R"({"id":1,"method":"slim.request","params":[")" + sPlayerId + R"(",["status","-",1,"tags:Aadly"]]})";
 		Json::Value root = Query(m_IP, m_Port, sPostdata);
 
 		if (root.isNull())
@@ -252,16 +258,17 @@ void CLogitechMediaServer::Do_Node_Work(const LogitechMediaServerNode &Node)
 							nStatus = MSTAT_STOPPED;
 					else
 						nStatus = MSTAT_ON;
-					std::string	sTitle = "";
-					std::string	sAlbum = "";
-					std::string	sArtist = "";
-					std::string	sAlbumArtist = "";
-					std::string	sTrackArtist = "";
-					std::string	sYear = "";
-					std::string	sDuration = "";
-					std::string sLabel = "";
+					std::string sTitle;
+					std::string sAlbum;
+					std::string sArtist;
+					std::string sAlbumArtist;
+					std::string sTrackArtist;
+					std::string sYear;
+					std::string sDuration;
+					std::string sLabel;
 
-					if (root["playlist_loop"].size()) {
+					if (!root["playlist_loop"].empty())
+					{
 						sTitle = root["playlist_loop"][0]["title"].asString();
 						sAlbum = root["playlist_loop"][0]["album"].asString();
 						sArtist = root["playlist_loop"][0]["artist"].asString();
@@ -270,13 +277,12 @@ void CLogitechMediaServer::Do_Node_Work(const LogitechMediaServerNode &Node)
 						sYear = root["playlist_loop"][0]["year"].asString();
 						sDuration = root["playlist_loop"][0]["duration"].asString();
 
-						if (sTrackArtist != "")
+						if (!sTrackArtist.empty())
 							sArtist = sTrackArtist;
-						else
-							if (sAlbumArtist != "")
-								sArtist = sAlbumArtist;
+						else if (!sAlbumArtist.empty())
+							sArtist = sAlbumArtist;
 						if (sYear == "0") sYear = "";
-						if (sYear != "")
+						if (!sYear.empty())
 							sYear = " (" + sYear + ")";
 
 						sLabel = sArtist + " - " + sTitle + sYear;
@@ -305,7 +311,7 @@ void CLogitechMediaServer::Do_Work()
 	int scounter = 0;
 	bool bFirstTime = true;
 
-	_log.Log(LOG_STATUS, "Logitech Media Server: Worker started...");
+	Log(LOG_STATUS, "Worker started...");
 
 	ReloadNodes();
 	ReloadPlaylists();
@@ -329,15 +335,14 @@ void CLogitechMediaServer::Do_Work()
 
 				GetPlayerInfo();
 
-				std::vector<LogitechMediaServerNode>::const_iterator itt;
-				for (itt = m_nodes.begin(); itt != m_nodes.end(); ++itt)
+				for (const auto &node : m_nodes)
 				{
 					if (IsStopRequested(0))
 						return;
 					if (m_iThreadsRunning < 1000)
 					{
 						m_iThreadsRunning++;
-						boost::thread t(boost::bind(&CLogitechMediaServer::Do_Node_Work, this, *itt));
+						boost::thread t([this, node] { Do_Node_Work(node); });
 						SetThreadName(t.native_handle(), "LogitechNode");
 						t.join();
 					}
@@ -351,20 +356,20 @@ void CLogitechMediaServer::Do_Work()
 		sleep_milliseconds(150);
 	}
 
-	_log.Log(LOG_STATUS, "Logitech Media Server: Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 void CLogitechMediaServer::GetPlayerInfo()
 {
 	try
 	{
-		std::string sPostdata = "{\"id\":1,\"method\":\"slim.request\",\"params\":[\"\",[\"serverstatus\",0,999]]}";
+		std::string sPostdata = R"({"id":1,"method":"slim.request","params":["",["serverstatus",0,999]]})";
 		Json::Value root = Query(m_IP, m_Port, sPostdata);
 
 		if (root.isNull()) {
 			m_iMissedQueries++;
 			if (m_iMissedQueries % 3 == 0) {
-				_log.Log(LOG_ERROR, "Logitech Media Server: No response from server %s:%i", m_IP.c_str(), m_Port);
+				Log(LOG_ERROR, "No response from server %s:%i", m_IP.c_str(), m_Port);
 			}
 		}
 		else {
@@ -374,7 +379,7 @@ void CLogitechMediaServer::GetPlayerInfo()
 			int totPlayers = root["player count"].asInt();
 			if (totPlayers > 0) {
 				if (!m_bShowedStartupMessage)
-					_log.Log(LOG_STATUS, "Logitech Media Server: %i connected player(s) found.", totPlayers);
+					Log(LOG_STATUS, "%i connected player(s) found.", totPlayers);
 				for (int ii = 0; ii < totPlayers; ii++)
 				{
 					if (root["players_loop"][ii]["name"].empty())
@@ -416,13 +421,13 @@ void CLogitechMediaServer::GetPlayerInfo()
 					}
 					else {
 						if (!m_bShowedStartupMessage)
-							_log.Log(LOG_ERROR, "Logitech Media Server: model '%s' not supported.", model.c_str());
+							Log(LOG_ERROR, "model '%s' not supported.", model.c_str());
 					}
 				}
 			}
 			else {
 				if (!m_bShowedStartupMessage)
-					_log.Log(LOG_ERROR, "Logitech Media Server: No connected players found.");
+					Log(LOG_ERROR, "No connected players found.");
 			}
 			m_bShowedStartupMessage = true;
 		}
@@ -440,9 +445,10 @@ void CLogitechMediaServer::UpsertPlayer(const std::string &Name, const std::stri
 	//1) Check on MacAddress (default)
 	result = m_sql.safe_query("SELECT Name FROM WOLNodes WHERE (HardwareID==%d) AND (MacAddress=='%q')", m_HwdID, MacAddress.c_str());
 	if (!result.empty()) {
-		if (result[0][0].c_str() != Name) { //Update Name in case it has been changed
+		if (result[0][0] != Name)
+		{ // Update Name in case it has been changed
 			m_sql.safe_query("UPDATE WOLNodes SET Name='%q', Timeout=0 WHERE (HardwareID==%d) AND (MacAddress=='%q')", Name.c_str(), m_HwdID, MacAddress.c_str());
-			_log.Log(LOG_STATUS, "Logitech Media Server: Player '%s' renamed to '%s'", result[0][0].c_str(), Name.c_str());
+			Log(LOG_STATUS, "Player '%s' renamed to '%s'", result[0][0].c_str(), Name.c_str());
 		}
 		else { //Mark device as 'Active'
 			m_sql.safe_query("UPDATE WOLNodes SET Timeout=0 WHERE (HardwareID==%d) AND (MacAddress=='%q')", m_HwdID, MacAddress.c_str());
@@ -454,7 +460,7 @@ void CLogitechMediaServer::UpsertPlayer(const std::string &Name, const std::stri
 	result = m_sql.safe_query("SELECT ID FROM WOLNodes WHERE (HardwareID==%d) AND (Name=='%q') AND (MacAddress=='%q')", m_HwdID, Name.c_str(), IPAddress.c_str());
 	if (!result.empty()) {
 		m_sql.safe_query("UPDATE WOLNodes SET MacAddress='%q', Timeout=0 WHERE (HardwareID==%d) AND (Name=='%q') AND (MacAddress=='%q')", MacAddress.c_str(), m_HwdID, Name.c_str(), IPAddress.c_str());
-		_log.Log(LOG_STATUS, "Logitech Media Server: Player '%s' IP changed to MacAddress", Name.c_str());
+		Log(LOG_STATUS, "Player '%s' IP changed to MacAddress", Name.c_str());
 		return;
 	}
 
@@ -462,7 +468,7 @@ void CLogitechMediaServer::UpsertPlayer(const std::string &Name, const std::stri
 	result = m_sql.safe_query("SELECT ID FROM WOLNodes WHERE (HardwareID==%d) AND (Name=='%q')", m_HwdID, Name.c_str());
 	if (!result.empty()) {
 		m_sql.safe_query("UPDATE WOLNodes SET MacAddress='%q', Timeout=0 WHERE (HardwareID==%d) AND (Name=='%q')", MacAddress.c_str(), m_HwdID, Name.c_str());
-		_log.Log(LOG_STATUS, "Logitech Media Server: Player '%s' IP changed to MacAddress", Name.c_str());
+		Log(LOG_STATUS, "Player '%s' IP changed to MacAddress", Name.c_str());
 		return;
 	}
 
@@ -470,13 +476,13 @@ void CLogitechMediaServer::UpsertPlayer(const std::string &Name, const std::stri
 	result = m_sql.safe_query("SELECT ID FROM WOLNodes WHERE (HardwareID==%d) AND (MacAddress=='%q')", m_HwdID, IPAddress.c_str());
 	if (!result.empty()) {
 		m_sql.safe_query("UPDATE WOLNodes SET Name='%q', MacAddress='%q', Timeout=0 WHERE (HardwareID==%d) AND (MacAddress=='%q')", Name.c_str(), MacAddress.c_str(), m_HwdID, IPAddress.c_str());
-		_log.Log(LOG_STATUS, "Logitech Media Server: Player '%s' IP changed to MacAddress", Name.c_str());
+		Log(LOG_STATUS, "Player '%s' IP changed to MacAddress", Name.c_str());
 		return;
 	}
 
 	//Player not found, add it...
 	m_sql.safe_query("INSERT INTO WOLNodes (HardwareID, Name, MacAddress, Timeout) VALUES (%d, '%q', '%q', 0)", m_HwdID, Name.c_str(), MacAddress.c_str());
-	_log.Log(LOG_STATUS, "Logitech Media Server: New Player '%s' added", Name.c_str());
+	Log(LOG_STATUS, "New Player '%s' added", Name.c_str());
 
 	result = m_sql.safe_query("SELECT ID FROM WOLNodes WHERE (HardwareID==%d) AND (MacAddress='%q')", m_HwdID, MacAddress.c_str());
 	if (result.empty())
@@ -512,10 +518,9 @@ bool CLogitechMediaServer::WriteToHardware(const char *pdata, const unsigned cha
 		return false;
 
 	long	DevID = (pSen->LIGHTING2.id3 << 8) | pSen->LIGHTING2.id4;
-	std::vector<LogitechMediaServerNode>::const_iterator itt;
-	for (itt = m_nodes.begin(); itt != m_nodes.end(); ++itt)
+	for (const auto &node : m_nodes)
 	{
-		if (itt->DevID == DevID)
+		if (node.DevID == DevID)
 		{
 			int iParam = pSen->LIGHTING2.level;
 			std::string sParam;
@@ -523,25 +528,25 @@ bool CLogitechMediaServer::WriteToHardware(const char *pdata, const unsigned cha
 			{
 			case light2_sOn:
 			case light2_sGroupOn:
-				return SendCommand(itt->ID, "PowerOn");
+				return SendCommand(node.ID, "PowerOn");
 			case light2_sOff:
 			case light2_sGroupOff:
-				return SendCommand(itt->ID, "PowerOff");
+				return SendCommand(node.ID, "PowerOff");
 			case gswitch_sPlay:
-				SendCommand(itt->ID, "NowPlaying");
-				return SendCommand(itt->ID, "Play");
+				SendCommand(node.ID, "NowPlaying");
+				return SendCommand(node.ID, "Play");
 			case gswitch_sPlayPlaylist:
 				sParam = GetPlaylistByRefID(iParam);
-				return SendCommand(itt->ID, "PlayPlaylist", sParam);
+				return SendCommand(node.ID, "PlayPlaylist", sParam);
 			case gswitch_sPlayFavorites:
-				return SendCommand(itt->ID, "PlayFavorites");
+				return SendCommand(node.ID, "PlayFavorites");
 			case gswitch_sStop:
-				return SendCommand(itt->ID, "Stop");
+				return SendCommand(node.ID, "Stop");
 			case gswitch_sPause:
-				return SendCommand(itt->ID, "Pause");
+				return SendCommand(node.ID, "Pause");
 			case gswitch_sSetVolume:
 				sParam = std::to_string(iParam);
-				return SendCommand(itt->ID, "SetVolume", sParam);
+				return SendCommand(node.ID, "SetVolume", sParam);
 			default:
 				return true;
 			}
@@ -558,12 +563,9 @@ void CLogitechMediaServer::ReloadNodes()
 	result = m_sql.safe_query("SELECT ID,Name,MacAddress FROM WOLNodes WHERE (HardwareID==%d)", m_HwdID);
 	if (!result.empty())
 	{
-		_log.Log(LOG_STATUS, "Logitech Media Server: %d player-switch(es) found.", (int)result.size());
-		std::vector<std::vector<std::string> >::const_iterator itt;
-		for (itt = result.begin(); itt != result.end(); ++itt)
+		Log(LOG_STATUS, "%d player-switch(es) found.", (int)result.size());
+		for (const auto &sd : result)
 		{
-			std::vector<std::string> sd = *itt;
-
 			LogitechMediaServerNode pnode;
 			pnode.ID = 0;
 			pnode.DevID = atoi(sd[0].c_str());
@@ -572,7 +574,7 @@ void CLogitechMediaServer::ReloadNodes()
 			pnode.IP = sd[2];
 			pnode.nStatus = MSTAT_UNKNOWN;
 			pnode.sStatus = "";
-			pnode.LastOK = mytime(NULL);
+			pnode.LastOK = mytime(nullptr);
 
 			std::vector<std::vector<std::string> > result2;
 			result2 = m_sql.safe_query("SELECT ID,nValue,sValue FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit == 1)", m_HwdID, pnode.szDevID);
@@ -587,23 +589,23 @@ void CLogitechMediaServer::ReloadNodes()
 		}
 	}
 	else
-		_log.Log(LOG_ERROR, "Logitech Media Server: No player-switches found.");
+		Log(LOG_ERROR, "No player-switches found.");
 }
 
 void CLogitechMediaServer::ReloadPlaylists()
 {
 	m_playlists.clear();
 
-	std::string sPostdata = "{\"id\":1,\"method\":\"slim.request\",\"params\":[\"\",[\"playlists\",0,999]]}";
+	std::string sPostdata = R"({"id":1,"method":"slim.request","params":["",["playlists",0,999]]})";
 	Json::Value root = Query(m_IP, m_Port, sPostdata);
 
 	if (root.isNull()) {
-		_log.Log(LOG_ERROR, "Logitech Media Server: No response from server %s:%i", m_IP.c_str(), m_Port);
+		Log(LOG_ERROR, "No response from server %s:%i", m_IP.c_str(), m_Port);
 	}
 	else {
 		int totPlaylists = root["count"].asInt();
 		if (totPlaylists > 0) {
-			_log.Log(LOG_STATUS, "Logitech Media Server: %i playlist(s) found.", totPlaylists);
+			Log(LOG_STATUS, "%i playlist(s) found.", totPlaylists);
 			for (int ii = 0; ii < totPlaylists; ii++)
 			{
 				LMSPlaylistNode pnode;
@@ -616,34 +618,32 @@ void CLogitechMediaServer::ReloadPlaylists()
 			}
 		}
 		else
-			_log.Log(LOG_STATUS, "Logitech Media Server: No playlists found.");
+			Log(LOG_STATUS, "No playlists found.");
 	}
 }
 
 std::string CLogitechMediaServer::GetPlaylistByRefID(const int ID)
 {
-	std::vector<CLogitechMediaServer::LMSPlaylistNode>::const_iterator itt;
+	for (const auto &playlist : m_playlists)
+		if (playlist.refID == ID)
+			return playlist.Name;
 
-	for (itt = m_playlists.begin(); itt != m_playlists.end(); ++itt) {
-		if (itt->refID == ID) return itt->Name;
-	}
-
-	_log.Log(LOG_ERROR, "Logitech Media Server: Playlist ID %d not found.", ID);
+	Log(LOG_ERROR, "Playlist ID %d not found.", ID);
 	return "";
 }
 
 bool CLogitechMediaServer::SendCommand(const int ID, const std::string &command, const std::string &param)
 {
 	std::vector<std::vector<std::string> > result;
-	std::string sPlayerId = "";
-	std::string sLMSCmnd = "";
+	std::string sPlayerId;
+	std::string sLMSCmnd;
 
 	// Get device details
 	result = m_sql.safe_query("SELECT DeviceID FROM DeviceStatus WHERE (ID==%d)", ID);
 	if (result.size() == 1)
 	{
 		// Get connection details
-		long	DeviceID = strtol(result[0][0].c_str(), NULL, 16);
+		long DeviceID = strtol(result[0][0].c_str(), nullptr, 16);
 		result = m_sql.safe_query("SELECT Name, MacAddress,Timeout FROM WOLNodes WHERE (HardwareID==%d) AND (ID==%d)", m_HwdID, DeviceID);
 		sPlayerId = result[0][1];
 	}
@@ -652,80 +652,82 @@ bool CLogitechMediaServer::SendCommand(const int ID, const std::string &command,
 	{
 		//std::string	sLMSCall;
 		if (command == "Left") {
-			sLMSCmnd = "\"button\", \"arrow_left\"";
+			sLMSCmnd = R"("button", "arrow_left")";
 		}
 		else if (command == "Right") {
-			sLMSCmnd = "\"button\", \"arrow_right\"";
+			sLMSCmnd = R"("button", "arrow_right")";
 		}
 		else if (command == "Up") {
-			sLMSCmnd = "\"button\", \"arrow_up\"";
+			sLMSCmnd = R"("button", "arrow_up")";
 		}
 		else if (command == "Down") {
-			sLMSCmnd = "\"button\", \"arrow_down\"";
+			sLMSCmnd = R"("button", "arrow_down")";
 		}
 		else if (command == "Favorites") {
-			sLMSCmnd = "\"button\", \"favorites\"";
+			sLMSCmnd = R"("button", "favorites")";
 		}
 		else if (command == "Browse") {
-			sLMSCmnd = "\"button\", \"browse\"";
+			sLMSCmnd = R"("button", "browse")";
 		}
 		else if (command == "NowPlaying") {
-			sLMSCmnd = "\"button\", \"playdisp_toggle\"";
+			sLMSCmnd = R"("button", "playdisp_toggle")";
 		}
 		else if (command == "Shuffle") {
-			sLMSCmnd = "\"button\", \"shuffle_toggle\"";
+			sLMSCmnd = R"("button", "shuffle_toggle")";
 		}
 		else if (command == "Repeat") {
-			sLMSCmnd = "\"button\", \"repeat_toggle\"";
+			sLMSCmnd = R"("button", "repeat_toggle")";
 		}
 		else if (command == "Stop") {
-			sLMSCmnd = "\"button\", \"stop\"";
+			sLMSCmnd = R"("button", "stop")";
 		}
 		else if (command == "VolumeUp") {
-			sLMSCmnd = "\"mixer\", \"volume\", \"+2\"";
+			sLMSCmnd = R"("mixer", "volume", "+2")";
 		}
 		else if (command == "Mute") {
-			sLMSCmnd = "\"mixer\", \"muting\", \"toggle\"";
+			sLMSCmnd = R"("mixer", "muting", "toggle")";
 		}
 		else if (command == "VolumeDown") {
-			sLMSCmnd = "\"mixer\", \"volume\", \"-2\"";
+			sLMSCmnd = R"("mixer", "volume", "-2")";
 		}
 		else if (command == "Rewind") {
-			sLMSCmnd = "\"button\", \"rew.single\"";
+			sLMSCmnd = R"("button", "rew.single")";
 		}
 		else if (command == "Play") {
-			sLMSCmnd = "\"button\", \"play.single\"";
+			sLMSCmnd = R"("button", "play.single")";
 		}
 		else if (command == "PlayPlaylist") {
-			if (param == "") return false;
-			sLMSCmnd = "\"playlist\", \"play\", \"" + param + "\"";
+			if (param.empty())
+				return false;
+			sLMSCmnd = R"("playlist", "play", ")" + param + "\"";
 		}
 		else if (command == "PlayFavorites") {
-			sLMSCmnd = "\"favorites\", \"playlist\", \"play\"";
+			sLMSCmnd = R"("favorites", "playlist", "play")";
 		}
 		else if (command == "Pause") {
-			sLMSCmnd = "\"button\", \"pause.single\"";
+			sLMSCmnd = R"("button", "pause.single")";
 		}
 		else if (command == "Forward") {
-			sLMSCmnd = "\"button\", \"fwd.single\"";
+			sLMSCmnd = R"("button", "fwd.single")";
 		}
 		else if (command == "PowerOn") {
-			sLMSCmnd = "\"power\", \"1\"";
+			sLMSCmnd = R"("power", "1")";
 		}
 		else if (command == "PowerOff") {
-			sLMSCmnd = "\"power\", \"0\"";
+			sLMSCmnd = R"("power", "0")";
 		}
 		else if (command == "SetVolume") {
-			if (param == "") return false;
-			sLMSCmnd = "\"mixer\", \"volume\", \"" + param + "\"";
+			if (param.empty())
+				return false;
+			sLMSCmnd = R"("mixer", "volume", ")" + param + "\"";
 		}
 
-		if (sLMSCmnd != "")
+		if (!sLMSCmnd.empty())
 		{
-			std::string sPostdata = "{\"id\":1,\"method\":\"slim.request\",\"params\":[\"" + sPlayerId + "\",[" + sLMSCmnd + "]]}";
+			std::string sPostdata = R"({"id":1,"method":"slim.request","params":[")" + sPlayerId + "\",[" + sLMSCmnd + "]]}";
 			Json::Value root = Query(m_IP, m_Port, sPostdata);
 
-			sPostdata = "{\"id\":1,\"method\":\"slim.request\",\"params\":[\"" + sPlayerId + "\",[\"status\",\"-\",1,\"tags:uB\"]]}";
+			sPostdata = R"({"id":1,"method":"slim.request","params":[")" + sPlayerId + R"(",["status","-",1,"tags:uB"]]})";
 			root = Query(m_IP, m_Port, sPostdata);
 
 			if (root["player_connected"].asString() == "1")
@@ -735,47 +737,39 @@ bool CLogitechMediaServer::SendCommand(const int ID, const std::string &command,
 
 				if (command == "Stop")
 					return sMode == "stop";
-				else if (command == "Pause")
+				if (command == "Pause")
 					return sMode == "pause";
-				else if (command == "Play")
+				if (command == "Play")
 					return sMode == "play";
-				else if (command == "PlayPlaylist")
+				if (command == "PlayPlaylist")
 					return sMode == "play";
-				else if (command == "PlayFavorites")
+				if (command == "PlayFavorites")
 					return sMode == "play";
-				else if (command == "PowerOn")
+				if (command == "PowerOn")
 					return sPower == "1";
-				else if (command == "PowerOff")
+				if (command == "PowerOff")
 					return sPower == "0";
-				else
-					return false;
 			}
-			else
-				return false;
-		}
-		else
-		{
-			_log.Log(LOG_ERROR, "Logitech Media Server: (%s) Command: '%s'. Unknown command.", result[0][0].c_str(), command.c_str());
 			return false;
 		}
-	}
-	else
-	{
-		_log.Log(LOG_ERROR, "Logitech Media Server: (%d) Command: '%s'. Device not found.", ID, command.c_str());
+		Log(LOG_ERROR, "(%s) Command: '%s'. Unknown command.", result[0][0].c_str(), command.c_str());
 		return false;
 	}
+	Log(LOG_ERROR, "(%d) Command: '%s'. Device not found.", ID, command.c_str());
+	return false;
 }
 
 void CLogitechMediaServer::SendText(const std::string &playerIP, const std::string &subject, const std::string &text, const int duration)
 {
-	if ((playerIP != "") && (text != "") && (duration > 0))
+	if ((!playerIP.empty()) && (!text.empty()) && (duration > 0))
 	{
-		std::string sLine1 = subject;
-		std::string sLine2 = text;
-		std::string sFont = ""; //"huge";
+		const std::string &sLine1 = subject;
+		const std::string &sLine2 = text;
+		std::string sFont; //"huge";
 		std::string sBrightness = "4";
 		std::string sDuration = std::to_string(duration);
-		std::string sPostdata = "{\"id\":1,\"method\":\"slim.request\",\"params\":[\"" + playerIP + "\",[\"show\",\"line1:" + sLine1 + "\",\"line2:" + sLine2 + "\",\"duration:" + sDuration + "\",\"brightness:" + sBrightness + "\",\"font:" + sFont + "\"]]}";
+		std::string sPostdata = R"({"id":1,"method":"slim.request","params":[")" + playerIP + R"(",["show","line1:)" + sLine1 + "\",\"line2:" + sLine2 + "\",\"duration:" + sDuration +
+					"\",\"brightness:" + sBrightness + "\",\"font:" + sFont + "\"]]}";
 		Json::Value root = Query(m_IP, m_Port, sPostdata);
 	}
 }
@@ -787,13 +781,11 @@ std::vector<CLogitechMediaServer::LMSPlaylistNode> CLogitechMediaServer::GetPlay
 
 int CLogitechMediaServer::GetPlaylistRefID(const std::string &name)
 {
-	std::vector<CLogitechMediaServer::LMSPlaylistNode>::const_iterator itt;
+	for (const auto &playlist : m_playlists)
+		if (playlist.Name == name)
+			return playlist.refID;
 
-	for (itt = m_playlists.begin(); itt != m_playlists.end(); ++itt) {
-		if (itt->Name == name) return itt->refID;
-	}
-
-	_log.Log(LOG_ERROR, "Logitech Media Server: Playlist '%s' not found.", name.c_str());
+	Log(LOG_ERROR, "Playlist '%s' not found.", name.c_str());
 	return 0;
 }
 
@@ -809,14 +801,11 @@ namespace http {
 			}
 			std::string hwid = request::findValue(&req, "idx");
 			std::string mode1 = request::findValue(&req, "mode1");
-			if (
-				(hwid == "") ||
-				(mode1 == "")
-				)
+			if ((hwid.empty()) || (mode1.empty()))
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pBaseHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			if (pBaseHardware->HwdType != HTYPE_LogitechMediaServer)
 				return;
@@ -840,11 +829,11 @@ namespace http {
 				return; //Only admin user allowed
 			}
 			std::string hwid = request::findValue(&req, "idx");
-			if (hwid == "")
+			if (hwid.empty())
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pBaseHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			if (pBaseHardware->HwdType != HTYPE_LogitechMediaServer)
 				return;
@@ -859,11 +848,11 @@ namespace http {
 				return; //Only admin user allowed
 			}
 			std::string hwid = request::findValue(&req, "idx");
-			if (hwid == "")
+			if (hwid.empty())
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pHardware == NULL)
+			if (pHardware == nullptr)
 				return;
 			if (pHardware->HwdType != HTYPE_LogitechMediaServer)
 				return;
@@ -875,12 +864,9 @@ namespace http {
 			result = m_sql.safe_query("SELECT ID,Name,MacAddress,(CASE Timeout WHEN -1 THEN 'Unused' ELSE 'Active' END) as Status FROM WOLNodes WHERE (HardwareID==%d)", iHardwareID);
 			if (!result.empty())
 			{
-				std::vector<std::vector<std::string> >::const_iterator itt;
 				int ii = 0;
-				for (itt = result.begin(); itt != result.end(); ++itt)
+				for (const auto &sd : result)
 				{
-					std::vector<std::string> sd = *itt;
-
 					root["result"][ii]["idx"] = sd[0];
 					root["result"][ii]["Name"] = sd[1];
 					root["result"][ii]["Mac"] = sd[2];
@@ -893,11 +879,11 @@ namespace http {
 		void CWebServer::Cmd_LMSGetPlaylists(WebEmSession & /*session*/, const request& req, Json::Value &root)
 		{
 			std::string hwid = request::findValue(&req, "idx");
-			if (hwid == "")
+			if (hwid.empty())
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pBaseHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			if (pBaseHardware->HwdType != HTYPE_LogitechMediaServer)
 				return;
@@ -909,11 +895,11 @@ namespace http {
 			std::vector<CLogitechMediaServer::LMSPlaylistNode> _nodes = pHardware->GetPlaylists();
 
 			int ii = 0;
-			for (const auto & itt : _nodes)
+			for (const auto &node : _nodes)
 			{
-				root["result"][ii]["id"] = itt.ID;
-				root["result"][ii]["refid"] = itt.refID;
-				root["result"][ii]["Name"] = itt.Name;
+				root["result"][ii]["id"] = node.ID;
+				root["result"][ii]["refid"] = node.refID;
+				root["result"][ii]["Name"] = node.Name;
 				ii++;
 			}
 		}
@@ -949,5 +935,5 @@ namespace http {
 			}
 		}
 
-	}
-}
+	} // namespace server
+} // namespace http
