@@ -5,17 +5,20 @@
 
 class MySensorsTCP : public MySensorsBase, ASyncTCP
 {
-public:
-	MySensorsTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort);
-	~MySensorsTCP(void);
-public:
+      public:
+	MySensorsTCP(int ID, const std::string &IPAddress, unsigned short usIPPort);
+	~MySensorsTCP() override = default;
+
+      public:
 	// signals
-	boost::signals2::signal<void()>	sDisconnected;
-private:
+	boost::signals2::signal<void()> sDisconnected;
+
+      private:
 	int m_retrycntr;
 	bool StartHardware() override;
 	bool StopHardware() override;
-protected:
+
+      protected:
 	std::string m_szIPAddress;
 	unsigned short m_usIPPort;
 
@@ -26,8 +29,7 @@ protected:
 	void OnConnect() override;
 	void OnDisconnect() override;
 	void OnData(const unsigned char *pData, size_t length) override;
-	void OnError(const boost::system::error_code& error) override;
+	void OnError(const boost::system::error_code &error) override;
 
 	std::shared_ptr<std::thread> m_thread;
 };
-
