@@ -16,10 +16,6 @@ OTGWTCP::OTGWTCP(const int ID, const std::string &IPAddress, const unsigned shor
 	SetModes(Mode1,Mode2,Mode3,Mode4,Mode5,Mode6);
 }
 
-OTGWTCP::~OTGWTCP(void)
-{
-}
-
 bool OTGWTCP::StartHardware()
 {
 	RequestStart();
@@ -29,7 +25,7 @@ bool OTGWTCP::StartHardware()
 	m_bIsStarted=true;
 
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&OTGWTCP::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	return (m_thread != nullptr);
 }
@@ -48,7 +44,7 @@ bool OTGWTCP::StopHardware()
 
 void OTGWTCP::OnConnect()
 {
-	_log.Log(LOG_STATUS,"OTGW: connected to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
+	Log(LOG_STATUS,"connected to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
 	m_bIsStarted=true;
 	m_bufferpos=0;
 	sOnConnected(this);
@@ -57,7 +53,7 @@ void OTGWTCP::OnConnect()
 
 void OTGWTCP::OnDisconnect()
 {
-	_log.Log(LOG_STATUS,"OTGW: disconnected");
+	Log(LOG_STATUS,"disconnected");
 }
 
 void OTGWTCP::Do_Work()
@@ -69,7 +65,7 @@ void OTGWTCP::Do_Work()
 		sec_counter++;
 
 		if (sec_counter % 12 == 0) {
-			m_LastHeartbeat=mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if (isConnected())
@@ -89,7 +85,7 @@ void OTGWTCP::Do_Work()
 	}
 	terminate();
 
-	_log.Log(LOG_STATUS,"OTGW: TCP/IP Worker stopped...");
+	Log(LOG_STATUS,"TCP/IP Worker stopped...");
 }
 
 void OTGWTCP::OnData(const unsigned char *pData, size_t length)
@@ -107,17 +103,17 @@ void OTGWTCP::OnError(const boost::system::error_code& error)
 		(error == boost::asio::error::timed_out)
 		)
 	{
-		_log.Log(LOG_ERROR, "OTGW: Can not connect to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
+		Log(LOG_ERROR, "Can not connect to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
 	}
 	else if (
 		(error == boost::asio::error::eof) ||
 		(error == boost::asio::error::connection_reset)
 		)
 	{
-		_log.Log(LOG_STATUS, "OTGW: Connection reset!");
+		Log(LOG_STATUS, "Connection reset!");
 	}
 	else
-		_log.Log(LOG_ERROR, "OTGW: %s", error.message().c_str());
+		Log(LOG_ERROR, "%s", error.message().c_str());
 }
 
 bool OTGWTCP::WriteInt(const unsigned char *pData, const unsigned char Len)
