@@ -12,8 +12,6 @@
 #include <string>
 #include <algorithm>
 #include <iostream>
-#include <boost/bind.hpp>
-
 #include <ctime>
 
 #ifndef WIN32
@@ -88,11 +86,6 @@ RFXComSerial::RFXComSerial(const int ID, const std::string& devname, unsigned in
 	m_serial.setTimeout(stimeout);
 }
 
-RFXComSerial::~RFXComSerial()
-{
-
-}
-
 bool RFXComSerial::StartHardware()
 {
 	RequestStart();
@@ -104,7 +97,7 @@ bool RFXComSerial::StartHardware()
 	m_retrycntr = RETRY_DELAY; //will force reconnect first thing
 
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&RFXComSerial::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 
 	return (m_thread != nullptr);
@@ -134,7 +127,7 @@ void RFXComSerial::Do_Work()
 		sec_counter++;
 
 		if (sec_counter % 12 == 0) {
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if (m_bStartFirmwareUpload)
@@ -195,7 +188,7 @@ bool RFXComSerial::OpenSerialDevice(const bool bIsFirmwareUpgrade)
 	}
 	m_bIsStarted = true;
 	m_rxbufferpos = 0;
-	setReadCallback(boost::bind(&RFXComSerial::readCallback, this, _1, _2));
+	setReadCallback([this](auto d, auto l) { readCallback(d, l); });
 	if (!bIsFirmwareUpgrade)
 		sOnConnected(this);
 	return true;
@@ -310,15 +303,15 @@ bool RFXComSerial::UpgradeFirmware()
 
 	m_szUploadMessage = "Bootloader, Start programming...";
 	Log(LOG_STATUS, m_szUploadMessage);
-	for (auto itt : firmwareBuffer)
+	for (const auto &firmware : firmwareBuffer)
 	{
 		icntr++;
 		if (icntr % 5 == 0)
 		{
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
-		unsigned long Address = itt.first;
-		m_FirmwareUploadPercentage = (100.0f / float(firmwareBuffer.size()))*icntr;
+		unsigned long Address = firmware.first;
+		m_FirmwareUploadPercentage = (100.0F / float(firmwareBuffer.size())) * icntr;
 		if (m_FirmwareUploadPercentage > 100)
 			m_FirmwareUploadPercentage = 100;
 
@@ -331,7 +324,7 @@ bool RFXComSerial::UpgradeFirmware()
 			spercentage.precision(2);
 			spercentage << std::setprecision(2) << std::fixed << m_FirmwareUploadPercentage;
 			m_szUploadMessage = saddress.str() + ", " + spercentage.str() + " %";
-			_log.Log(LOG_STATUS, m_szUploadMessage);
+			Log(LOG_STATUS, m_szUploadMessage);
 
 			unsigned char bcmd[PKT_writeblock + 10];
 			bcmd[0] = COMMAND_WRITEPM;
@@ -339,8 +332,8 @@ bool RFXComSerial::UpgradeFirmware()
 			bcmd[2] = Address & 0xFF;
 			bcmd[3] = (Address & 0xFF00) >> 8;
 			bcmd[4] = (unsigned char)((Address & 0xFF0000) >> 16);
-			memcpy(bcmd + 5, itt.second.c_str(), itt.second.size());
-			bool ret = Write_TX_PKT(bcmd, 5 + itt.second.size(), 20);
+			memcpy(bcmd + 5, firmware.second.c_str(), firmware.second.size());
+			bool ret = Write_TX_PKT(bcmd, 5 + firmware.second.size(), 20);
 			if (!ret)
 			{
 				m_szUploadMessage = "Bootloader, unable to program firmware memory, please try again!!!";
@@ -470,7 +463,7 @@ bool RFXComSerial::Read_Firmware_File(const char *szFilename, std::map<unsigned
 	int addrh = 0;
 
 	fileBuffer.clear();
-	std::string dstring = "";
+	std::string dstring;
 	bool bHaveEOF = false;
 
 	while (!infile.eof())
@@ -755,7 +748,7 @@ bool RFXComSerial::Read_TX_PKT()
 					m_bHaveRX = true;
 					return true;
 				}
-				else if (tByte == PKT_DLE)
+				if (tByte == PKT_DLE)
 				{
 					bHadDLE = true;
 				}
@@ -810,7 +803,7 @@ bool RFXComSerial::Handle_RX_PKT(const unsigned char *pdata, size_t length)
 					sstr << ", ";
 				szRespone+=sstr.str();
 			}
-			_log.Log(LOG_STATUS, "%s", szRespone.c_str());
+			Log(LOG_STATUS, "%s", szRespone.c_str());
 			*/
 			m_bHaveRX = true;
 			return true;
@@ -882,19 +875,19 @@ namespace http {
 				return;
 			}
 
-			CDomoticzHardwareBase *pHardware = NULL;
+			CDomoticzHardwareBase *pHardware = nullptr;
 			if ((!hardwareid.empty()) && (hardwareid != "undefined"))
 			{
 				pHardware = m_mainworker.GetHardware(atoi(hardwareid.c_str()));
 			}
-			if (pHardware == NULL)
+			if (pHardware == nullptr)
 			{
 				//Direct Entry, try to find the RFXCom hardware
 				pHardware = m_mainworker.GetHardwareByType(HTYPE_RFXtrx433);
-				if (pHardware == NULL)
+				if (pHardware == nullptr)
 				{
 					pHardware = m_mainworker.GetHardwareByType(HTYPE_RFXtrx868);
-					if (pHardware == NULL)
+					if (pHardware == nullptr)
 					{
 						return;
 					}
@@ -935,7 +928,8 @@ namespace http {
 			}
 
 			std::string idx = request::findValue(&req, "idx");
-			if (idx == "") {
+			if (idx.empty())
+			{
 				return;
 			}
 			std::vector<std::vector<std::string> > result;
@@ -999,7 +993,7 @@ namespace http {
 					if (pBase->m_Version.find("Pro XL") != std::string::npos)
 					{
 						std::string AsyncMode = request::findValue(&req, "combo_rfx_xl_async_type");
-						if (AsyncMode == "")
+						if (AsyncMode.empty())
 							AsyncMode = "0";
 						result = m_sql.safe_query("UPDATE Hardware SET Extra='%q' WHERE (ID='%q')", AsyncMode.c_str(), idx.c_str());
 						pBase->SetAsyncType((CRFXBase::_eRFXAsyncType)atoi(AsyncMode.c_str()));
@@ -1008,7 +1002,7 @@ namespace http {
 			}
 			else
 			{
-				//For now disable setting the protocols on a 868Mhz device
+				//For now disable setting the protocols on a 868MHz device
 			}
 		}
 
@@ -1018,21 +1012,21 @@ namespace http {
 			root["title"] = "GetFirmwareUpgradePercentage";
 			std::string hardwareid = request::findValue(&req, "hardwareid");
 
-			CDomoticzHardwareBase *pHardware = NULL;
+			CDomoticzHardwareBase *pHardware = nullptr;
 			if ((!hardwareid.empty()) && (hardwareid != "undefined"))
 			{
 				pHardware = m_mainworker.GetHardware(atoi(hardwareid.c_str()));
 			}
-			if (pHardware == NULL)
+			if (pHardware == nullptr)
 			{
 				//Direct Entry, try to find the RFXCom hardware
 				pHardware = m_mainworker.GetHardwareByType(HTYPE_RFXtrx433);
-				if (pHardware == NULL)
+				if (pHardware == nullptr)
 				{
 					pHardware = m_mainworker.GetHardwareByType(HTYPE_RFXtrx868);
 				}
 			}
-			if (pHardware != NULL)
+			if (pHardware != nullptr)
 			{
 				if (
 					(pHardware->HwdType == HTYPE_RFXtrx315) ||
@@ -1049,5 +1043,5 @@ namespace http {
 			else
 				root["message"] = "Hardware not found, or not enabled!";
 		}
-	}
-}
+	} // namespace server
+} // namespace http
