@@ -151,6 +151,9 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 	bool haveUV = false;
 	float uvi = 0;
 
+	bool haveLux = false;
+	float lux = 0;
+
 	int snr = 12;  // Set to show "-" if no snr is received. rtl_433 uses automatic gain, better to use SNR instead of RSSI to report received RF Signal quality
 
 	int code = 0;
@@ -278,6 +281,16 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 		uvi = (float)atof(data["uv"].c_str());
 		haveUV = true;
 	}
+	if (FindField(data, "light_klx"))
+	{
+		lux = ( (float)atof(data["light_klx"].c_str()) ) * 1000;
+		haveLux = true;
+	}
+	if (FindField(data, "light_lux"))
+	{
+		lux = (float)atof(data["light_lux"].c_str());
+		haveLux = true;
+	}
 	if (FindField(data, "snr"))
 	{
 		/* Map the received Signal to Noise Ratio to the domoticz RSSI 4-bit field that has range of 0-11 (12-15 display '-' in device tab).
@@ -343,6 +356,9 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 
 
 	unsigned int sensoridx = (id & 0xff) | ((channel & 0xff) << 8);
+	if (model == "TFA-Drop") {
+		sensoridx = id;
+	}
 
 	if (haveTemp && haveHumidity)
 	{
@@ -429,6 +445,11 @@ bool CRtl433::ParseData(std::map<std::string, std::string>& data)
 		SendUVSensor((uint8_t)sensoridx, (uint8_t)unit, batterylevel, uvi, model, snr);
 		bHandled = true;
 	}
+	if (haveLux)
+	{
+		SendLuxSensor((uint8_t)sensoridx, (uint8_t)unit, batterylevel, lux, model);
+		bHandled = true;
+	}
 
 	if (!strcmp(model.c_str(), "X10-Security"))
 	{
