@@ -33,10 +33,6 @@ CSBFSpot::CSBFSpot(const int ID, const std::string &SMAConfigFile)
 	Init();
 }
 
-CSBFSpot::~CSBFSpot(void)
-{
-}
-
 void CSBFSpot::Init()
 {
 	m_SBFDataPath="";
@@ -51,7 +47,7 @@ void CSBFSpot::Init()
 	infile.open(m_SBFConfigFile.c_str());
 	if (!infile.is_open())
 	{
-		_log.Log(LOG_ERROR,"SBFSpot: Could not open configuration file!");
+		Log(LOG_ERROR,"Could not open configuration file!");
 		return;
 	}
 	while (!infile.eof())
@@ -59,12 +55,12 @@ void CSBFSpot::Init()
 		getline(infile, sLine);
 		sLine.erase(std::remove(sLine.begin(), sLine.end(), '\r'), sLine.end());
 		sLine = stdstring_trim(sLine);
-		if (sLine.size()!=0)
+		if (!sLine.empty())
 		{
 			if (sLine.find("OutputPath=")==0)
 			{
 				tmpString=sLine.substr(strlen("OutputPath="));
-				if (tmpString!="")
+				if (!tmpString.empty())
 				{
 					unsigned char lastchar=tmpString[tmpString.size()-1];
 #ifdef WIN32
@@ -92,9 +88,9 @@ void CSBFSpot::Init()
 		}
 	}
 	infile.close();
-	if ((m_SBFDataPath.size()==0)||(m_SBFDateFormat.size()==0)||(m_SBFTimeFormat.size()==0))
+	if ((m_SBFDataPath.empty()) || (m_SBFDateFormat.empty()) || (m_SBFTimeFormat.empty()))
 	{
-		_log.Log(LOG_ERROR,"SBFSpot: Could not find OutputPath in configuration file!");
+		Log(LOG_ERROR,"Could not find OutputPath in configuration file!");
 	}
 }
 
@@ -104,7 +100,7 @@ bool CSBFSpot::StartHardware()
 
 	Init();
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CSBFSpot::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted=true;
 	sOnConnected(this);
@@ -129,10 +125,10 @@ void CSBFSpot::Do_Work()
 {
 	int LastMinute=-1;
 
-	_log.Log(LOG_STATUS,"SBFSpot: Worker started...");
+	Log(LOG_STATUS,"Worker started...");
 	while (!IsStopRequested(1000))
 	{
-		time_t atime=mytime(NULL);
+		time_t atime = mytime(nullptr);
 		struct tm ltime;
 		localtime_r(&atime,&ltime);
 		if (((ltime.tm_min/SMA_POLL_INTERVAL!=LastMinute))&&(ltime.tm_sec>20))
@@ -144,7 +140,7 @@ void CSBFSpot::Do_Work()
 			mytime(&m_LastHeartbeat);
 		}
 	}
-	_log.Log(LOG_STATUS,"SBFSpot: Worker stopped...");
+	Log(LOG_STATUS,"Worker stopped...");
 }
 
 bool CSBFSpot::WriteToHardware(const char *pdata, const unsigned char length)
@@ -198,7 +194,7 @@ void CSBFSpot::SendMeter(const unsigned char ID1,const unsigned char ID2, const
 	total-=tsen.ENERGY.total5*0x100;
 	tsen.ENERGY.total6=(unsigned char)(total);
 
-	sDecodeRXMessage(this, (const unsigned char *)&tsen.ENERGY, defaultname.c_str(), 255);
+	sDecodeRXMessage(this, (const unsigned char *)&tsen.ENERGY, defaultname.c_str(), 255, nullptr);
 }
 
 bool CSBFSpot::GetMeter(const unsigned char ID1,const unsigned char ID2, double &musage, double &mtotal)
@@ -207,7 +203,7 @@ bool CSBFSpot::GetMeter(const unsigned char ID1,const unsigned char ID2, double
 	std::vector<std::vector<std::string> > result;
 	result=m_sql.safe_query("SELECT Name, sValue FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID==%d) AND (Type==%d) AND (Subtype==%d)",
 		m_HwdID, int(Idx), int(pTypeENERGY), int(sTypeELEC2));
-	if (result.size()<1)
+	if (result.empty())
 	{
 		return false;
 	}
@@ -222,7 +218,7 @@ bool CSBFSpot::GetMeter(const unsigned char ID1,const unsigned char ID2, double
 
 void CSBFSpot::ImportOldMonthData()
 {
-	_log.Log(LOG_STATUS, "SBFSpot Import Old Month Data: Start");
+	Log(LOG_STATUS, "SBFSpot Import Old Month Data: Start");
 	//check if this device exists in the database, if not exit
 	bool bDeviceExits = true;
 	std::vector<std::vector<std::string> > result;
@@ -236,14 +232,14 @@ void CSBFSpot::ImportOldMonthData()
 			m_HwdID, "00000001", int(pTypeGeneral), int(sTypeKwh));
 		if (result.empty())
 		{
-			_log.Log(LOG_ERROR, "SBFSpot Import Old Month Data: FAILED - Cannot find sensor in database");
+			Log(LOG_ERROR, "SBFSpot Import Old Month Data: FAILED - Cannot find sensor in database");
 			return;
 		}
 	}
 	uint64_t ulID = std::stoull(result[0][0]);
 
 	//Try actual year, and previous year
-	time_t atime = time(NULL);
+	time_t atime = time(nullptr);
 	struct tm ltime;
 	localtime_r(&atime, &ltime);
 
@@ -257,14 +253,14 @@ void CSBFSpot::ImportOldMonthData()
 			ImportOldMonthData(ulID,iYear, iMonth);
 		}
 	}
-	_log.Log(LOG_STATUS, "SBFSpot Import Old Month Data: Complete");
+	Log(LOG_STATUS, "SBFSpot Import Old Month Data: Complete");
 }
 
 void CSBFSpot::ImportOldMonthData(const uint64_t DevID, const int Year, const int Month)
 {
-	if (m_SBFDataPath.size() == 0)
+	if (m_SBFDataPath.empty())
 		return;
-	if (m_SBFPlantName.size() == 0)
+	if (m_SBFPlantName.empty())
 		return;
 
 	int iInvOff = 1;
@@ -281,7 +277,7 @@ void CSBFSpot::ImportOldMonthData(const uint64_t DevID, const int Year, const in
 	}
 
 	std::string tmpString;
-	std::string szSeperator = "";
+	std::string szSeperator;
 	std::vector<std::string> results;
 	std::string sLine;
 	bool bHaveVersion = false;
@@ -296,7 +292,7 @@ void CSBFSpot::ImportOldMonthData(const uint64_t DevID, const int Year, const in
 	{
 		getline(infile, sLine);
 		sLine.erase(std::remove(sLine.begin(), sLine.end(), '\r'), sLine.end());
-		if (sLine.size() != 0)
+		if (!sLine.empty())
 		{
 			if (bIsSMAWebExport)
 			{
@@ -327,7 +323,7 @@ void CSBFSpot::ImportOldMonthData(const uint64_t DevID, const int Year, const in
 				{
 					//Insert value into our database
 					m_sql.safe_query("INSERT INTO Meter_Calendar (DeviceRowID, Value, Date) VALUES ('%" PRIu64 "', '%llu', '%q')", DevID, ulCounter, szDate);
-					_log.Log(LOG_STATUS, "SBFSpot Import Old Month Data: Inserting %s",szDate);
+					Log(LOG_STATUS, "SBFSpot Import Old Month Data: Inserting %s",szDate);
 				}
 
 			}
@@ -342,7 +338,7 @@ void CSBFSpot::ImportOldMonthData(const uint64_t DevID, const int Year, const in
 			else if (sLine.find("sep=") == 0)
 			{
 				tmpString = sLine.substr(strlen("sep="));
-				if (tmpString != "")
+				if (!tmpString.empty())
 				{
 					szSeperator = tmpString;
 				}
@@ -395,12 +391,12 @@ void CSBFSpot::ImportOldMonthData(const uint64_t DevID, const int Year, const in
 							//Insert value into our database
 							m_sql.safe_query("INSERT INTO Meter_Calendar (DeviceRowID, Value, Date) VALUES ('%" PRIu64 "', '%llu', '%q')",
 								DevID, ulCounter, szDate);
-							_log.Log(LOG_STATUS, "SBFSpot Import Old Month Data: Inserting %s", szDate);
+							Log(LOG_STATUS, "SBFSpot Import Old Month Data: Inserting %s", szDate);
 						}
 					}
 				}
 			}
-			else if ((szSeperator != "") && (m_SBFInverter != ""))
+			else if ((!szSeperator.empty()) && (!m_SBFInverter.empty()))
 			{
 				StringSplit(sLine, szSeperator, results);
 				for (size_t l = 0; l < results.size(); l++)
@@ -432,27 +428,25 @@ int CSBFSpot::getSunRiseSunSetMinutes(const bool bGetSunRise)
 		if (bGetSunRise) {
 			return sunRiseInMinutes;
 		}
-		else {
-			return sunSetInMinutes;
-		}
+		return sunSetInMinutes;
 	}
 	return 0;
 }
 
 void CSBFSpot::GetMeterDetails()
 {
-	if (m_SBFDataPath.size() == 0)
+	if (m_SBFDataPath.empty())
 	{
-		_log.Log(LOG_ERROR, "SBFSpot: Data path empty!");
+		Log(LOG_ERROR, "Data path empty!");
 		return;
 	}
-	if (m_SBFPlantName.size() == 0)
+	if (m_SBFPlantName.empty())
 	{
-		_log.Log(LOG_ERROR, "SBFSpot: Plant name empty!");
+		Log(LOG_ERROR, "Plant name empty!");
 		return;
 	}
 
-	time_t atime = time(NULL);
+	time_t atime = time(nullptr);
 	struct tm ltime;
 	localtime_r(&atime, &ltime);
 
@@ -476,7 +470,7 @@ void CSBFSpot::GetMeterDetails()
 	bool bHaveVersion = false;
 	std::string tmpString;
 	std::ifstream infile;
-	std::string szLastDate = "";
+	std::string szLastDate;
 	std::vector<std::string> szLastLines;
 	std::vector<std::string> results;
 	std::string sLine;
@@ -485,7 +479,7 @@ void CSBFSpot::GetMeterDetails()
 	{
 		if ((ActHourMin > sunRise) && (ActHourMin < sunSet))
 		{
-			_log.Log(LOG_ERROR, "SBFSpot: Could not open spot file: %s", szLogFile);
+			Log(LOG_ERROR, "Could not open spot file: %s", szLogFile);
 		}
 		return;
 	}
@@ -493,12 +487,12 @@ void CSBFSpot::GetMeterDetails()
 	{
 		getline(infile, sLine);
 		sLine.erase(std::remove(sLine.begin(), sLine.end(), '\r'), sLine.end());
-		if (sLine.size() != 0)
+		if (!sLine.empty())
 		{
 			if (sLine.find("sep=") == 0)
 			{
 				tmpString = sLine.substr(strlen("sep="));
-				if (tmpString != "")
+				if (!tmpString.empty())
 				{
 					szSeperator = tmpString;
 				}
@@ -538,7 +532,7 @@ void CSBFSpot::GetMeterDetails()
 
 	if (szLastLines.empty())
 	{
-		_log.Log(LOG_ERROR, "SBFSpot: No data record found in spot file!");
+		Log(LOG_ERROR, "No data record found in spot file!");
 		return;
 	}
 
@@ -552,19 +546,18 @@ void CSBFSpot::GetMeterDetails()
 	double Pac = 0;
 	int InvIdx = 0;
 
-	std::vector<std::string>::const_iterator itt;
-	for (itt = szLastLines.begin(); itt != szLastLines.end(); ++itt)
+	for (const auto &line : szLastLines)
 	{
-		StringSplit(*itt, szSeperator, results);
+		StringSplit(line, szSeperator, results);
 
-		if (results[1].size() < 1)
+		if (results[1].empty())
 		{
-			_log.Log(LOG_ERROR, "SBFSpot: No data record found in spot file!");
+			Log(LOG_ERROR, "No data record found in spot file!");
 			return;
 		}
 		if ((results[28] != "OK") && (results[28] != "Ok"))
 		{
-			_log.Log(LOG_ERROR, "SBFSpot: Invalid field [28] should be OK!");
+			Log(LOG_ERROR, "Invalid field [28] should be OK!");
 			return;
 		}
 
@@ -625,7 +618,7 @@ void CSBFSpot::GetMeterDetails()
 		{
 			if (kWhCounter < (int)(LastTotal * 100) / 100)
 			{
-				_log.Log(LOG_ERROR, "SBFSpot: Actual KwH counter (%f) less then last Counter (%f)!", kWhCounter, LastTotal);
+				Log(LOG_ERROR, "Actual KwH counter (%f) less then last Counter (%f)!", kWhCounter, LastTotal);
 				return;
 			}
 		}
@@ -646,12 +639,13 @@ namespace http {
 			}
 
 			std::string idx = request::findValue(&req, "idx");
-			if (idx == "") {
+			if (idx.empty())
+			{
 				return;
 			}
 			int hardwareID = atoi(idx.c_str());
 			CDomoticzHardwareBase *pHardware = m_mainworker.GetHardware(hardwareID);
-			if (pHardware != NULL)
+			if (pHardware != nullptr)
 			{
 				if (pHardware->HwdType == HTYPE_SBFSpot)
 				{
@@ -660,5 +654,5 @@ namespace http {
 				}
 			}
 		}
-	}
-}
+	} // namespace server
+} // namespace http
