@@ -134,26 +134,26 @@ HEATBEAT_COUNT, UPDATE_MASTER_COUNT and GPIO_POLL_MSEC are related.
 Set values so that that heartbeat occurs every 10 seconds and update
 master occurs once, 30 seconds after startup.
 */
-#define HEARTBEAT_COUNT		40
+#define HEARTBEAT_COUNT 40
 #define UPDATE_MASTER_COUNT 120
-#define DB_UPDATE_DELAY		4
-#define GPIO_POLL_MSEC		250
+#define DB_UPDATE_DELAY 4
+#define GPIO_POLL_MSEC 250
 
-#define GPIO_IN				0
-#define GPIO_OUT			1
-#define GPIO_LOW			0
-#define GPIO_HIGH			1
-#define GPIO_EDGE_NONE		0
-#define GPIO_EDGE_RISING	1
-#define GPIO_EDGE_FALLING	2
-#define GPIO_EDGE_BOTH		3
-#define GPIO_EDGE_UNKNOWN	-1
-#define GPIO_PIN_MIN		0
-#define GPIO_PIN_MAX		1023
-#define GPIO_MAX_VALUE_SIZE	16
-#define GPIO_MAX_PATH		64
-#define GPIO_PATH			"/sys/class/gpio/gpio"
-#define GPIO_DEVICE_ID_BASE	0x030E0E00
+#define GPIO_IN 0
+#define GPIO_OUT 1
+#define GPIO_LOW 0
+#define GPIO_HIGH 1
+#define GPIO_EDGE_NONE 0
+#define GPIO_EDGE_RISING 1
+#define GPIO_EDGE_FALLING 2
+#define GPIO_EDGE_BOTH 3
+#define GPIO_EDGE_UNKNOWN -1
+#define GPIO_PIN_MIN 0
+#define GPIO_PIN_MAX 1023
+#define GPIO_MAX_VALUE_SIZE 16
+#define GPIO_MAX_PATH 64
+#define GPIO_PATH "/sys/class/gpio/gpio"
+#define GPIO_DEVICE_ID_BASE 0x030E0E00
 
 std::vector<gpio_info> CSysfsGpio::m_saved_state;
 int CSysfsGpio::m_sysfs_hwdid;
@@ -171,17 +171,13 @@ CSysfsGpio::CSysfsGpio(const int ID, const int AutoConfigureDevices, const int D
 	m_maxfd = 0;
 }
 
-CSysfsGpio::~CSysfsGpio(void)
-{
-}
-
 bool CSysfsGpio::StartHardware()
 {
 	RequestStart();
 
 	Init();
 
-	m_thread = std::make_shared<std::thread>(&CSysfsGpio::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 
@@ -202,7 +198,6 @@ bool CSysfsGpio::StopHardware()
 	}
 	catch (...)
 	{
-
 	}
 	try
 	{
@@ -214,7 +209,6 @@ bool CSysfsGpio::StopHardware()
 	}
 	catch (...)
 	{
-
 	}
 
 	m_bIsStarted = false;
@@ -224,20 +218,18 @@ bool CSysfsGpio::StopHardware()
 bool CSysfsGpio::WriteToHardware(const char *pdata, const unsigned char length)
 {
 	bool bOk = false;
-	const tRBUF *pSen = reinterpret_cast<const tRBUF*>(pdata);
+	const tRBUF *pSen = reinterpret_cast<const tRBUF *>(pdata);
 	unsigned char packettype = pSen->ICMND.packettype;
 	int gpio_pin = pSen->LIGHTING2.unitcode;
 
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		if ((m_saved_state[i].pin_number == gpio_pin) &&
-			(m_saved_state[i].direction == GPIO_OUT) &&
-			(packettype == pTypeLighting2))
+		if ((s.pin_number == gpio_pin) && (s.direction == GPIO_OUT) && (packettype == pTypeLighting2))
 		{
 			int state = pSen->LIGHTING2.cmnd == light2_sOn ? GPIO_HIGH : GPIO_LOW;
 			GpioWrite(gpio_pin, state);
-			m_saved_state[i].db_state = state;
-			m_saved_state[i].value = state;
+			s.db_state = state;
+			s.value = state;
 			bOk = true;
 			break;
 		}
@@ -254,9 +246,9 @@ void CSysfsGpio::Do_Work()
 	{
 		counter++;
 
-		if (counter % HEARTBEAT_COUNT == 0)	/* Heartbeat maintenance */
+		if (counter % HEARTBEAT_COUNT == 0) /* Heartbeat maintenance */
 		{
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if (m_polling_enabled)
@@ -267,15 +259,15 @@ void CSysfsGpio::Do_Work()
 
 		if (bUpdateMaster)
 		{
-			if (counter == UPDATE_MASTER_COUNT)	/* only executes once, and only if we have a master/slave configuration */
+			if (counter == UPDATE_MASTER_COUNT) /* only executes once, and only if we have a master/slave configuration */
 			{
 				bUpdateMaster = false;
-				std::vector<std::vector<std::string> > result;
+				std::vector<std::vector<std::string>> result;
 				result = m_sql.safe_query("SELECT ID FROM Users WHERE (RemoteSharing==1) AND (Active==1)");
 
 				if (!result.empty())
 				{
-					_log.Log(LOG_STATUS, "Sysfs GPIO: Update master devices");
+					Log(LOG_STATUS, "Update master devices");
 					UpdateDomoticzInputs(true);
 				}
 			}
@@ -293,16 +285,16 @@ void CSysfsGpio::Do_Work()
 	}
 
 	/* termination, close all open fd's */
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		if (m_saved_state[i].read_value_fd != -1)
+		if (s.read_value_fd != -1)
 		{
-			close(m_saved_state[i].read_value_fd);
-			m_saved_state[i].read_value_fd = -1;
+			close(s.read_value_fd);
+			s.read_value_fd = -1;
 		}
 	}
 
-	_log.Log(LOG_STATUS, "Sysfs GPIO: Worker stopped");
+	Log(LOG_STATUS, "Worker stopped");
 }
 
 void CSysfsGpio::EdgeDetectThread()
@@ -330,38 +322,38 @@ void CSysfsGpio::EdgeDetectThread()
 	FD_ZERO(&m_rfds);
 	m_maxfd = 0;
 
-	for (int i = 0; i < m_saved_state.size(); i++) /* setup gpio pins */
+	for (auto &s : m_saved_state) /* setup gpio pins */
 	{
-		if ((m_saved_state[i].direction == GPIO_IN) && (m_saved_state[i].edge != GPIO_EDGE_NONE))
+		if ((s.direction == GPIO_IN) && (s.edge != GPIO_EDGE_NONE))
 		{
-			fd = GpioOpenRw(m_saved_state[i].pin_number);
-			m_saved_state[i].edge_fd = fd; /* store file descriptor, closed after stoprequested */
+			fd = GpioOpenRw(s.pin_number);
+			s.edge_fd = fd; /* store file descriptor, closed after stoprequested */
 
 			if ((fd != -1) && (fd <= FD_SETSIZE))
 			{
 				FD_SET(fd, &m_rfds);
 				m_maxfd = (m_maxfd > fd ? m_maxfd : fd);
-				GpioWrite(m_saved_state[i].pin_number, 1); /* enable interrupts */
+				GpioWrite(s.pin_number, 1); /* enable interrupts */
 			}
 		}
 		else
 		{
-			m_saved_state[i].edge_fd = -1;
+			s.edge_fd = -1;
 		}
 	}
 
-	_log.Log(LOG_STATUS, "Sysfs GPIO: Edge detection started");
+	Log(LOG_STATUS, "Edge detection started");
 
 	while (!IsStopRequested(0)) /* detect gpio state changes */
 	{
-		tv.tv_sec = 1;	// Set select timeout to 1 second.
+		tv.tv_sec = 1; // Set select timeout to 1 second.
 		tv.tv_usec = 0;
 		memcpy(&tmp_fds, &m_rfds, sizeof(tmp_fds));
 
 		//-------------------------------------------------------------------
 		//	Wait for GPIO interrupt.
 		//
-		int retval = select(m_maxfd + 1, NULL, NULL, &tmp_fds, &tv);
+		int retval = select(m_maxfd + 1, nullptr, nullptr, &tmp_fds, &tv);
 
 		if (IsStopRequested(0))
 		{
@@ -377,9 +369,7 @@ void CSysfsGpio::EdgeDetectThread()
 
 			for (int i = 0; i < m_saved_state.size(); i++)
 			{
-				if ((FD_ISSET(m_saved_state[i].edge_fd, &tmp_fds) &&
-					(m_saved_state[i].direction == GPIO_IN) &&
-					(m_saved_state[i].edge != GPIO_EDGE_NONE)))
+				if ((FD_ISSET(m_saved_state[i].edge_fd, &tmp_fds) && (m_saved_state[i].direction == GPIO_IN) && (m_saved_state[i].edge != GPIO_EDGE_NONE)))
 				{
 					int value = GpioReadFd(m_saved_state[i].edge_fd);
 					GpioSaveState(i, value);
@@ -408,16 +398,16 @@ void CSysfsGpio::EdgeDetectThread()
 		}
 	}
 
-	for (int i = 0; i < m_saved_state.size(); i++) /* close all open edge detect fd's */
+	for (auto &s : m_saved_state) /* close all open edge detect fd's */
 	{
-		if (m_saved_state[i].edge_fd > 0)
+		if (s.edge_fd > 0)
 		{
-			close(m_saved_state[i].edge_fd);
-			m_saved_state[i].edge_fd = -1;
+			close(s.edge_fd);
+			s.edge_fd = -1;
 		}
 	}
 
-	_log.Log(LOG_STATUS, "Sysfs GPIO: Edge detection stopped");
+	Log(LOG_STATUS, "Edge detection stopped");
 }
 
 void CSysfsGpio::Init()
@@ -440,8 +430,8 @@ void CSysfsGpio::Init()
 	m_Packet.LIGHTING2.unitcode = 0;
 	m_Packet.LIGHTING2.id1 = (id >> 24) & 0xFF;
 	m_Packet.LIGHTING2.id2 = (id >> 16) & 0xFF;
-	m_Packet.LIGHTING2.id3 = (id >> 8)  & 0xFF;
-	m_Packet.LIGHTING2.id4 = (id >> 0)  & 0xFF;
+	m_Packet.LIGHTING2.id3 = (id >> 8) & 0xFF;
+	m_Packet.LIGHTING2.id4 = (id >> 0) & 0xFF;
 	m_Packet.LIGHTING2.cmnd = 0;
 	m_Packet.LIGHTING2.level = 0;
 	m_Packet.LIGHTING2.filler = 0;
@@ -456,26 +446,21 @@ void CSysfsGpio::Init()
 
 	UpdateGpioOutputs();
 
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		snprintf(path, GPIO_MAX_PATH, "%s%d/value", GPIO_PATH, m_saved_state[i].pin_number);
-		m_saved_state[i].read_value_fd = open(path, O_RDONLY);
-		if ((m_saved_state[i].direction == GPIO_IN) ? input_count++ : output_count++);
+		snprintf(path, GPIO_MAX_PATH, "%s%d/value", GPIO_PATH, s.pin_number);
+		s.read_value_fd = open(path, O_RDONLY);
+		if ((s.direction == GPIO_IN) ? input_count++ : output_count++)
+			;
 
 		/*	Enable polling if at least one input edge is set to NONE or is INVALID. */
-		if	(!m_polling_enabled &&
-			(m_saved_state[i].direction == GPIO_IN) &&
-			((m_saved_state[i].edge == GPIO_EDGE_NONE) || (m_saved_state[i].edge == GPIO_EDGE_UNKNOWN)))
+		if (!m_polling_enabled && (s.direction == GPIO_IN) && ((s.edge == GPIO_EDGE_NONE) || (s.edge == GPIO_EDGE_UNKNOWN)))
 		{
 			m_polling_enabled = true;
 		}
 
 		/*	Enable interrupts if at least one input edge is set to RISING FALLING or BOTH. */
-		if	(!m_interrupts_enabled &&
-			(m_saved_state[i].direction == GPIO_IN) &&
-			((m_saved_state[i].edge == GPIO_EDGE_RISING) ||
-			(m_saved_state[i].edge == GPIO_EDGE_FALLING) ||
-			(m_saved_state[i].edge == GPIO_EDGE_BOTH)))
+		if (!m_interrupts_enabled && (s.direction == GPIO_IN) && ((s.edge == GPIO_EDGE_RISING) || (s.edge == GPIO_EDGE_FALLING) || (s.edge == GPIO_EDGE_BOTH)))
 		{
 			m_interrupts_enabled = true;
 		}
@@ -483,16 +468,12 @@ void CSysfsGpio::Init()
 
 	UpdateDomoticzInputs(false); /* Make sure database inputs are in sync with actual hardware */
 
-	_log.Log(LOG_STATUS, "Sysfs GPIO: Startup - polling:%s interrupts:%s debounce:%dmsec inputs:%d outputs:%d",
-		m_polling_enabled ? "yes":"no",
-		m_interrupts_enabled ? "yes":"no",
-		m_debounce_msec,
-		input_count,
-		output_count);
+	Log(LOG_STATUS, "Startup - polling:%s interrupts:%s debounce:%dmsec inputs:%d outputs:%d", m_polling_enabled ? "yes" : "no", m_interrupts_enabled ? "yes" : "no", m_debounce_msec, input_count,
+	    output_count);
 
 	if (m_interrupts_enabled)
 	{
-		m_edge_thread = std::make_shared<std::thread>(&CSysfsGpio::EdgeDetectThread, this);
+		m_edge_thread = std::make_shared<std::thread>([this] { EdgeDetectThread(); });
 		SetThreadName(m_edge_thread->native_handle(), "SysfsGpio_Edge");
 	}
 }
@@ -536,13 +517,12 @@ void CSysfsGpio::FindGpioExports()
 
 void CSysfsGpio::PollGpioInputs(bool PollOnce)
 {
-	if (m_saved_state.size())
+	if (!m_saved_state.empty())
 	{
 		for (int i = 0; i < m_saved_state.size(); i++)
 		{
-			if ((m_saved_state[i].direction == GPIO_IN) &&
-				(m_saved_state[i].read_value_fd != -1) &&
-				(PollOnce || (m_saved_state[i].edge == GPIO_EDGE_NONE) || (m_saved_state[i].edge == GPIO_EDGE_UNKNOWN)))
+			if ((m_saved_state[i].direction == GPIO_IN) && (m_saved_state[i].read_value_fd != -1) &&
+			    (PollOnce || (m_saved_state[i].edge == GPIO_EDGE_NONE) || (m_saved_state[i].edge == GPIO_EDGE_UNKNOWN)))
 			{
 				GpioSaveState(i, GpioReadFd(m_saved_state[i].read_value_fd));
 			}
@@ -552,21 +532,19 @@ void CSysfsGpio::PollGpioInputs(bool PollOnce)
 
 void CSysfsGpio::CreateDomoticzDevices()
 {
-	std::vector<std::vector<std::string> > result;
+	std::vector<std::vector<std::string>> result;
 	std::vector<std::string> deviceid;
 
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		bool  createNewDevice = false;
+		bool createNewDevice = false;
 		deviceid = GetGpioDeviceId();
 
-		if (m_saved_state[i].direction == GPIO_IN)
+		if (s.direction == GPIO_IN)
 		{
 			/* Input */
 
-			result = m_sql.safe_query("SELECT nValue,Options FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-				m_HwdID,
-				m_saved_state[i].pin_number);
+			result = m_sql.safe_query("SELECT nValue,Options FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_HwdID, s.pin_number);
 
 			if (result.empty())
 			{
@@ -581,16 +559,14 @@ void CSysfsGpio::CreateDomoticzDevices()
 					if (sd[1].empty())
 					{
 						/* update manual created device */
-						m_saved_state[i].request_update = 1;
+						s.request_update = 1;
 						UpdateDomoticzDatabase();
 					}
 					else
 					{
 						if (atoi(sd[1].c_str()) != GPIO_IN) /* device was not an input, delete it */
 						{
-							m_sql.safe_query(
-								"DELETE FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-								m_HwdID, m_saved_state[i].pin_number);
+							m_sql.safe_query("DELETE FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_HwdID, s.pin_number);
 
 							createNewDevice = true;
 						}
@@ -601,19 +577,17 @@ void CSysfsGpio::CreateDomoticzDevices()
 			if (createNewDevice)
 			{
 				/* create new input device */
-				m_sql.safe_query(
-					"INSERT INTO DeviceStatus (HardwareID, DeviceID, Unit, Type, SubType, SwitchType, Used, SignalLevel, BatteryLevel, Name, nValue, sValue, Options) "
-					"VALUES (%d,'%q',%d, %d, %d, %d, 0, 12, 255, '%q', %d, ' ', '0')",
-					m_HwdID, deviceid[0].c_str(), m_saved_state[i].pin_number, pTypeLighting2, sTypeAC, int(STYPE_Contact), "Input", m_saved_state[i].value);
+				m_sql.safe_query("INSERT INTO DeviceStatus (HardwareID, DeviceID, Unit, Type, SubType, SwitchType, Used, "
+						 "SignalLevel, BatteryLevel, Name, nValue, sValue, Options) "
+						 "VALUES (%d,'%q',%d, %d, %d, %d, 0, 12, 255, '%q', %d, ' ', '0')",
+						 m_HwdID, deviceid[0].c_str(), s.pin_number, pTypeLighting2, sTypeAC, int(STYPE_Contact), "Input", s.value);
 			}
 		}
 		else
 		{
 			/* Output */
 
-			result = m_sql.safe_query("SELECT nValue,Options FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-				m_HwdID,
-				m_saved_state[i].pin_number);
+			result = m_sql.safe_query("SELECT nValue,Options FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_HwdID, s.pin_number);
 
 			if (result.empty())
 			{
@@ -628,22 +602,20 @@ void CSysfsGpio::CreateDomoticzDevices()
 					if (sd[1].empty())
 					{
 						/* update manual created output device */
-						m_saved_state[i].request_update = 1;
+						s.request_update = 1;
 						UpdateDomoticzDatabase();
 					}
 					else
 					{
 						if ((atoi(sd[1].c_str()) != GPIO_OUT)) /* device was not an output, delete it */
 						{
-							m_sql.safe_query(
-								"DELETE FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-								m_HwdID, m_saved_state[i].pin_number);
+							m_sql.safe_query("DELETE FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_HwdID, s.pin_number);
 
 							createNewDevice = true;
 						}
 						else
 						{
-							GpioWrite(m_saved_state[i].pin_number, atoi(sd[0].c_str()));
+							GpioWrite(s.pin_number, atoi(sd[0].c_str()));
 						}
 					}
 				}
@@ -652,10 +624,10 @@ void CSysfsGpio::CreateDomoticzDevices()
 			if (createNewDevice)
 			{
 				/* create new output device */
-				m_sql.safe_query(
-					"INSERT INTO DeviceStatus (HardwareID, DeviceID, Unit, Type, SubType, SwitchType, Used, SignalLevel, BatteryLevel, Name, nValue, sValue, Options) "
-					"VALUES (%d,'%q',%d, %d, %d, %d, 0, 12, 255, '%q', %d, ' ', '1')",
-					m_HwdID, deviceid[0].c_str(), m_saved_state[i].pin_number, pTypeLighting2, sTypeAC, int(STYPE_OnOff), "Output", m_saved_state[i].value);
+				m_sql.safe_query("INSERT INTO DeviceStatus (HardwareID, DeviceID, Unit, Type, SubType, SwitchType, Used, "
+						 "SignalLevel, BatteryLevel, Name, nValue, sValue, Options) "
+						 "VALUES (%d,'%q',%d, %d, %d, %d, 0, 12, 255, '%q', %d, ' ', '1')",
+						 m_HwdID, deviceid[0].c_str(), s.pin_number, pTypeLighting2, sTypeAC, int(STYPE_OnOff), "Output", s.value);
 			}
 		}
 	}
@@ -663,64 +635,58 @@ void CSysfsGpio::CreateDomoticzDevices()
 
 void CSysfsGpio::UpdateDomoticzDatabase()
 {
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		if (m_saved_state[i].request_update == 1)
+		if (s.request_update == 1)
 		{
-			std::vector<std::vector<std::string> > result = m_sql.safe_query("SELECT nValue,Options FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-				m_HwdID,
-				m_saved_state[i].pin_number);
+			std::vector<std::vector<std::string>> result = m_sql.safe_query("SELECT nValue,Options FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_HwdID, s.pin_number);
 
 			if (!result.empty())
 			{
-				//std::vector<std::string> sd = result[0];
-				m_saved_state[i].value = GpioRead(m_saved_state[i].pin_number, "value");
+				// std::vector<std::string> sd = result[0];
+				s.value = GpioRead(s.pin_number, "value");
 
-				m_sql.safe_query(
-					"UPDATE DeviceStatus SET nValue=%d,Options=%d WHERE (HardwareID==%d) AND (Unit==%d)",
-					m_saved_state[i].value, m_saved_state[i].direction, m_HwdID, m_saved_state[i].pin_number);
+				m_sql.safe_query("UPDATE DeviceStatus SET nValue=%d,Options=%d WHERE (HardwareID==%d) AND (Unit==%d)", s.value, s.direction, m_HwdID, s.pin_number);
 
-				m_saved_state[i].db_state = m_saved_state[i].value;
-				m_saved_state[i].id_valid = -1;
+				s.db_state = s.value;
+				s.id_valid = -1;
 			}
 
-			m_saved_state[i].request_update = -1;
+			s.request_update = -1;
 		}
 	}
 }
 
 void CSysfsGpio::UpdateDomoticzInputs(bool forceUpdate)
 {
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		if ((m_saved_state[i].direction == GPIO_IN) && (m_saved_state[i].value != -1))
+		if ((s.direction == GPIO_IN) && (s.value != -1))
 		{
-			int		state = GPIO_LOW;
+			int state = GPIO_LOW;
 
-			if (m_saved_state[i].active_low)
+			if (s.active_low)
 			{
-				if (m_saved_state[i].value == GPIO_LOW)
+				if (s.value == GPIO_LOW)
 				{
 					state = GPIO_HIGH;
 				}
 			}
 			else
 			{
-				if (m_saved_state[i].value == GPIO_HIGH)
+				if (s.value == GPIO_HIGH)
 				{
 					state = GPIO_HIGH;
 				}
 			}
 
-			if ((m_saved_state[i].db_state != state) || (forceUpdate))
+			if ((s.db_state != state) || (forceUpdate))
 			{
-				bool	updateDatabase = false;
-				bool	log_db_change = false;
-				std::vector< std::vector<std::string> > result = m_sql.safe_query("SELECT nValue,Used FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-					m_HwdID,
-					m_saved_state[i].pin_number);
+				bool updateDatabase = false;
+				bool log_db_change = false;
+				std::vector<std::vector<std::string>> result = m_sql.safe_query("SELECT nValue,Used FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_HwdID, s.pin_number);
 
-				if ((!result.empty()) && (result.size() > 0))
+				if ((!result.empty()) && (!result.empty()))
 				{
 					std::vector<std::string> sd = result[0];
 
@@ -742,7 +708,7 @@ void CSysfsGpio::UpdateDomoticzInputs(bool forceUpdate)
 							updateDatabase = true;
 						}
 
-						m_saved_state[i].db_state = state; /* save new database state */
+						s.db_state = state; /* save new database state */
 					}
 				}
 
@@ -759,16 +725,14 @@ void CSysfsGpio::UpdateDomoticzInputs(bool forceUpdate)
 						m_Packet.LIGHTING2.level = 0;
 					}
 
-					UpdateDeviceID(m_saved_state[i].pin_number);
-					m_Packet.LIGHTING2.unitcode = (char)m_saved_state[i].pin_number;
+					UpdateDeviceID(s.pin_number);
+					m_Packet.LIGHTING2.unitcode = (char)s.pin_number;
 					m_Packet.LIGHTING2.seqnbr++;
-					sDecodeRXMessage(this, (const unsigned char *)&m_Packet.LIGHTING2, "Input", 255);
+					sDecodeRXMessage(this, (const unsigned char *)&m_Packet.LIGHTING2, "Input", 255, m_Name.c_str());
 
 					if (log_db_change)
 					{
-						_log.Log(LOG_STATUS, "Sysfs GPIO: gpio%d new state = %s",
-							m_saved_state[i].pin_number,
-							state ? "on" : "off");
+						Log(LOG_STATUS, "gpio%d new state = %s", s.pin_number, state ? "on" : "off");
 					}
 				}
 			}
@@ -799,11 +763,9 @@ void CSysfsGpio::UpdateDeviceID(int pin)
 		if (m_saved_state[index].id_valid == -1)
 		{
 			std::string sdeviceid;
-			std::vector< std::vector<std::string> > result = m_sql.safe_query("SELECT DeviceID FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-				m_HwdID,
-				pin);
+			std::vector<std::vector<std::string>> result = m_sql.safe_query("SELECT DeviceID FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_HwdID, pin);
 
-			if ((!result.empty() && (result.size() > 0)))
+			if ((!result.empty() && (!result.empty())))
 			{
 				/* use database device id */
 				std::vector<std::string> sd = result[0];
@@ -817,10 +779,10 @@ void CSysfsGpio::UpdateDeviceID(int pin)
 			}
 
 			/* extract hex device sub-id's */
-			m_saved_state[index].id1 = strtol(sdeviceid.substr(0, 1).c_str(), NULL, 16) & 0xFF;
-			m_saved_state[index].id2 = strtol(sdeviceid.substr(1, 2).c_str(), NULL, 16) & 0xFF;
-			m_saved_state[index].id3 = strtol(sdeviceid.substr(3, 2).c_str(), NULL, 16) & 0xFF;
-			m_saved_state[index].id4 = strtol(sdeviceid.substr(5, 2).c_str(), NULL, 16) & 0xFF;
+			m_saved_state[index].id1 = strtol(sdeviceid.substr(0, 1).c_str(), nullptr, 16) & 0xFF;
+			m_saved_state[index].id2 = strtol(sdeviceid.substr(1, 2).c_str(), nullptr, 16) & 0xFF;
+			m_saved_state[index].id3 = strtol(sdeviceid.substr(3, 2).c_str(), nullptr, 16) & 0xFF;
+			m_saved_state[index].id4 = strtol(sdeviceid.substr(5, 2).c_str(), nullptr, 16) & 0xFF;
 			m_saved_state[index].id_valid = 1;
 		}
 
@@ -836,24 +798,22 @@ void CSysfsGpio::UpdateGpioOutputs()
 {
 	/* make sure actual gpio output values match database */
 
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		if (m_saved_state[i].direction == GPIO_OUT)
+		if (s.direction == GPIO_OUT)
 		{
-			std::vector<std::vector<std::string> > result = m_sql.safe_query("SELECT nValue,Used FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-				m_HwdID,
-				m_saved_state[i].pin_number);
+			std::vector<std::vector<std::string>> result = m_sql.safe_query("SELECT nValue,Used FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_HwdID, s.pin_number);
 
-			if ((!result.empty()) && (result.size() > 0))
+			if ((!result.empty()) && (!result.empty()))
 			{
 				std::vector<std::string> sd = result[0];
-				m_saved_state[i].db_state = atoi(sd[0].c_str());
+				s.db_state = atoi(sd[0].c_str());
 
 				if (atoi(sd[1].c_str()))
 				{
 					/* device is used, update gpio output pin */
-					GpioWrite(m_saved_state[i].pin_number, m_saved_state[i].db_state);
-					m_saved_state[i].value = m_saved_state[i].db_state;
+					GpioWrite(s.pin_number, s.db_state);
+					s.value = s.db_state;
 				}
 			}
 		}
@@ -875,32 +835,26 @@ std::vector<std::string> CSysfsGpio::GetGpioDeviceId()
 //---------------------------------------------------------------------------
 //	sysfs gpio helper functions
 //
-int CSysfsGpio::GetReadResult(int bytecount, char* value_str)
+int CSysfsGpio::GetReadResult(int bytecount, char *value_str)
 {
 	int retval = -1;
 
 	switch (bytecount)
 	{
 		case -1:
-		case  0:
-		case  1:
-		{
+		case 0:
+		case 1: {
 			break;
 		}
 
-		default:
-		{
-			if ((memcmp("0", value_str, strlen("0")) == 0) ||
-				(memcmp("in", value_str, strlen("in")) == 0) ||
-				(memcmp("none", value_str, strlen("none")) == 0))
+		default: {
+			if ((memcmp("0", value_str, strlen("0")) == 0) || (memcmp("in", value_str, strlen("in")) == 0) || (memcmp("none", value_str, strlen("none")) == 0))
 			{
 				retval = 0;
 				break;
 			}
 
-			if ((memcmp("1", value_str, strlen("1")) == 0) ||
-				(memcmp("out", value_str, strlen("out")) == 0) ||
-				(memcmp("rising", value_str, strlen("rising")) == 0))
+			if ((memcmp("1", value_str, strlen("1")) == 0) || (memcmp("out", value_str, strlen("out")) == 0) || (memcmp("rising", value_str, strlen("rising")) == 0))
 			{
 				retval = 1;
 				break;
@@ -935,7 +889,7 @@ int CSysfsGpio::GpioRead(int gpio_pin, const char *param)
 
 	if (fd == -1)
 	{
-		return(-1);
+		return (-1);
 	}
 
 	bytecount = read(fd, value_str, GPIO_MAX_VALUE_SIZE);
@@ -944,10 +898,10 @@ int CSysfsGpio::GpioRead(int gpio_pin, const char *param)
 	if (-1 == bytecount)
 	{
 		close(fd);
-		return(-1);
+		return (-1);
 	}
 
-	return(GetReadResult(bytecount, &value_str[0]));
+	return (GetReadResult(bytecount, &value_str[0]));
 }
 
 int CSysfsGpio::GpioReadFd(int fd)
@@ -957,7 +911,7 @@ int CSysfsGpio::GpioReadFd(int fd)
 
 	if (fd == -1)
 	{
-		return(-1);
+		return (-1);
 	}
 
 	if (lseek(fd, 0, SEEK_SET) == -1)
@@ -967,7 +921,7 @@ int CSysfsGpio::GpioReadFd(int fd)
 
 	bytecount = read(fd, value_str, GPIO_MAX_VALUE_SIZE);
 
-	return(GetReadResult(bytecount, &value_str[0]));
+	return (GetReadResult(bytecount, &value_str[0]));
 }
 
 int CSysfsGpio::GpioWrite(int gpio_pin, int value)
@@ -980,17 +934,17 @@ int CSysfsGpio::GpioWrite(int gpio_pin, int value)
 
 	if (fd == -1)
 	{
-		return(-1);
+		return (-1);
 	}
 
 	if (1 != write(fd, value ? "1" : "0", 1))
 	{
 		close(fd);
-		return(-1);
+		return (-1);
 	}
 
 	close(fd);
-	return(0);
+	return (0);
 }
 
 int CSysfsGpio::GpioOpenRw(int gpio_pin)
@@ -1000,7 +954,7 @@ int CSysfsGpio::GpioOpenRw(int gpio_pin)
 	snprintf(path, GPIO_MAX_PATH, "%s%d/value", GPIO_PATH, gpio_pin);
 	int fd = open(path, O_RDWR);
 
-	return(fd);
+	return (fd);
 }
 
 //---------------------------------------------------------------------------
@@ -1010,16 +964,14 @@ std::vector<int> CSysfsGpio::GetGpioIds()
 {
 	std::vector<int> gpio_ids;
 
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		std::vector<std::vector<std::string> > result = m_sql.safe_query("SELECT ID, Used FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-			m_sysfs_hwdid,
-			m_saved_state[i].pin_number);
+		std::vector<std::vector<std::string>> result = m_sql.safe_query("SELECT ID, Used FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_sysfs_hwdid, s.pin_number);
 
 		if (result.empty())
 		{
 			/* add pin to the list only if it does not exist in the db */
-			gpio_ids.push_back(m_saved_state[i].pin_number);
+			gpio_ids.push_back(s.pin_number);
 		}
 	}
 
@@ -1030,17 +982,15 @@ std::vector<std::string> CSysfsGpio::GetGpioNames()
 {
 	std::vector<std::string> gpio_names;
 
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		std::vector<std::vector<std::string> > result = m_sql.safe_query("SELECT ID, Used FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)",
-			m_sysfs_hwdid,
-			m_saved_state[i].pin_number);
+		std::vector<std::vector<std::string>> result = m_sql.safe_query("SELECT ID, Used FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit==%d)", m_sysfs_hwdid, s.pin_number);
 
 		if (result.empty())
 		{
 			/* add name to the list only if it does not exist in the db */
 			char name[32];
-			snprintf(name, sizeof(name), "gpio%d-%s", m_saved_state[i].pin_number, m_saved_state[i].direction ? "output" : "input");
+			snprintf(name, sizeof(name), "gpio%d-%s", s.pin_number, s.direction ? "output" : "input");
 			gpio_names.push_back(name);
 		}
 	}
@@ -1050,11 +1000,11 @@ std::vector<std::string> CSysfsGpio::GetGpioNames()
 
 void CSysfsGpio::RequestDbUpdate(int pin)
 {
-	for (int i = 0; i < m_saved_state.size(); i++)
+	for (auto &s : m_saved_state)
 	{
-		if (m_saved_state[i].pin_number == pin)
+		if (s.pin_number == pin)
 		{
-			m_saved_state[i].request_update = 1;
+			s.request_update = 1;
 		}
 	}
 
