@@ -4,17 +4,19 @@
 
 class CWinddelen : public CDomoticzHardwareBase
 {
-public:
-	CWinddelen(const int ID, const std::string &IPAddress, const unsigned short usTotParts, const unsigned short usMillID);
-	~CWinddelen(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-private:
+      public:
+	CWinddelen(int ID, const std::string &IPAddress, unsigned short usTotParts, unsigned short usMillID);
+	~CWinddelen() override = default;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+
+      private:
 	void Init();
 	bool StartHardware() override;
 	bool StopHardware() override;
 	void Do_Work();
 	void GetMeterDetails();
-private:
+
+      private:
 	std::string m_szMillName;
 	unsigned short m_usMillID;
 	unsigned short m_usTotParts;
@@ -22,4 +24,3 @@ private:
 
 	std::shared_ptr<std::thread> m_thread;
 };
-
