@@ -1,5 +1,4 @@
 #include "stdafx.h"
-#include "../hardware/hardwaretypes.h"
 #include "../main/localtime_r.h"
 #include "../main/Logger.h"
 #include "../main/mainworker.h"
@@ -8,9 +7,11 @@
 #include "../main/WebServer.h"
 #include "../webserver/cWebem.h"
 #include "../main/json_helper.h"
+#include "hardwaretypes.h"
 #include "XiaomiGateway.h"
 #include <openssl/aes.h>
 #include <boost/asio.hpp>
+#include "XiaomiDeviceSupport.h"
 
 #ifndef WIN32
 #include <ifaddrs.h>
@@ -41,7 +42,10 @@ typedef enum
 	GATEWAY_SOUND_VOLUME_CONTROL,	    //  7, Xiaomi Gateway Volume
 	SELECTOR_WIRED_WALL_SINGLE,	    //  8, Xiaomi Wired Single Wall Switch
 	SELECTOR_WIRED_WALL_DUAL_CHANNEL_0, //  9, Xiaomi Wired Dual Wall Switch Channel 0
-	SELECTOR_WIRED_WALL_DUAL_CHANNEL_1  // 10, Xiaomi Wired Dual Wall Switch Channel 1
+	SELECTOR_WIRED_WALL_DUAL_CHANNEL_1, // 10, Xiaomi Wired Dual Wall Switch Channel 1
+	ACT_RELAIS_CHANNEL_0,		    // 11, Xiaomi Relais Channel 0
+	ACT_RELAIS_CHANNEL_1,		    // 12, Xiaomi Relais Channel 1
+	ACT_LIGHT			    // 13, Xiaomi Light bulb
 } XiaomiUnitCode;
 
 /****************************************************************************
@@ -63,6 +67,7 @@ typedef enum
 // Xiaomi Wireless Single Wall Switch | WXKG03LM
 #define MODEL_SELECTOR_WIRELESS_WALL_SINGLE_1 "86sw1"
 #define MODEL_SELECTOR_WIRELESS_WALL_SINGLE_2 "remote.b186acn01"
+#define MODEL_SELECTOR_WIRELESS_WALL_SINGLE_3 "remote.b186acn02"
 #define NAME_SELECTOR_WIRELESS_WALL_SINGLE "Xiaomi Wireless Single Wall Switch"
 
 // Xiaomi Wireless Dual Wall Switch | WXKG02LM
@@ -158,9 +163,11 @@ typedef enum
 #define MODEL_ACT_LIGHT "light.aqcb02"
 #define NAME_ACT_LIGHT "Light bulb"
 
-// [NEW] Aqara Aqara Wireless Relay Controller (2 Channels) | LLKZMK11LM // TODO: not implemented yet
+// Xiaomi Aqara Wireless Relay Controller (2 Channels) | LLKZMK11LM
 #define MODEL_ACT_RELAIS "relay.c2acn01"
-#define NAME_ACT_RELAIS "Aqara Wireless Relay Controller"
+//#define NAME_ACT_RELAIS "Aqara Wireless Relay Controller"
+#define NAME_ACT_RELAIS_CHANNEL_0 "Aqara Wireless Relay Controller - Channel 1"
+#define NAME_ACT_RELAIS_CHANNEL_1 "Aqara Wireless Relay Controller - Channel 2"
 
 /****************************************************************************
  ********************************* GATEWAY **********************************
@@ -325,6 +332,12 @@ XiaomiGateway::XiaomiGateway(const int ID)
 	m_HwdID = ID;
 	m_bDoRestart = false;
 	m_ListenPort9898 = false;
+	m_DeviceSupport = new XiaomiDeviceSupportHardcoded();
+}
+
+XiaomiGateway::~XiaomiGateway()
+{
+	delete m_DeviceSupport;
 }
 
 bool XiaomiGateway::WriteToHardware(const char *pdata, const unsigned char length)
@@ -362,7 +375,8 @@ bool XiaomiGateway::WriteToHardware(const char *pdata, const unsigned char lengt
 		cmdcommand = DetermineCommand(xcmd->cmnd);
 
 		if (xcmd->unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_SINGLE || xcmd->unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_DUAL_CHANNEL_0 ||
-		    xcmd->unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_DUAL_CHANNEL_1 || ((xcmd->subtype == sSwitchGeneralSwitch) && (xcmd->unitcode == XiaomiUnitCode::ACT_ONOFF_PLUG)))
+		    xcmd->unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_DUAL_CHANNEL_1 || ((xcmd->subtype == sSwitchGeneralSwitch) && (xcmd->unitcode == XiaomiUnitCode::ACT_ONOFF_PLUG)) ||
+		    xcmd->unitcode == XiaomiUnitCode::ACT_RELAIS_CHANNEL_0 || xcmd->unitcode == XiaomiUnitCode::ACT_RELAIS_CHANNEL_1 || xcmd->unitcode == XiaomiUnitCode::ACT_LIGHT)
 		{
 			message = R"({"cmd":"write","model":")" + cmddevice + R"(","sid":"158d00)" + sid + R"(","short_id":0,"data":"{\")" + cmdchannel + R"(\":\")" + cmdcommand +
 				  R"(\",\"key\":\"@gatewaykey\"}" })";
@@ -532,7 +546,7 @@ bool XiaomiGateway::SendMessageToGateway(const std::string &controlmessage)
 	boost::asio::ip::udp::endpoint remote_endpoint_;
 	remote_endpoint_ = boost::asio::ip::udp::endpoint(boost::asio::ip::address::from_string(m_GatewayIp), 9898);
 	socket_.send_to(boost::asio::buffer(*message1), remote_endpoint_);
-	sleep_milliseconds(150);
+	sleep_milliseconds(150); // TODO: reduce or remove sleep
 	std::array<char, 512> recv_buffer_;
 	memset(&recv_buffer_[0], 0, sizeof(recv_buffer_));
 #ifdef _DEBUG
@@ -960,6 +974,14 @@ bool XiaomiGateway::StartHardware()
 	{
 		m_IncludeVoltage = true;
 	}
+	XiaomiDeviceSupportUserVariable *deviceSupport = new XiaomiDeviceSupportUserVariable(m_sql, _log, "relay.c2acn01");
+	if (deviceSupport->LoadSIDsOk())
+	{
+		delete m_DeviceSupport;
+		m_DeviceSupport = deviceSupport;
+		Log(LOG_DEBUG_INT, "XiaomiDeviceSupportUserVariable loaded OK");
+	}
+
 	Log(LOG_STATUS, "XiaomiGateway (ID=%d): Delaying worker startup...", m_HwdID);
 	sleep_seconds(5);
 
@@ -1000,7 +1022,7 @@ void XiaomiGateway::Do_Work()
 	{
 		boost::asio::ip::udp::resolver resolver(io_service);
 		boost::asio::ip::udp::resolver::query query(boost::asio::ip::udp::v4(), m_GatewayIp, "");
-		boost::asio::ip::udp::resolver::iterator endpoints = resolver.resolve(query);
+		auto endpoints = resolver.resolve(query);
 		boost::asio::ip::udp::endpoint ep = *endpoints;
 		boost::asio::ip::udp::socket socket(io_service);
 		socket.connect(ep);
@@ -1204,7 +1226,7 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 
 		if (!TrueGateway)
 		{
-			_log.Log(LOG_ERROR, "XiaomiGateway: received data from  unregisted gateway!");
+			_log.Log(LOG_ERROR, "XiaomiGateway: received data from unregistered gateway!");
 			start_receive();
 			return;
 		}
@@ -1225,6 +1247,19 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 		std::string sid = root["sid"].asString();
 		std::string data = root["data"].asString();
 		int unitcode = 1;
+
+		if (model.empty())
+		{
+			XiaomiDeviceSupport *devicesupport = m_XiaomiGateway->GetDeviceSupport();
+			_log.Log(LOG_DEBUG_INT, "XiaomiGateway: model empty for '%s', trying DeviceSupport.", sid.c_str());
+			model = devicesupport->GetXiaomiDeviceModelByID(sid);
+			if (model.empty())
+			{
+				_log.Log(LOG_STATUS, "XiaomiGateway: model empty for '%s', and no match found by DeviceSupport. Add your device to the list in case it's supported.", sid.c_str());
+			}
+			_log.Log(LOG_DEBUG_INT, "XiaomiGateway: model lookup for '%s' found: '%s'", sid.c_str(), model.c_str());
+		}
+
 		if ((cmd == COMMAND_REPORT) || (cmd == COMMAND_READ_ACK) || (cmd == COMMAND_HEARTBEAT))
 		{
 			Json::Value root2;
@@ -1268,6 +1303,11 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 					type = STYPE_OnOff;
 					name = NAME_ACT_ONOFF_PLUG;
 				}
+				else if (model == MODEL_ACT_RELAIS)
+				{
+					type = STYPE_OnOff;
+					name = NAME_ACT_RELAIS_CHANNEL_0;
+				}
 				else if (model == MODEL_ACT_ONOFF_PLUG_WALL_1 || model == MODEL_ACT_ONOFF_PLUG_WALL_2)
 				{
 					type = STYPE_OnOff;
@@ -1311,7 +1351,7 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 					type = STYPE_END; // type = STYPE_OnOff; // TODO: fix this hack
 					name = NAME_SELECTOR_WIRED_WALL_DUAL;
 				}
-				else if (model == MODEL_SELECTOR_WIRELESS_WALL_SINGLE_1 || model == MODEL_SELECTOR_WIRELESS_WALL_SINGLE_2)
+				else if (model == MODEL_SELECTOR_WIRELESS_WALL_SINGLE_1 || model == MODEL_SELECTOR_WIRELESS_WALL_SINGLE_2 || model == MODEL_SELECTOR_WIRELESS_WALL_SINGLE_3)
 				{
 					type = STYPE_Selector;
 					name = NAME_SELECTOR_WIRELESS_WALL_SINGLE;
@@ -1341,6 +1381,10 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 					type = STYPE_BlindsPercentage;
 					name = NAME_ACT_BLINDS_CURTAIN;
 				}
+				else if (model == MODEL_ACT_LIGHT)
+				{
+					type = STYPE_Dimmer;
+				}
 
 				std::string voltage = root2["voltage"].asString();
 				int battery = 255;
@@ -1354,7 +1398,7 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 					std::string no_close = root2["no_close"].asString();
 					std::string no_motion = root2["no_motion"].asString();
 					// Aqara's Wireless switch reports per channel
-					std::string aqara_wireless1 = root2[NAME_CHANNEL_0].asString();
+					std::string aqara_wireless1 = root2[NAME_CHANNEL_0].asString(); // TODO: rename var as it's not always a wireless switch
 					std::string aqara_wireless2 = root2[NAME_CHANNEL_1].asString();
 					std::string aqara_wireless3 = root2["dual_channel"].asString();
 					// Smart plug usage
@@ -1468,8 +1512,31 @@ void XiaomiGateway::xiaomi_udp_server::handle_receive(const boost::system::error
 					{
 						if (model == MODEL_ACT_ONOFF_PLUG || model == MODEL_ACT_ONOFF_PLUG_WALL_1 || model == MODEL_ACT_ONOFF_PLUG_WALL_2)
 						{
-							sleep_milliseconds(100); // Need to sleep here as the gateway will send 2 update messages, and need time for the database to update the state so
-										 // that the event is not triggered twice
+							// Need to sleep here as the gateway will send 2 update messages, and need time for the database to update the
+							// state so that the event is not triggered twice
+							sleep_milliseconds(100); // TODO: try to reduce or remove this sleep
+							TrueGateway->InsertUpdateSwitch(sid, name, on, type, unitcode, level, cmd, load_power, power_consumed, battery);
+						}
+						else if (model == MODEL_ACT_RELAIS)
+						{
+							unitcode = XiaomiUnitCode::ACT_RELAIS_CHANNEL_0;
+							name = NAME_ACT_RELAIS_CHANNEL_0;
+							if (!aqara_wireless1.empty())
+							{
+								if (aqara_wireless1 == STATE_ON)
+								{
+									on = true;
+								}
+							}
+							else if (!aqara_wireless2.empty())
+							{
+								unitcode = XiaomiUnitCode::ACT_RELAIS_CHANNEL_1;
+								name = NAME_ACT_RELAIS_CHANNEL_1;
+								if (aqara_wireless2 == STATE_ON)
+								{
+									on = true;
+								}
+							}
 							TrueGateway->InsertUpdateSwitch(sid, name, on, type, unitcode, level, cmd, load_power, power_consumed, battery);
 						}
 						else if ((model == MODEL_ACT_BLINDS_CURTAIN) && (!curtain.empty()))
@@ -1693,16 +1760,16 @@ void XiaomiGateway::XiaomiGatewayTokenManager::UpdateTokenSID(const std::string
 	std::unique_lock<std::mutex> lock(m_mutex);
 	for (auto &m_GatewayToken : m_GatewayTokens)
 	{
-		if (boost::get<0>(m_GatewayToken) == ip)
+		if (std::get<0>(m_GatewayToken) == ip)
 		{
-			boost::get<1>(m_GatewayToken) = token;
-			boost::get<2>(m_GatewayToken) = sid;
+			std::get<1>(m_GatewayToken) = token;
+			std::get<2>(m_GatewayToken) = sid;
 			found = true;
 		}
 	}
 	if (!found)
 	{
-		m_GatewayTokens.push_back(boost::make_tuple(ip, token, sid));
+		m_GatewayTokens.emplace_back(ip, token, sid);
 	}
 }
 
@@ -1712,8 +1779,8 @@ std::string XiaomiGateway::XiaomiGatewayTokenManager::GetToken(const std::string
 	bool found = false;
 	std::unique_lock<std::mutex> lock(m_mutex);
 	for (auto &m_GatewayToken : m_GatewayTokens)
-		if (boost::get<0>(m_GatewayToken) == ip)
-			token = boost::get<1>(m_GatewayToken);
+		if (std::get<0>(m_GatewayToken) == ip)
+			token = std::get<1>(m_GatewayToken);
 
 	return token;
 }
@@ -1724,8 +1791,8 @@ std::string XiaomiGateway::XiaomiGatewayTokenManager::GetSID(const std::string &
 	bool found = false;
 	std::unique_lock<std::mutex> lock(m_mutex);
 	for (auto &m_GatewayToken : m_GatewayTokens)
-		if (boost::get<0>(m_GatewayToken) == ip)
-			sid = boost::get<2>(m_GatewayToken);
+		if (std::get<0>(m_GatewayToken) == ip)
+			sid = std::get<2>(m_GatewayToken);
 
 	return sid;
 }
@@ -1733,11 +1800,12 @@ std::string XiaomiGateway::XiaomiGatewayTokenManager::GetSID(const std::string &
 std::string XiaomiGateway::DetermineChannel(int32_t unitcode)
 {
 	std::string cmdchannel;
-	if (unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_SINGLE || unitcode == XiaomiUnitCode::ACT_ONOFF_PLUG || unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_DUAL_CHANNEL_0)
+	if (unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_SINGLE || unitcode == XiaomiUnitCode::ACT_ONOFF_PLUG || unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_DUAL_CHANNEL_0 ||
+	    unitcode == XiaomiUnitCode::ACT_RELAIS_CHANNEL_0)
 	{
 		cmdchannel = NAME_CHANNEL_0;
 	}
-	else if (unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_DUAL_CHANNEL_1)
+	else if (unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_DUAL_CHANNEL_1 || unitcode == XiaomiUnitCode::ACT_RELAIS_CHANNEL_1)
 	{
 		cmdchannel = NAME_CHANNEL_1;
 	}
@@ -1749,15 +1817,23 @@ std::string XiaomiGateway::DetermineDevice(int32_t unitcode)
 	std::string cmddevice;
 	if (unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_SINGLE)
 	{
-		cmddevice = "ctrl_neutral1";
+		cmddevice = MODEL_SELECTOR_WIRED_WALL_SINGLE_1;
 	}
 	else if (unitcode == XiaomiUnitCode::ACT_ONOFF_PLUG)
 	{
-		cmddevice = "plug";
+		cmddevice = MODEL_ACT_ONOFF_PLUG;
 	}
 	else if (unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_DUAL_CHANNEL_0 || unitcode == XiaomiUnitCode::SELECTOR_WIRED_WALL_DUAL_CHANNEL_1)
 	{
-		cmddevice = "ctrl_neutral2";
+		cmddevice = MODEL_SELECTOR_WIRED_WALL_DUAL_1;
+	}
+	else if (unitcode == XiaomiUnitCode::ACT_RELAIS_CHANNEL_0 || unitcode == XiaomiUnitCode::ACT_RELAIS_CHANNEL_1)
+	{
+		cmddevice = MODEL_ACT_RELAIS;
+	}
+	else if (unitcode == XiaomiUnitCode::ACT_LIGHT)
+	{
+		cmddevice = MODEL_ACT_LIGHT;
 	}
 	return cmddevice;
 }
