@@ -2232,20 +2232,63 @@ std::string bt_openwebnet::getWhereDescription(const std::string& who, const std
 		return where + vectorToString(whereParameters);
 	}
 	else if (who == "4") {
-		// "Temperature control" : TODO
-		//0 : General probes (all probes)
-		//1 : Zone 1 master probe ...
-		//99 : Zone 99 master probe
-		//001 : All probes(master and slave) belonging to Zone 1 ...
-		//099 : All probes(master and slave) belonging to Zone 99
-		//101 : Probe 1 of Zone 1 ...
-		//801 : Probe 8 of Zone 1
-		//102 : Probe 1 of Zone 2...
-		//899 : Probe 8 of Zone 99
-		//#0 : Central Unit
-		//#1 : Zone 1 via Central Unit...
-		//#99 : Zone 99 via Central Unit
-		//3#<where actuators> with actuators = Z#N belonging to [0 - 99]#[1 - 9] : Split Control actuator Z/N
+		// "Temperature control" : 
+		std::stringstream ssw(where);
+		std::string tokenx, str1, str2, str3;
+
+		if (std::getline(ssw, tokenx, '#')) str1 = tokenx;
+		if (std::getline(ssw, tokenx, '#')) str2 = tokenx;
+		if (std::getline(ssw, tokenx, '#')) str3 = tokenx;
+
+		if (str1.length() && str2.length() && str2.length())
+		{
+			// TODO
+			// 3#<where actuators> with actuators = Z#N belonging to [0 - 99]#[1 - 9] : Split Control actuator Z/N
+		}
+		else if (int len1 = str1.length()) 
+		{
+			int iWhere = atoi(str1.c_str());
+			if (len1 <= 2)
+			{
+				// 0 : General probes (all probes)
+				// 1 : Zone 1...99 master probe ...
+				
+				if (iWhere == 0)
+					return "General probes (all probes)";
+				else if ((iWhere >= 1) && (iWhere <= 99))
+					return "Zone" + str1 + " master probe";
+			}
+			else if (len1 == 3)
+			{
+				int probe = iWhere / 100;
+				int zone = iWhere % 100;
+				if (probe == 0)
+				{
+					// 001 : All probes(master and slave) belonging to Zone 1 ...
+					// 099 : All probes(master and slave) belonging to Zone 99
+					return "All probes(master and slave) belonging to Zone " + where.substr(1, 2);
+				}
+				else if ((probe >= 1) && (probe <= 99))
+				{
+					// 101 : Probe 1 of Zone 1 ...
+					// 801 : Probe 8 of Zone 1
+					// 102 : Probe 1 of Zone 2...
+					// 899 : Probe 8 of Zone 99
+					return "Probe " + where.substr(0, 0) + " of Zone " + where.substr(1, 2);
+				}
+			}
+		}
+		else if (str2.length())
+		{
+			//#0 : Central Unit
+			//#1 : Zone 1 via Central Unit...
+			//#99 : Zone 99 via Central Unit
+			int iWhere = atoi(str2.c_str());
+			if (iWhere == 0)
+				return "Central Unit";
+			else if ((iWhere >= 1) && (iWhere <= 99))
+				return "Zone " + str2 + "via Central Unit";
+		}
 	}
 	else if (who == "5") {
         
