@@ -247,6 +247,31 @@ enum {
 	TEMPERATURE_CONTROL_DIMENSION_END_DATE_HOLIDAY_SCENARIO = 30
 };
 
+// temperature WHAT Mode
+enum
+{
+	TEMPERATURE_WHAT_MODE_CONDITIONING = 0,
+	TEMPERATURE_WHAT_MODE_HEATING = 1,
+	TEMPERATURE_WHAT_MODE_ANTIFREEZE = 102,
+	TEMPERATURE_WHAT_MODE_THERMAL_PROTECTION = 202,
+	TEMPERATURE_WHAT_MODE_GENERIC_OFF = 303
+};
+
+// temperature SELECTOR status
+enum
+{
+	TEMPERATURE_SELECTOR_0_NORMAL = 0,
+	TEMPERATURE_SELECTOR_01 = 1,
+	TEMPERATURE_SELECTOR_02 = 2,
+	TEMPERATURE_SELECTOR_03 = 3,
+	TEMPERATURE_SELECTOR_11 = 11,
+	TEMPERATURE_SELECTOR_12 = 12,
+	TEMPERATURE_SELECTOR_13 = 13,
+	TEMPERATURE_SELECTOR_4 = 4,
+	TEMPERATURE_SELECTOR_5 = 5
+};
+
+
 // Load Control dimension
 enum{
 	LOAD_CONTROL_WHAT_ALL_DIMENSIONS = 0,
