@@ -16,7 +16,7 @@
 #include "SQLHelper.h"
 
 #define MAX_LOG_LINE_BUFFER 100
-#define MAX_LOG_LINE_LENGTH (2048*3)
+#define MAX_LOG_LINE_LENGTH (2048 * 3)
 
 extern bool g_bRunAsDaemon;
 extern bool g_bUseSyslog;
@@ -35,8 +35,8 @@ CLogger::CLogger()
 	m_bEnableLogTimestamps = true;
 	m_bEnableErrorsToNotificationSystem = false;
 	m_LastLogNotificationsSend = 0;
-	m_log_flags = LOG_NORM | LOG_STATUS | LOG_ERROR;
-	m_debug_flags = DEBUG_NORM;
+	SetLogFlags(LOG_NORM | LOG_STATUS | LOG_ERROR);
+	SetDebugFlags(DEBUG_NORM);
 }
 
 CLogger::~CLogger()
@@ -45,7 +45,7 @@ CLogger::~CLogger()
 		m_outputfile.close();
 }
 
-//Supported flags: normal,status,error,debug
+// Supported flags: all,normal,status,error,debug
 bool CLogger::SetLogFlags(const std::string &sFlags)
 {
 	std::vector<std::string> flags;
@@ -60,8 +60,8 @@ bool CLogger::SetLogFlags(const std::string &sFlags)
 			continue;
 		if (is_number(wflag))
 		{
-			//Flags are set provided (bitwise)
-			SetLogFlags(atoi(wflag.c_str()));
+			// Flags are set provided (bitwise)
+			SetLogFlags(strtoul(wflag.c_str(), nullptr, 10));
 			return true;
 		}
 		if (wflag == "all")
@@ -75,13 +75,18 @@ bool CLogger::SetLogFlags(const std::string &sFlags)
 		else if (wflag == "debug")
 			iFlags |= LOG_DEBUG_INT;
 		else
-			return false; //invalid flag
+			return false; // invalid flag
 	}
 	SetLogFlags(iFlags);
 	return true;
 }
 
-//Supported flags: normal,hardware,received,webserver,eventsystem,python,thread_id
+void CLogger::SetLogFlags(const uint32_t iFlags)
+{
+	m_log_flags = iFlags;
+}
+
+// Supported flags: all,normal,hardware,received,webserver,eventsystem,python,thread_id,sql
 bool CLogger::SetDebugFlags(const std::string &sFlags)
 {
 	std::vector<std::string> flags;
@@ -96,13 +101,13 @@ bool CLogger::SetDebugFlags(const std::string &sFlags)
 			continue;
 		if (is_number(wflag))
 		{
-			//Flags are set provided (bitwise)
-			SetLogFlags(atoi(wflag.c_str()));
+			// Flags are set provided (bitwise)
+			SetDebugFlags(strtoul(wflag.c_str(), nullptr, 10));
 			return true;
 		}
 		if (wflag == "all")
 			iFlags |= DEBUG_ALL;
-		if (wflag == "normal")
+		else if (wflag == "normal")
 			iFlags |= DEBUG_NORM;
 		else if (wflag == "hardware")
 			iFlags |= DEBUG_HARDWARE;
@@ -116,13 +121,32 @@ bool CLogger::SetDebugFlags(const std::string &sFlags)
 			iFlags |= DEBUG_PYTHON;
 		else if (wflag == "thread_id")
 			iFlags |= DEBUG_THREADIDS;
+		else if (wflag == "sql")
+			iFlags |= DEBUG_SQL;
 		else
-			return false; //invalid flag
+			return false; // invalid flag
 	}
 	SetDebugFlags(iFlags);
 	return true;
 }
 
+void CLogger::SetDebugFlags(const uint32_t iFlags)
+{
+	m_debug_flags = iFlags;
+}
+
+bool CLogger::IsLogLevelEnabled(const _eLogLevel level)
+{
+	return (m_log_flags & level);
+}
+
+bool CLogger::IsDebugLevelEnabled(const _eDebugLevel level)
+{
+	if (!(m_log_flags & LOG_DEBUG_INT))
+		return false;
+	return (m_debug_flags & level);
+}
+
 void CLogger::SetOutputFile(const char *OutputFile)
 {
 	std::unique_lock<std::mutex> lock(m_mutex);
@@ -155,15 +179,15 @@ void CLogger::ForwardErrorsToNotificationSystem(const bool bDoForward)
 		m_notification_log.clear();
 }
 
-void CLogger::Log(const _eLogLevel level, const std::string& sLogline)
+void CLogger::Log(const _eLogLevel level, const std::string &sLogline)
 {
 	Log(level, "%s", sLogline.c_str());
 }
 
-void CLogger::Log(const _eLogLevel level, const char* logline, ...)
+void CLogger::Log(const _eLogLevel level, const char *logline, ...)
 {
 	if (!(m_log_flags & level))
-		return; //This log level is not enabled!
+		return; // This log level is not enabled!
 
 	va_list argList;
 	char cbuffer[MAX_LOG_LINE_LENGTH];
@@ -225,20 +249,20 @@ void CLogger::Log(const _eLogLevel level, const char* logline, ...)
 
 		if (!g_bRunAsDaemon)
 		{
-			//output to console
-	#ifndef WIN32
+			// output to console
+#ifndef WIN32
 			if (level != LOG_ERROR)
-	#endif
+#endif
 				std::cout << szIntLog << std::endl;
-	#ifndef WIN32
-			else  // print text in red color
+#ifndef WIN32
+			else // print text in red color
 				std::cout << szIntLog.substr(0, 25) << "\033[1;31m" << szIntLog.substr(25) << "\033[0;0m" << std::endl;
-	#endif
+#endif
 		}
 
 		if (m_outputfile.is_open())
 		{
-			//output to file
+			// output to file
 			m_outputfile << szIntLog << std::endl;
 			m_outputfile.flush();
 		}
@@ -253,7 +277,7 @@ void CLogger::Log(const _eLogLevel level, const char* logline, ...)
 	}
 }
 
-void CLogger::Debug(const _eDebugLevel level, const char* logline, ...)
+void CLogger::Debug(const _eDebugLevel level, const char *logline, ...)
 {
 	if (!IsDebugLevelEnabled(level))
 		return;
@@ -265,7 +289,7 @@ void CLogger::Debug(const _eDebugLevel level, const char* logline, ...)
 	Debug(level, std::string(cbuffer));
 }
 
-void CLogger::Debug(const _eDebugLevel level, const std::string& sLogline)
+void CLogger::Debug(const _eDebugLevel level, const std::string &sLogline)
 {
 	if (!IsDebugLevelEnabled(level))
 		return;
@@ -302,7 +326,7 @@ void CLogger::LogSequenceEnd(const _eLogLevel level)
 	m_bInSequenceMode = false;
 }
 
-void CLogger::LogSequenceAdd(const char* logline)
+void CLogger::LogSequenceAdd(const char *logline)
 {
 	if (!m_bInSequenceMode)
 		return;
@@ -310,7 +334,7 @@ void CLogger::LogSequenceAdd(const char* logline)
 	m_sequencestring << logline << std::endl;
 }
 
-void CLogger::LogSequenceAddNoLF(const char* logline)
+void CLogger::LogSequenceAddNoLF(const char *logline)
 {
 	if (!m_bInSequenceMode)
 		return;
@@ -349,7 +373,7 @@ std::list<CLogger::_tLogLineStruct> CLogger::GetLog(const _eLogLevel level, cons
 		for (const auto &l : m_lastlog)
 			std::copy_if(l.second.begin(), l.second.end(), std::back_inserter(mlist), [lastlogtime](const _tLogLineStruct &l2) { return l2.logtime > lastlogtime; });
 
-	//Sort by time
+	// Sort by time
 	mlist.sort(compareLogByTime);
 	return mlist;
 }
