@@ -10,9 +10,9 @@ enum _eLogLevel : uint32_t
 	LOG_NORM = 0x0000001,
 	LOG_STATUS = 0x0000002,
 	LOG_ERROR = 0x0000004,
-	LOG_DEBUG_INT = 0x0000008, //do not use directly, use _log.Debug(...) instead
+	LOG_DEBUG_INT = 0x0000008, // do not use directly, use _log.Debug(...) instead
 	//
-	LOG_ALL = 0xFFFFFFF //Used by web interface to retrieve all log types
+	LOG_ALL = 0xFFFFFFF // Used by web interface to retrieve all log types
 };
 enum _eDebugLevel : uint32_t
 {
@@ -22,14 +22,15 @@ enum _eDebugLevel : uint32_t
 	DEBUG_WEBSERVER = 0x0000008,
 	DEBUG_EVENTSYSTEM = 0x0000010,
 	DEBUG_PYTHON = 0x0000020,
-	DEBUG_THREADIDS = 0x0000030,
+	DEBUG_THREADIDS = 0x0000040,
+	DEBUG_SQL = 0x0000080,
 	//
 	DEBUG_ALL = 0xFFFFFFF
 };
 
 class CLogger
 {
-public:
+      public:
 	struct _tLogLineStruct
 	{
 		time_t logtime;
@@ -42,21 +43,12 @@ public:
 	~CLogger();
 
 	bool SetLogFlags(const std::string &sFlags);
-	void SetLogFlags(const uint32_t iFlags) {
-		m_log_flags = iFlags;
-	}
-	bool IsLogLevelEnabled(const _eLogLevel level) {
-		return (m_log_flags & level);
-	}
+	void SetLogFlags(const uint32_t iFlags);
+	bool IsLogLevelEnabled(const _eLogLevel level);
+
 	bool SetDebugFlags(const std::string &sFlags);
-	void SetDebugFlags(const uint32_t iFlags) {
-		m_debug_flags = iFlags;
-	}
-	bool IsDebugLevelEnabled(const _eDebugLevel level) {
-		if (!(m_log_flags & LOG_DEBUG_INT))
-			return false;
-		return (m_debug_flags & level);
-	}
+	void SetDebugFlags(const uint32_t iFlags);
+	bool IsDebugLevelEnabled(const _eDebugLevel level);
 
 	void SetOutputFile(const char *OutputFile);
 
@@ -73,8 +65,8 @@ public:
 #endif
 		;
 	void LogSequenceStart();
-	void LogSequenceAdd(const char* logline);
-	void LogSequenceAddNoLF(const char* logline);
+	void LogSequenceAdd(const char *logline);
+	void LogSequenceAddNoLF(const char *logline);
 	void LogSequenceEnd(_eLogLevel level);
 
 	void EnableLogTimestamps(bool bEnableTimestamps);
@@ -87,13 +79,14 @@ public:
 
 	std::list<_tLogLineStruct> GetNotificationLogs();
 	bool NotificationLogsEnabled();
-private:
+
+      private:
 	uint32_t m_log_flags;
 	uint32_t m_debug_flags;
 
 	std::mutex m_mutex;
 	std::ofstream m_outputfile;
-	std::map<_eLogLevel, std::deque<_tLogLineStruct> > m_lastlog;
+	std::map<_eLogLevel, std::deque<_tLogLineStruct>> m_lastlog;
 	std::deque<_tLogLineStruct> m_notification_log;
 	bool m_bInSequenceMode;
 	bool m_bEnableLogTimestamps;
