@@ -4,27 +4,29 @@
 
 enum _eSwitchType
 {
-	STYPE_OnOff = 0,				//0
-	STYPE_Doorbell,					//1
-	STYPE_Contact,					//2
-	STYPE_Blinds,					//3
-	STYPE_X10Siren,					//4
-	STYPE_SMOKEDETECTOR,			//5
-	STYPE_BlindsInverted,			//6
-	STYPE_Dimmer,					//7
-	STYPE_Motion,					//8
-	STYPE_PushOn,					//9
-	STYPE_PushOff,					//10
-	STYPE_DoorContact,				//11
-	STYPE_Dusk,						//12
-	STYPE_BlindsPercentage,			//13
-	STYPE_VenetianBlindsUS,			//14
-	STYPE_VenetianBlindsEU,			//15
-	STYPE_BlindsPercentageInverted,	//16
-	STYPE_Media,					//17
-	STYPE_Selector,					//18
-	STYPE_DoorLock,					//19
-	STYPE_DoorLockInverted,			//20
+	STYPE_OnOff = 0,						//0
+	STYPE_Doorbell,							//1
+	STYPE_Contact,							//2
+	STYPE_Blinds,							//3
+	STYPE_X10Siren,							//4
+	STYPE_SMOKEDETECTOR,					//5
+	STYPE_BlindsInverted,					//6
+	STYPE_Dimmer,							//7
+	STYPE_Motion,							//8
+	STYPE_PushOn,							//9
+	STYPE_PushOff,							//10
+	STYPE_DoorContact,						//11
+	STYPE_Dusk,								//12
+	STYPE_BlindsPercentage,					//13
+	STYPE_VenetianBlindsUS,					//14
+	STYPE_VenetianBlindsEU,					//15
+	STYPE_BlindsPercentageInverted,			//16
+	STYPE_Media,							//17
+	STYPE_Selector,							//18
+	STYPE_DoorLock,							//19
+	STYPE_DoorLockInverted,					//20
+	STYPE_BlindsPercentageWithStop,			//21
+	STYPE_BlindsPercentageInvertedWithStop,	//22
 	STYPE_END
 };
 
@@ -219,6 +221,8 @@ enum _eHardwareTypes {
 	HTYPE_Mercedes,				//122
 	HTYPE_AirconWithMe,         //123
 	HTYPE_TeleinfoMeterTCP,		//124
+	HTYPE_MQTTAutoDiscovery,	//125
+	HTYPE_RFLINKMQTT,			//126
 	HTYPE_END
 };
 
