@@ -4,19 +4,14 @@
 class CNotificationEmail : public CNotificationBase {
 public:
 	CNotificationEmail();
-	~CNotificationEmail();
-	virtual bool IsConfigured();
-protected:
-	virtual bool SendMessageImplementation(
-		const uint64_t Idx,
-		const std::string &Name,
-		const std::string &Subject,
-		const std::string &Text,
-		const std::string &ExtraData,
-		const int Priority,
-		const std::string &Sound,
-		const bool bFromNotification);
-private:
+	~CNotificationEmail() override = default;
+	bool IsConfigured() override;
+
+      protected:
+	bool SendMessageImplementation(uint64_t Idx, const std::string &Name, const std::string &Subject, const std::string &Text, const std::string &ExtraData, int Priority, const std::string &Sound,
+				       bool bFromNotification) override;
+
+      private:
 	std::string _EmailFrom;
 	std::string _EmailTo;
 	std::string _EmailServer;
