@@ -14,10 +14,6 @@ CNotificationPushsafer::CNotificationPushsafer() : CNotificationBase(std::string
 	SetupConfig(std::string("PushsaferImage"), _apiuser);
 }
 
-CNotificationPushsafer::~CNotificationPushsafer()
-{
-}
-
 bool CNotificationPushsafer::SendMessageImplementation(
 	const uint64_t Idx,
 	const std::string &Name,
@@ -95,7 +91,7 @@ bool CNotificationPushsafer::SendMessageImplementation(
 	{
 		if (!_apiuser.empty())
 		{
-			if (HTTPClient::GETBinary(CURLEncode::URLDecode(_apiuser.c_str()), ExtraHeadersBinary, camimage, 10))
+			if (HTTPClient::GETBinary(CURLEncode::URLDecode(_apiuser), ExtraHeadersBinary, camimage, 10))
 			{
 				std::string base64ImageString(camimage.begin(), camimage.end());
 				base64ImageString = base64_encode(base64ImageString);
@@ -123,5 +119,5 @@ bool CNotificationPushsafer::SendMessageImplementation(
 
 bool CNotificationPushsafer::IsConfigured()
 {
-	return _apikey != "";
+	return !_apikey.empty();
 }
