@@ -581,7 +581,7 @@ std::string CBasePush::ProcessSendValue(const uint64_t DeviceRowIdx, const std::
 				sprintf(szData, "%g", vis * 0.3937007874015748F);
 			}
 		}
-		else if (vType == "Status")
+		else if ((vType == "Status") || (vType == "Alert"))
 		{
 			sprintf(szData, "%d", nValue);
 		}
@@ -604,7 +604,7 @@ std::string CBasePush::ProcessSendValue(const uint64_t DeviceRowIdx, const std::
 
 			sprintf(szData, "%d", level);
 		}
-		else if ((vType == "Current 1") || (vType == "Current 2") || (vType == "Current 3"))
+		else if ((vType == "Current") || (vType == "Current 1") || (vType == "Current 2") || (vType == "Current 3"))
 		{
 			strcpy(szData, rawsendValue.c_str());
 		}
@@ -790,11 +790,11 @@ std::string CBasePush::getUnit(const int devType, const int devSubType, const in
 	{
 		strcpy(szData, "dB");
 	}
-	else if (vType == "Status")
+	else if ((vType == "Status") || (vType == "Alert"))
 	{
 		strcpy(szData, "");
 	}
-	else if ((vType == "Current 1") || (vType == "Current 2") || (vType == "Current 3"))
+	else if ((vType == "Current") || (vType == "Current 1") || (vType == "Current 2") || (vType == "Current 3"))
 	{
 		strcpy(szData, "");
 	}
@@ -948,7 +948,9 @@ namespace http {
 					int dType = atoi(sd[2].c_str());
 					int dSubType = atoi(sd[3].c_str());
 					std::string sOptions = RFX_Type_SubType_Values(dType, dSubType);
-					if (sOptions == "Status")
+					std::vector<std::string> tmpV;
+					StringSplit(sOptions, ",", tmpV);
+					if (!tmpV.empty() && tmpV[0] == "Status")
 					{
 						root["result"][ii]["name"] = sd[1];
 						root["result"][ii]["value"] = sd[0];
