@@ -4,6 +4,7 @@
 #include <sstream>
 #include "../httpclient/UrlEncode.h"
 #include "../main/Helper.h"
+#include "../main/Logger.h"
 
 //(c) 2016 GizMoCuz
 
@@ -120,10 +121,9 @@ struct _tFCGI_UnknownTypeRecord {
 	_tFCGI_UnknownTypeBody body;
 };
 
-std::string ExecuteCommandAndReturnRaw(const std::string &szCommand)
+std::vector<char> ExecuteCommandAndReturnRaw(const std::string &szCommand)
 {
-	std::string ret;
-
+	std::vector<char> myData;
 	try
 	{
 		FILE *fp;
@@ -134,13 +134,20 @@ std::string ExecuteCommandAndReturnRaw(const std::string &szCommand)
 #else
 		fp = popen(szCommand.c_str(), "r");
 #endif
-		if (fp != NULL)
+		if (fp != nullptr)
 		{
-			char path[1035];
-			/* Read the output a line at a time - output it. */
-			while (fgets(path, sizeof(path) - 1, fp) != NULL)
-			{
-				ret += path;
+			for (;;) {
+				const int BufferSize = 1024;
+
+				const size_t oldSize = myData.size();
+				myData.resize(myData.size() + BufferSize);        
+
+				const unsigned bytesRead = fread(&myData[oldSize], 1, BufferSize,fp);
+				myData.resize(oldSize + bytesRead);
+
+				if (bytesRead == 0) {
+					break;
+				}
 			}
 			/* close */
 #ifdef WIN32
@@ -154,7 +161,7 @@ std::string ExecuteCommandAndReturnRaw(const std::string &szCommand)
 	{
 
 	}
-	return ret;
+	return myData;
 }
 
 extern std::istream & safeGetline(std::istream & is, std::string & line);
@@ -173,26 +180,28 @@ bool fastcgi_parser::handlePHP(const server_settings &settings, const std::strin
 	std::multimap<std::string, std::string> parameters;
 
 	std::string request_path2 = req.uri; // we need the raw request string to parse the get-request
+	std::string szQueryString;
 	size_t paramPos = request_path2.find_first_of('?');
 	if (paramPos != std::string::npos)
 	{
 		std::string params = request_path2.substr(paramPos + 1);
+		szQueryString = request_path2.substr(paramPos + 1);
 		std::string name;
 		std::string value;
 
 		size_t q = 0;
 		size_t p = q;
 		int flag_done = 0;
-		std::string uri = params;
+		const std::string &uri = params;
 		while (!flag_done) {
-			q = uri.find("=", p);
+			q = uri.find('=', p);
 			if (q == std::string::npos)
 			{
 				break;
 			}
 			name = uri.substr(p, q - p);
 			p = q + 1;
-			q = uri.find("&", p);
+			q = uri.find('&', p);
 			if (q != std::string::npos)
 				value = uri.substr(p, q - p);
 			else {
@@ -200,8 +209,9 @@ bool fastcgi_parser::handlePHP(const server_settings &settings, const std::strin
 				flag_done = 1;
 			}
 			// the browser sends blanks as +
-			while (1) {
-				size_t p = value.find("+");
+			while (true)
+			{
+				size_t p = value.find('+');
 				if (p == std::string::npos)
 					break;
 				value.replace(p, 1, " ");
@@ -214,17 +224,17 @@ bool fastcgi_parser::handlePHP(const server_settings &settings, const std::strin
 		const char *pContent_Type = request::get_req_header(&req, "Content-Type");
 		if (pContent_Type)
 		{
-			if (strstr(pContent_Type, "multipart") != NULL)
+			if (strstr(pContent_Type, "multipart") != nullptr)
 			{
 				const char *pBoundary = strstr(pContent_Type, "boundary=");
-				if (pBoundary != NULL)
+				if (pBoundary != nullptr)
 				{
 					std::string szBoundary = std::string("--") + (pBoundary + 9);
 					//Find boundary in content
 					std::istringstream ss(req.content);
 					std::string csubstr;
 					int ii = 0;
-					std::string vName = "";
+					std::string vName;
 					while (!ss.eof())
 					{
 						safeGetline(ss, csubstr);
@@ -249,7 +259,7 @@ bool fastcgi_parser::handlePHP(const server_settings &settings, const std::strin
 									return false;
 								}
 								vName = csubstr.substr(npos + 6);
-								npos = vName.find("\"");
+								npos = vName.find('"');
 								if (npos == std::string::npos)
 								{
 									rep = reply::stock_reply(reply::bad_request);
@@ -261,7 +271,7 @@ bool fastcgi_parser::handlePHP(const server_settings &settings, const std::strin
 						}
 						else if (ii == 2)
 						{
-							if (csubstr.size() == 0)
+							if (csubstr.empty())
 							{
 								ii++;
 								//2 empty lines, rest is data
@@ -288,24 +298,16 @@ bool fastcgi_parser::handlePHP(const server_settings &settings, const std::strin
 	gfci.paddingLength = 0;
 	request_id_++;
 
-	std::string szQueryString;
 
 	std::string str_params;
-	std::multimap<std::string, std::string>::const_iterator itt;
-	for (itt = parameters.begin(); itt != parameters.end(); ++itt)
+	for (const auto &p : parameters)
 	{
 		if (!str_params.empty())
 			str_params += " ";
 
-		str_params.append(itt->first);
+		str_params.append(p.first);
 		str_params.append("=");
-		str_params.append(itt->second);
-
-		if (!szQueryString.empty())
-			szQueryString += "&";
-		szQueryString.append(itt->first);
-		szQueryString.append("=");
-		szQueryString.append(CURLEncode::URLEncode(itt->second));
+		str_params.append(p.second);
 	}
 
 	std::string fullexecmd = settings.php_cgi_path + " " + full_path;
@@ -336,23 +338,29 @@ bool fastcgi_parser::handlePHP(const server_settings &settings, const std::strin
 
 	fullexecmd += " SERVER_SOFTWARE=Domoticz";
 	fullexecmd += " SERVER_NAME=localhost";
-	fullexecmd += " SERVER_ADDR=" + CURLEncode::URLEncode(settings.listening_address);
+	fullexecmd += " SERVER_ADDR='" + settings.listening_address + "'";
 	fullexecmd += " SERVER_PORT=" + settings.listening_port;
 	fullexecmd += " REMOTE_ADDR=" + req.host_address;
-	fullexecmd += " REMOTE_PORT=" + req.host_port;
+	fullexecmd += " QUERY_STRING='" + szQueryString + "'";
 
-	std::vector<header>::const_iterator ittHeader;
-	for (ittHeader = req.headers.begin(); ittHeader != req.headers.end(); ++ittHeader)
+	for (const auto &header : req.headers)
 	{
-		std::string rName = "HTTP_" + ittHeader->name;
+		std::string rName = "HTTP_" + header.name;
 		stdreplace(rName, "-", "_");
 		stdupper(rName);
-		fullexecmd += " " + rName + "=" + CURLEncode::URLEncode(ittHeader->value);
+		fullexecmd += " " + rName + "='" + header.value + "'";
 
-		fcgi_params[rName] = CURLEncode::URLEncode(ittHeader->value);
+		fcgi_params[rName] = CURLEncode::URLEncode(header.value);
 	}
+#ifdef WIN32
+	fullexecmd = "SET QUERY_STRING=\""+szQueryString + "\" & " + fullexecmd;
+#else
+	fullexecmd = "export QUERY_STRING='"+szQueryString + "' && " + fullexecmd;
+#endif
 
-	std::string pret = ExecuteCommandAndReturnRaw(fullexecmd);
+	_log.Debug(DEBUG_NORM, "[PHP] Command: %s", fullexecmd.c_str());
+	std::vector<char> v = ExecuteCommandAndReturnRaw(fullexecmd);
+	std::string pret(v.begin(), v.end());
 	if (pret.empty())
 	{
 		rep = reply::stock_reply(reply::not_found);
@@ -363,6 +371,8 @@ bool fastcgi_parser::handlePHP(const server_settings &settings, const std::strin
 	bool bDoneWithHeaders = false;
 	while (!bDoneWithHeaders)
 	{
+		if (pret[0] == '\r') pret=pret.substr(1);	//Skip CR symbol if present
+		
 		size_t tpos = pret.find('\n');
 		if (tpos == std::string::npos)
 		{
@@ -418,6 +428,5 @@ bool fastcgi_parser::handlePHP(const server_settings &settings, const std::strin
 	return true;
 }
 
-}
-}
-
+	} // namespace server
+} // namespace http
